<?php
session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';


// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("Location: ../admin.php");
    exit;
}

// Fonction pour récupérer les tags fréquents
function getFrequentTags($pdo) {
    $query = "
        SELECT 
            st.id,
            st.tag, 
            st.resolved,
            st.section,
            st.date_cle_id,
            COUNT(DISTINCT tt.tache_id) as total_count,
            COUNT(DISTINCT CASE WHEN (dc.date IS NULL OR t.date_creation > dc.date) THEN tt.tache_id ELSE NULL END) as count_since_last_date_cle,
            dc.id as date_cle_id,
            dc.description as date_cle_description,
            dc.date as date_cle_date,
            dc.section as date_cle_section,
            dc.sous_section as date_cle_sous_section,
            dc.numero_chambre as date_cle_numero_chambre
        FROM 
            section_tags st
        LEFT JOIN 
            tags_taches tt ON st.id = tt.tag_id
        LEFT JOIN 
            taches t ON tt.tache_id = t.id
        LEFT JOIN 
            dates_cles dc ON st.date_cle_id = dc.id
        GROUP BY 
            st.id, st.tag, st.resolved, st.section, st.date_cle_id, dc.id, dc.description, dc.date, dc.section, dc.sous_section, dc.numero_chambre
        HAVING 
            COUNT(DISTINCT tt.tache_id) >= 10
        ORDER BY 
            st.resolved ASC, COUNT(DISTINCT tt.tache_id) DESC
    ";
    return $pdo->query($query)->fetchAll(PDO::FETCH_ASSOC);
}

$frequentTags = getFrequentTags($pdo);

// Traitement de la création ou mise à jour d'une date clé
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['create_date_cle']) || isset($_POST['update_date_cle'])) {
        $description = $_POST['description'];
        $date = $_POST['date'];
        $section = $_POST['section'];
        $sous_section = $_POST['sous_section'] ?? null;
        $numero_chambre = $_POST['numero_chambre'] ?? null;
        $tag_id = $_POST['tag_id'];

        if (isset($_POST['create_date_cle'])) {
            // Créer la date clé
            $date_cle_id = addDateCle($pdo, $description, $date, $section, $sous_section, $numero_chambre);
            if ($date_cle_id) {
                // Associer la date clé au tag et le marquer comme résolu
                $stmt = $pdo->prepare("UPDATE section_tags SET resolved = TRUE, date_cle_id = ? WHERE id = ?");
                $stmt->execute([$date_cle_id, $tag_id]);
            }
        } elseif (isset($_POST['update_date_cle'])) {
            $date_cle_id = $_POST['date_cle_id'];
            // Mettre à jour la date clé
            updateDateCle($pdo, $date_cle_id, $description, $date, $section, $sous_section, $numero_chambre);
        }

        // Rediriger vers la page des alertes
        header("Location: alertes.php");
        exit;
    }
}

?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Alertes - Admin</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/gh/alpinejs/alpine@v2.x.x/dist/alpine.min.js" defer></script>
</head>
<body class="bg-gray-100 font-sans">
    <div class="flex">
        <?php include 'sidebar.php'; ?>

        <div id="main-content" class="flex-1 p-10">
            <h1 class="text-3xl font-bold mb-6">Alertes - Tags fréquents</h1>
            
            <?php if (empty($frequentTags)): ?>
                <p class="text-gray-600">Aucune alerte pour le moment.</p>
            <?php else: ?>
                <div class="space-y-4">
                    <h2 class="text-2xl font-semibold mb-4">Alertes actives</h2>
                    <?php foreach ($frequentTags as $tag): ?>
                        <?php if (!$tag['resolved']): ?>
                            <div x-data="{ open: false }" class="bg-white shadow-md rounded-lg overflow-hidden">
                                <div class="px-6 py-4 flex justify-between items-center cursor-pointer" @click="open = !open">
                                    <div>
                                        <h2 class="text-xl font-semibold">
                                            Section: <?php echo htmlspecialchars($tag['section']); ?> - 
                                            Tag: <?php echo htmlspecialchars($tag['tag']); ?> 
                                            (<?php echo $tag['count_since_last_date_cle']; ?> tâches depuis la dernière date clé)
                                        </h2>
                                    </div>
                                    <svg class="w-6 h-6 transform transition-transform duration-200" :class="{'rotate-180': open}" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 9l-7 7-7-7" />
                                    </svg>
                                </div>
                                <div x-show="open" class="px-6 py-4 border-t">
                                    <h3 class="text-lg font-semibold mb-2">Date clé associée :</h3>
                                    <?php if ($tag['date_cle_id']): ?>
                                        <p>Description : <?php echo htmlspecialchars($tag['date_cle_description']); ?></p>
                                        <p>Date : <?php echo htmlspecialchars($tag['date_cle_date']); ?></p>
                                        <p>Section : <?php echo htmlspecialchars($tag['date_cle_section']); ?></p>
                                        <p>Sous-section : <?php echo htmlspecialchars($tag['date_cle_sous_section'] ?? 'Non définie'); ?></p>
                                        <p>Numéro de chambre : <?php echo htmlspecialchars($tag['date_cle_numero_chambre'] ?? 'Non défini'); ?></p>
                                    <?php else: ?>
                                        <p>Aucune date clé associée</p>
                                    <?php endif; ?>
                                    <form method="POST" action="" class="mt-4 space-y-4">
                                        <input type="hidden" name="section" value="<?php echo htmlspecialchars($tag['section']); ?>">
                                        <input type="hidden" name="tag_id" value="<?php echo htmlspecialchars($tag['id']); ?>">
                                        <div>
                                            <label for="description_<?php echo $tag['id']; ?>" class="block text-sm font-medium text-gray-700">Description</label>
                                            <textarea name="description" id="description_<?php echo $tag['id']; ?>" rows="3" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required><?php echo htmlspecialchars($tag['date_cle_description'] ?? ''); ?></textarea>
                                        </div>
                                        <div>
                                            <label for="date_<?php echo $tag['id']; ?>" class="block text-sm font-medium text-gray-700">Date</label>
                                            <input type="date" name="date" id="date_<?php echo $tag['id']; ?>" value="<?php echo htmlspecialchars($tag['date_cle_date'] ?? ''); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                                        </div>
                                        <div>
                                            <label for="sous_section_<?php echo $tag['id']; ?>" class="block text-sm font-medium text-gray-700">Sous-section</label>
                                            <input type="text" name="sous_section" id="sous_section_<?php echo $tag['id']; ?>" value="<?php echo htmlspecialchars($tag['date_cle_sous_section'] ?? ''); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                        </div>
                                        <div>
                                            <label for="numero_chambre_<?php echo $tag['id']; ?>" class="block text-sm font-medium text-gray-700">Numéro de chambre</label>
                                            <input type="text" name="numero_chambre" id="numero_chambre_<?php echo $tag['id']; ?>" value="<?php echo htmlspecialchars($tag['date_cle_numero_chambre'] ?? ''); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                        </div>
                                        <button type="submit" name="<?php echo $tag['date_cle_id'] ? 'update_date_cle' : 'create_date_cle'; ?>" class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded">
                                            <?php echo $tag['date_cle_id'] ? 'Mettre à jour la date clé' : 'Créer une date clé'; ?>
                                        </button>
                                    </form>
                                </div>
                            </div>
                        <?php endif; ?>
                    <?php endforeach; ?>

                    <h2 class="text-2xl font-semibold my-6">Alertes résolues</h2>
                    <?php foreach ($frequentTags as $tag): ?>
                        <?php if ($tag['resolved']): ?>
                            <div x-data="{ showDateCle: false }" class="bg-gray-200 shadow-md rounded-lg overflow-hidden p-4 mb-4">
                                <div class="flex justify-between items-center">
                                    <h2 class="text-xl font-semibold">
                                        Section: <?php echo htmlspecialchars($tag['section']); ?> - 
                                        Tag: <?php echo htmlspecialchars($tag['tag']); ?> 
                                        (<?php echo $tag['total_count']; ?> tâches au total)
                                    </h2>
                                    <button @click="showDateCle = !showDateCle" class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded">
                                        Voir la date clé
                                    </button>
                                </div>
                                <div x-show="showDateCle" class="mt-4">
                                    <h3 class="text-lg font-semibold mb-2">Date clé associée :</h3>
                                    <?php if ($tag['date_cle_id']): ?>
                                        <p>Description : <?php echo htmlspecialchars($tag['date_cle_description']); ?></p>
                                        <p>Date : <?php echo htmlspecialchars($tag['date_cle_date']); ?></p>
                                        <p>Section : <?php echo htmlspecialchars($tag['date_cle_section']); ?></p>
                                        <p>Sous-section : <?php echo htmlspecialchars($tag['date_cle_sous_section'] ?? 'Non définie'); ?></p>
                                        <p>Numéro de chambre : <?php echo htmlspecialchars($tag['date_cle_numero_chambre'] ?? 'Non défini'); ?></p>
                                        <form method="POST" action="" class="mt-4 space-y-4">
                                            <input type="hidden" name="date_cle_id" value="<?php echo $tag['date_cle_id']; ?>">
                                            <input type="hidden" name="section" value="<?php echo htmlspecialchars($tag['section']); ?>">
                                            <input type="hidden" name="tag_id" value="<?php echo htmlspecialchars($tag['id']); ?>">
                                            <div>
                                                <label for="edit_description_<?php echo $tag['id']; ?>" class="block text-sm font-medium text-gray-700">Description</label>
                                                <textarea name="description" id="edit_description_<?php echo $tag['id']; ?>" rows="3" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required><?php echo htmlspecialchars($tag['date_cle_description']); ?></textarea>
                                            </div>
                                            <div>
                                                <label for="edit_date_<?php echo $tag['id']; ?>" class="block text-sm font-medium text-gray-700">Date</label>
                                                <input type="date" name="date" id="edit_date_<?php echo $tag['id']; ?>" value="<?php echo htmlspecialchars($tag['date_cle_date']); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50" required>
                                            </div>
                                            <div>
                                                <label for="edit_sous_section_<?php echo $tag['id']; ?>" class="block text-sm font-medium text-gray-700">Sous-section</label>
                                                <input type="text" name="sous_section" id="edit_sous_section_<?php echo $tag['id']; ?>" value="<?php echo htmlspecialchars($tag['date_cle_sous_section'] ?? ''); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                            </div>
                                            <div>
                                                <label for="edit_numero_chambre_<?php echo $tag['id']; ?>" class="block text-sm font-medium text-gray-700">Numéro de chambre</label>
                                                <input type="text" name="numero_chambre" id="edit_numero_chambre_<?php echo $tag['id']; ?>" value="<?php echo htmlspecialchars($tag['date_cle_numero_chambre'] ?? ''); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                            </div>
                                            <button type="submit" name="update_date_cle" class="bg-green-500 hover:bg-green-600 text-white font-bold py-2 px-4 rounded">
                                                Mettre à jour la date clé
                                            </button>
                                        </form>
                                    <?php else: ?>
                                        <p>Aucune date clé associée</p>
                                    <?php endif; ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
    </div>
    <script>
        // Vous pouvez ajouter ici du JavaScript supplémentaire si nécessaire
    </script>
</body>
</html>