<?php
session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';

// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("Location: ../admin.php");
    exit;
}

// Récupérer les paramètres de filtrage
$end_date = $_GET['end_date'] ?? date('Y-m-d');
$start_date = $_GET['start_date'] ?? date('Y-m-d', strtotime('-1 month'));
$period = $_GET['period'] ?? '';

// Vérifier si le formulaire a été soumis avec des dates personnalisées
if (isset($_GET['start_date']) && isset($_GET['end_date']) && empty($period)) {
    $start_date = $_GET['start_date'];
    $end_date = $_GET['end_date'];
} else {
    // Logique pour les périodes prédéfinies
    switch ($period) {
        case 'week':
            $start_date = date('Y-m-d', strtotime('-1 week'));
            break;
        case 'month':
            $start_date = date('Y-m-d', strtotime('-1 month'));
            break;
        case 'year':
            $start_date = date('Y-m-d', strtotime('-1 year'));
            break;
        case 'all':
            $start_date = $pdo->query("SELECT MIN(date_soumission) FROM questionnaires")->fetchColumn();
            break;
    }
}

// Récupérer les données avec le nouveau système de calcul
$data = getAnalyticsData($pdo, $start_date, $end_date);
$noteTrends = getNoteTrends($pdo, $start_date, $end_date);
$structure = getQuestionnaireStructure($pdo);

// Couleurs harmonieuses pour les sections
$harmonicColors = [
    '#3498db', '#2ecc71', '#e74c3c', '#f39c12', '#9b59b6', 
    '#1abc9c', '#d35400', '#34495e', '#2980b9', '#27ae60'
];

// Associer les couleurs aux sections
$sectionColors = [];
$colorIndex = 0;
foreach ($structure as $section => $subSections) {
    $sectionColors[$section] = $harmonicColors[$colorIndex % count($harmonicColors)];
    $colorIndex++;
}

// Trier les moyennes des sous-sections
usort($data['subSectionAverages'], function($a, $b) {
    return $b['moyenne'] <=> $a['moyenne'];
});
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Analytics - Admin</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link href="../css/styles.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/alpinejs@3.x.x/dist/cdn.min.js" defer></script>
    <style>
        .chart-container {
            position: relative;
            height: 400px;
            width: 100%;
        }
        .data-card {
            transition: all 0.3s ease;
        }
        .data-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        }
        .compact-table td, .compact-table th {
            padding-top: 0.5rem;
            padding-bottom: 0.5rem;
        }
    </style>
</head>
<body class="bg-gray-100 font-sans">
    <div class="flex">
        <?php include 'sidebar.php'; ?>
        <div id="main-content" class="flex-1 p-6">
            <h1 class="text-3xl font-bold mb-6 text-gray-800">Analytics</h1>

            <!-- Formulaire de filtrage -->
            <div class="bg-white p-6 rounded-lg shadow-md mb-6">
                <form method="GET" class="space-y-4">
                    <div class="flex flex-wrap items-end -mx-2 mb-4">
                        <div class="w-full md:w-1/3 px-2 mb-4 md:mb-0">
                            <label for="start_date" class="block text-sm font-medium text-gray-700 mb-1">Date de début</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo htmlspecialchars($start_date); ?>" class="w-full p-2 border rounded-md focus:ring-indigo-500 focus:border-indigo-500">
                        </div>
                        <div class="w-full md:w-1/3 px-2 mb-4 md:mb-0">
                            <label for="end_date" class="block text-sm font-medium text-gray-700 mb-1">Date de fin</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo htmlspecialchars($end_date); ?>" class="w-full p-2 border rounded-md focus:ring-indigo-500 focus:border-indigo-500">
                        </div>
                        <div class="w-full md:w-1/3 px-2 flex justify-end">
                            <button type="submit" class="px-6 py-2 bg-green-600 text-white rounded-md hover:bg-green-700 focus:outline-none focus:ring-2 focus:ring-green-500 focus:ring-opacity-50">
                                Voir la période
                            </button>
                        </div>
                    </div>
                    <div class="flex space-x-2">
                        <button type="submit" name="period" value="week" class="px-4 py-2 bg-indigo-600 text-white rounded-md hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-indigo-500 focus:ring-opacity-50 <?php echo $period === 'week' ? 'bg-indigo-800' : ''; ?>">Semaine</button>
                        <button type="submit" name="period" value="month" class="px-4 py-2 bg-indigo-600 text-white rounded-md hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-indigo-500 focus:ring-opacity-50 <?php echo $period === 'month' ? 'bg-indigo-800' : ''; ?>">Mois</button>
                        <button type="submit" name="period" value="year" class="px-4 py-2 bg-indigo-600 text-white rounded-md hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-indigo-500 focus:ring-opacity-50 <?php echo $period === 'year' ? 'bg-indigo-800' : ''; ?>">Année</button>
                        <button type="submit" name="period" value="all" class="px-4 py-2 bg-indigo-600 text-white rounded-md hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-indigo-500 focus:ring-opacity-50 <?php echo $period === 'all' ? 'bg-indigo-800' : ''; ?>">Tout</button>
                    </div>
                </form>
            </div>

            <!-- Résumé des statistiques -->
            <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 xl:grid-cols-6 gap-6 mb-6">
                <?php 
                $sections = ['Note globale', 'Hotel', 'Chambre', 'Restaurant', 'Spa', 'Impressions'];
                foreach ($sections as $section): 
                    $sectionAvg = $section === 'Note globale' ? $data['globalAverage'] : 
                        (array_values(array_filter($data['sectionAverages'], function($item) use ($section) {
                            return $item['section'] === $section;
                        }))[0]['moyenne'] ?? 0);
                    
                    $borderColor = $sectionColors[$section] ?? '#000000';
                ?>
                <div class="bg-white rounded-lg shadow-md p-6 data-card" style="border-left: 4px solid <?php echo $borderColor; ?>;">
                    <h3 class="text-lg font-semibold mb-2 text-gray-800"><?php echo htmlspecialchars($section); ?></h3>
                    <p class="text-3xl font-bold" style="color: <?php echo $borderColor; ?>;">
                        <?php echo number_format($sectionAvg, 2); ?>
                    </p>
                </div>
                <?php endforeach; ?>
            </div>

            <!-- Graphiques -->
            <div class="grid grid-cols-4 gap-6 mb-6">
                <div class="col-span-3 bg-white rounded-lg shadow-md p-6">
                    <h2 class="text-xl font-semibold mb-4 text-gray-800">Évolution des notes</h2>
                    <div class="chart-container">
                        <canvas id="noteEvolutionChart"></canvas>
                    </div>
                </div>

                <div class="col-span-1 bg-white rounded-lg shadow-md p-6">
                    <h2 class="text-xl font-semibold mb-4 text-gray-800">Détails par section</h2>
                    <div class="mb-4">
                        <label for="sectionDropdown" class="block text-sm font-medium text-gray-700 mb-2">Sélectionnez une section :</label>
                        <select id="sectionDropdown" class="w-full p-2 border rounded-md focus:ring-indigo-500 focus:border-indigo-500">
                            <option value="">Toutes les sections</option>
                            <?php foreach ($structure as $section => $subSections): ?>
                                <option value="<?php echo htmlspecialchars($section); ?>"><?php echo htmlspecialchars($section); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div id="subSectionSelector" class="space-y-2" style="max-height: 300px; overflow-y: auto;">
                    </div>
                </div>
            </div>

            <!-- Notes moyennes par chambre -->
            <div class="bg-white rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-semibold mb-4 text-gray-800">Notes moyennes par chambre</h2>
                <div class="chart-container">
                    <canvas id="roomRatingsChart"></canvas>
                </div>
            </div>

            <!-- Moyennes des sous-sections -->
            <div class="bg-white rounded-lg shadow-md p-6">
                <h2 class="text-xl font-semibold mb-4 text-gray-800">Moyennes des sous-sections</h2>
                <div class="overflow-x-auto space-y-8">
                    <?php
                    $sections = ['Hotel', 'Chambre', 'Restaurant', 'Spa', 'Impressions générales'];
                    foreach ($sections as $currentSection):
                        // Filtrer les sous-sections pour la section courante
                        $sectionData = array_filter($data['subSectionAverages'], function($item) use ($currentSection) {
                            return $item['section'] === $currentSection;
                        });

                        if (!empty($sectionData)):
                    ?>
                        <div class="mb-6">
                            <h3 class="text-lg font-semibold mb-4 text-white bg-gray-600 p-3 rounded-t-lg">
                                <?php echo htmlspecialchars($currentSection); ?>
                            </h3>
                            <table class="min-w-full divide-y divide-gray-200">
                                <thead class="bg-gray-50">
                                    <tr>
                                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Sous-section</th>
                                        <th class="px-6 py-3 text-center text-xs font-medium text-gray-500 uppercase tracking-wider">1★</th>
                                        <th class="px-6 py-3 text-center text-xs font-medium text-gray-500 uppercase tracking-wider">2★</th>
                                        <th class="px-6 py-3 text-center text-xs font-medium text-gray-500 uppercase tracking-wider">3★</th>
                                        <th class="px-6 py-3 text-center text-xs font-medium text-gray-500 uppercase tracking-wider">4★</th>
                                        <th class="px-6 py-3 text-center text-xs font-medium text-gray-500 uppercase tracking-wider">5★</th>
                                        <th class="px-6 py-3 text-center text-xs font-medium text-gray-500 uppercase tracking-wider">Score</th>
                                    </tr>
                                </thead>
                                <tbody class="bg-white divide-y divide-gray-200">
                                    <?php foreach ($sectionData as $subSection): ?>
                                        <tr>
                                            <td class="px-6 py-4 whitespace-nowrap text-sm font-medium text-gray-900">
                                                <?php echo htmlspecialchars($subSection['sous_section']); ?>
                                            </td>
                                            <td class="px-6 py-4 text-center">
                                                <button onclick="showStarDetails('<?php echo htmlspecialchars($subSection['section']); ?>', '<?php echo htmlspecialchars($subSection['sous_section']); ?>', 1)" 
                                                        class="text-gray-600 hover:text-blue-600">
                                                    <?php echo $subSection['one_star']; ?>
                                                </button>
                                            </td>
                                            <td class="px-6 py-4 text-center">
                                                <button onclick="showStarDetails('<?php echo htmlspecialchars($subSection['section']); ?>', '<?php echo htmlspecialchars($subSection['sous_section']); ?>', 2)" 
                                                        class="text-gray-600 hover:text-blue-600">
                                                    <?php echo $subSection['two_stars']; ?>
                                                </button>
                                            </td>
                                            <td class="px-6 py-4 text-center">
                                                <button onclick="showStarDetails('<?php echo htmlspecialchars($subSection['section']); ?>', '<?php echo htmlspecialchars($subSection['sous_section']); ?>', 3)" 
                                                        class="text-gray-600 hover:text-blue-600">
                                                    <?php echo $subSection['three_stars']; ?>
                                                </button>
                                            </td>
                                            <td class="px-6 py-4 text-center">
                                                <button onclick="showStarDetails('<?php echo htmlspecialchars($subSection['section']); ?>', '<?php echo htmlspecialchars($subSection['sous_section']); ?>', 4)" 
                                                        class="text-gray-600 hover:text-blue-600">
                                                    <?php echo $subSection['four_stars']; ?>
                                                </button>
                                            </td>
                                            <td class="px-6 py-4 text-center">
                                                <button onclick="showStarDetails('<?php echo htmlspecialchars($subSection['section']); ?>', '<?php echo htmlspecialchars($subSection['sous_section']); ?>', 5)" 
                                                        class="text-gray-600 hover:text-blue-600">
                                                    <?php echo $subSection['five_stars']; ?>
                                                </button>
                                            </td>
                                            <td class="px-6 py-4 text-center">
    <?php
    // Calcul du score avec la nouvelle pondération
    $total_points = 
        ($subSection['one_star'] * -30) +
        ($subSection['two_stars'] * -15) +
        ($subSection['three_stars'] * 1) +
        ($subSection['four_stars'] * 2) +
        ($subSection['five_stars'] * 5);
    
    $total_notes = 
        $subSection['one_star'] +
        $subSection['two_stars'] +
        $subSection['three_stars'] +
        $subSection['four_stars'] +
        $subSection['five_stars'];
    
    $score = $total_notes > 0 ? $total_points / $total_notes : 0;
    
    // Définir la classe de couleur selon le score
    $bgClass = '';
    if ($score >= 4.5) {
        $bgClass = 'bg-blue-300'; // bleu clair
    } elseif ($score >= 4 && $score < 4.5) {
        $bgClass = 'bg-blue-600 text-white'; // bleu foncé
    }
    ?>
    <span class="px-3 py-1 rounded <?php echo $bgClass; ?>">
        <?php echo number_format($score, 2); ?>
    </span>
</td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php 
                        endif;
                    endforeach; 
                    ?>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal pour les détails -->
    <div id="starDetailsModal" class="fixed inset-0 bg-gray-600 bg-opacity-50 overflow-y-auto h-full w-full hidden" style="z-index: 1000;">
        <div class="relative top-20 mx-auto p-5 border w-11/12 max-w-4xl shadow-lg rounded-md bg-white">
            <div class="flex justify-between items-center pb-3">
                <h3 id="modalTitle" class="text-xl font-semibold"></h3>
                <button onclick="closeStarDetailsModal()" class="text-gray-400 hover:text-gray-500">
                    <svg class="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12" />
                    </svg>
                </button>
            </div>
            <div id="modalContent" class="overflow-x-auto">
            </div>
        </div>
    </div>

    <script src="../js/admin.js"></script>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        const sectionColors = <?php echo json_encode($sectionColors); ?>;
        const structure = <?php echo json_encode($structure); ?>;
        
        function getRandomColor() {
            const letters = '0123456789ABCDEF';
            let color = '#';
            for (let i = 0; i < 6; i++) {
                color += letters[Math.floor(Math.random() * 16)];
            }
            return color;
        }

        // Configuration du graphique d'évolution des notes
        const noteEvolutionCtx = document.getElementById('noteEvolutionChart').getContext('2d');
        const noteEvolutionChart = new Chart(noteEvolutionCtx, {
            type: 'line',
            data: {
                labels: <?php echo json_encode(array_column($data['noteEvolution'], 'date')); ?>,
                datasets: [
                    {
                        label: 'Note globale',
                        data: <?php echo json_encode($globalNotes); ?>,
                        borderColor: '#000000',
                        backgroundColor: '#00000080',
                        fill: false,
                        tension: 0.1,
                        borderWidth: 3,
                        order: 0
                    }
                ]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: false,
                        min: 1,
                        max: 5,
                        ticks: {
                            stepSize: 1
                        }
                    }
                },
                plugins: {
                    legend: {
                        position: 'top'
                    },
                    tooltip: {
                        mode: 'index',
                        intersect: false,
                        callbacks: {
                            label: function(context) {
                                return context.dataset.label + ': ' + context.formattedValue;
                            }
                        }
                    }
                }
            }
        });

        // Configuration du graphique des notes moyennes par chambre
        const roomRatingsCtx = document.getElementById('roomRatingsChart').getContext('2d');
        new Chart(roomRatingsCtx, {
            type: 'bar',
            data: {
                labels: <?php echo json_encode(array_column($data['roomRatings'], 'numero_chambre')); ?>,
                datasets: [{
                    label: 'Note moyenne',
                    data: <?php echo json_encode(array_column($data['roomRatings'], 'moyenne')); ?>,
                    backgroundColor: Object.values(sectionColors),
                    borderColor: Object.values(sectionColors).map(color => color.replace('0.5)', '1)')),
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: false,
                        min: 1,
                        max: 5,
                        ticks: {
                            stepSize: 1
                        }
                    }
                },
                plugins: {
                    legend: {
                        display: false
                    },
                    tooltip: {
                        callbacks: {
                            title: function(tooltipItems) {
                                return 'Chambre ' + tooltipItems[0].label;
                            }
                        }
                    }
                }
            }
        });

        // Gestion du sélecteur de sections
        const sectionDropdown = document.getElementById('sectionDropdown');
        const subSectionSelector = document.getElementById('subSectionSelector');

        sectionDropdown.addEventListener('change', function() {
            const selectedSection = this.value;
            subSectionSelector.innerHTML = '';

            if (selectedSection) {
                structure[selectedSection].forEach(subSection => {
                    const label = document.createElement('label');
                    label.className = 'flex items-center space-x-2 p-2 hover:bg-gray-100 rounded transition duration-150 ease-in-out';
                    label.innerHTML = `
                        <input type="checkbox" value="${selectedSection}-${subSection}" class="form-checkbox h-5 w-5 text-indigo-600 transition duration-150 ease-in-out">
                        <span class="text-gray-700">${subSection}</span>
                    `;
                    label.querySelector('input').addEventListener('change', updateChart);
                    subSectionSelector.appendChild(label);
                });
            } else {
                Object.entries(structure).forEach(([section, subSections]) => {
                    subSections.forEach(subSection => {
                        const label = document.createElement('label');
                        label.className = 'flex items-center space-x-2 p-2 hover:bg-gray-100 rounded transition duration-150 ease-in-out';
                        label.innerHTML = `
                            <input type="checkbox" value="${section}-${subSection}" class="form-checkbox h-5 w-5 text-indigo-600 transition duration-150 ease-in-out">
                            <span class="text-gray-700">${section} - ${subSection}</span>
                        `;
                        label.querySelector('input').addEventListener('change', updateChart);
                        subSectionSelector.appendChild(label);
                    });
                });
            }
        });

        function updateChart() {
            const checkedSubSections = Array.from(document.querySelectorAll('#subSectionSelector input:checked'))
                .map(checkbox => checkbox.value);

            noteEvolutionChart.data.datasets = noteEvolutionChart.data.datasets.filter(dataset => 
                dataset.label === 'Note globale');

            checkedSubSections.forEach(subSection => {
                const [section, subSectionName] = subSection.split('-');
                const color = sectionColors[section] || getRandomColor();
                const subSectionData = <?php echo json_encode($data['noteEvolution']); ?>.map(item => {
                    return item.sections[section] && item.sections[section][subSectionName] ? item.sections[section][subSectionName] : null;
                });
                
                noteEvolutionChart.data.datasets.push({
                    label: `${section} - ${subSectionName}`,
                    data: subSectionData,
                    borderColor: color,
                    backgroundColor: color + '40',
                    fill: false,
                    tension: 0.1,
                    borderWidth: 2
                });
            });

            noteEvolutionChart.update();
        }

        // Initialiser l'affichage
        sectionDropdown.dispatchEvent(new Event('change'));
    });

    function showStarDetails(section, subsection, stars) {
        fetch(`get_star_details.php?section=${encodeURIComponent(section)}&sous_section=${encodeURIComponent(subsection)}&note=${stars}&start_date=<?php echo $start_date; ?>&end_date=<?php echo $end_date; ?>`)
            .then(response => response.json())
            .then(data => {
                const modal = document.getElementById('starDetailsModal');
                const title = document.getElementById('modalTitle');
                const content = document.getElementById('modalContent');
                
                title.textContent = `${section} - ${subsection} (${stars} étoile${stars > 1 ? 's' : ''})`;
                
                let tableHTML = `
                    <table class="min-w-full divide-y divide-gray-200">
                        <thead class="bg-gray-50">
                            <tr>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Client</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Chambre</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Date Séjour</th>
                                <th class="px-6 py-3 text-center text-xs font-medium text-gray-500 uppercase tracking-wider">Nbre nuits</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Commentaire</th>
                            </tr>
                        </thead>
                        <tbody>
                `;
                
                data.forEach(item => {
                    const dateArrivee = new Date(item.date_arrivee);
                    const dateDepart = new Date(item.date_depart);
                    const nbreNuits = Math.floor((dateDepart - dateArrivee) / (1000 * 60 * 60 * 24));
                    
                    tableHTML += `
                        <tr class="hover:bg-gray-50">
                            <td class="px-6 py-4 whitespace-nowrap">${item.prenom} ${item.nom}</td>
                            <td class="px-6 py-4">${item.numero_chambre}</td>
                            <td class="px-6 py-4">Du ${new Date(item.date_arrivee).toLocaleDateString('fr-FR')} au ${new Date(item.date_depart).toLocaleDateString('fr-FR')}</td>
                            <td class="px-6 py-4 text-center">${nbreNuits}</td>
                            <td class="px-6 py-4">${item.commentaire || '-'}</td>
                        </tr>
                    `;
                });
                
                tableHTML += `
                        </tbody>
                    </table>
                `;
                
                content.innerHTML = tableHTML;
                modal.classList.remove('hidden');
            })
            .catch(error => {
                console.error('Error:', error);
                alert('Une erreur est survenue lors du chargement des détails.');
            });
    }

    function closeStarDetailsModal() {
        document.getElementById('starDetailsModal').classList.add('hidden');
    }

    document.addEventListener('click', function(event) {
        const modal = document.getElementById('starDetailsModal');
        const modalContent = modal.querySelector('.relative');
        if (event.target === modal) {
            closeStarDetailsModal();
        }
    });
    </script>
</body>
</html>
                                                