<?php
session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';

// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("Location: ../admin.php");
    exit;
}

// Récupérer les paramètres de filtrage
$search = $_GET['search'] ?? '';
$start_date = $_GET['start_date'] ?? '';
$end_date = $_GET['end_date'] ?? '';
$room_number = $_GET['room_number'] ?? '';
$service = $_GET['service'] ?? '';
$min_rating = $_GET['min_rating'] ?? '';
$max_rating = $_GET['max_rating'] ?? '';

// Pagination
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$perPage = 50;
$offset = ($page - 1) * $perPage;

// Récupérer les sections du questionnaire
$stmt = $pdo->query("SELECT DISTINCT section FROM structure_questionnaire ORDER BY ordre");
$sections = $stmt->fetchAll(PDO::FETCH_COLUMN);

// Construire la partie dynamique de la requête SQL pour les notes par section
$sectionCases = [];
foreach ($sections as $section) {
    $sectionSafe = $pdo->quote($section);
    $sectionId = sanitizeForId($section);
    $sectionCases[] = "AVG(CASE WHEN n.section = $sectionSafe THEN n.note END) as note_$sectionId";
}
$sectionCasesSQL = implode(", ", $sectionCases);

// Construire la requête SQL avec les filtres
$query = "
    SELECT 
        q.id,
        c.prenom,
        c.nom,
        c.email,
        q.date_soumission,
        c.numero_chambre,
        q.lu,
        AVG(CASE WHEN n.note IS NOT NULL THEN n.note END) as note_moyenne,
        $sectionCasesSQL,
        GROUP_CONCAT(DISTINCT CONCAT(n.section, ':', n.sous_section, ':', COALESCE(n.note, 'N/A')) ORDER BY n.section, n.sous_section SEPARATOR '|') as sous_sections_notes,
        GROUP_CONCAT(DISTINCT CONCAT(cs.section, ':', cs.commentaire) SEPARATOR '||') as commentaires
    FROM 
        questionnaires q
    LEFT JOIN 
        clients c ON q.client_id = c.id
    LEFT JOIN 
        notes_sous_sections n ON q.id = n.questionnaire_id
    LEFT JOIN
        commentaires_sections cs ON q.id = cs.questionnaire_id
    WHERE 1=1
";

$countQuery = "SELECT COUNT(DISTINCT q.id) FROM questionnaires q LEFT JOIN clients c ON q.client_id = c.id WHERE 1=1";

$params = [];

if ($search) {
    $searchCondition = "(c.prenom LIKE ? OR c.nom LIKE ? OR c.numero_chambre LIKE ?)";
    $query .= " AND $searchCondition";
    $countQuery .= " AND $searchCondition";
    $params = array_merge($params, ["%$search%", "%$search%", "%$search%"]);
}

if ($start_date) {
    $query .= " AND q.date_soumission >= ?";
    $countQuery .= " AND q.date_soumission >= ?";
    $params[] = $start_date;
}

if ($end_date) {
    $query .= " AND q.date_soumission <= ?";
    $countQuery .= " AND q.date_soumission <= ?";
    $params[] = $end_date;
}

if ($room_number) {
    $query .= " AND c.numero_chambre = ?";
    $countQuery .= " AND c.numero_chambre = ?";
    $params[] = $room_number;
}

if ($service) {
    $query .= " AND n.section = ?";
    $countQuery .= " AND EXISTS (SELECT 1 FROM notes_sous_sections n WHERE n.questionnaire_id = q.id AND n.section = ?)";
    $params[] = $service;
}

$query .= "
    GROUP BY 
        q.id, c.prenom, c.nom, c.email, q.date_soumission, c.numero_chambre, q.lu
    HAVING 1=1
";

if ($min_rating) {
    $query .= " AND AVG(CASE WHEN n.note IS NOT NULL THEN n.note END) >= ?";
    $params[] = $min_rating;
}

if ($max_rating) {
    $query .= " AND AVG(CASE WHEN n.note IS NOT NULL THEN n.note END) <= ?";
    $params[] = $max_rating;
}

// Compter le nombre total de résultats
$stmtCount = $pdo->prepare($countQuery);
$stmtCount->execute($params);
$totalResults = $stmtCount->fetchColumn();

// Calculer le nombre total de pages
$totalPages = ceil($totalResults / $perPage);

// Ajouter la limitation pour la pagination
$query .= "
    ORDER BY 
        q.date_soumission DESC
    LIMIT $offset, $perPage
";

$stmt = $pdo->prepare($query);
$stmt->execute($params);
$recent_questionnaires = $stmt->fetchAll(PDO::FETCH_ASSOC);

?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Tableau de bord - Admin</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="../css/styles.css" rel="stylesheet">
    <link href="../css/dashboard_styles.css" rel="stylesheet">
    <script src="https://unpkg.com/@popperjs/core@2"></script>
    <script src="https://unpkg.com/tippy.js@6"></script>
    <script src="https://cdn.jsdelivr.net/npm/alpinejs@3.x.x/dist/cdn.min.js" defer></script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css">
    <style>
        .table-container {
            max-height: calc(100vh - 200px);
            overflow-y: auto;
        }
        .sticky-header th {
            position: sticky;
            top: 0;
            background-color: #f3f4f6;
            z-index: 10;
        }
        .comment-icon {
            display: inline-block;
            width: 18px;
            height: 18px;
            background-color: #4a5568;
            mask-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 24 24' stroke='currentColor'%3E%3Cpath stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='M7 8h10M7 12h4m1 8l-4-4H5a2 2 0 01-2-2V6a2 2 0 012-2h14a2 2 0 012 2v8a2 2 0 01-2 2h-3l-4 4z' /%3E%3C/svg%3E");
            mask-repeat: no-repeat;
            mask-position: center;
            transition: background-color 0.3s ease;
        }
        .comment-icon:hover {
            background-color: #2d3748;
        }
    </style>
</head>
<body class="bg-gray-100 font-sans">
    <div class="flex">
        <?php include 'sidebar.php'; ?>

        <div id="main-content" class="flex-1 p-10">
            <h1 class="text-3xl font-bold mb-6">Tableau de bord</h1>
            
            <!-- Formulaire de filtrage amélioré -->
            <div x-data="{ showFilters: false }" class="bg-white p-4 rounded-lg shadow-md mb-6">
                <div class="flex justify-between items-center mb-4">
                    <div class="flex-1 mr-4">
                        <input type="text" id="search" name="search" placeholder="Rechercher..." value="<?php echo htmlspecialchars($search); ?>" class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500">
                    </div>
                    <button @click="showFilters = !showFilters" class="bg-blue-500 text-white px-4 py-2 rounded-md hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2">
                        <span x-text="showFilters ? 'Masquer les filtres' : 'Afficher les filtres'"></span>
                    </button>
                </div>
                
                <div x-show="showFilters" x-transition:enter="transition ease-out duration-300"
                     x-transition:enter-start="opacity-0 transform scale-95"
                     x-transition:enter-end="opacity-100 transform scale-100"
                     x-transition:leave="transition ease-in duration-200"
                     x-transition:leave-start="opacity-100 transform scale-100"
                     x-transition:leave-end="opacity-0 transform scale-95">
                    <form class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                        <input type="hidden" name="page" value="1">
                        <div>
                            <label for="start_date" class="block text-sm font-medium text-gray-700">Date de début</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo htmlspecialchars($start_date); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-300 focus:ring focus:ring-blue-200 focus:ring-opacity-50">
                        </div>
                        <div>
                            <label for="end_date" class="block text-sm font-medium text-gray-700">Date de fin</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo htmlspecialchars($end_date); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-300 focus:ring focus:ring-blue-200 focus:ring-opacity-50">
                        </div>
                        <div>
                            <label for="room_number" class="block text-sm font-medium text-gray-700">Numéro de chambre</label>
                            <input type="text" id="room_number" name="room_number" value="<?php echo htmlspecialchars($room_number); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-300 focus:ring focus:ring-blue-200 focus:ring-opacity-50">
                        </div>
                        <div>
                            <label for="service" class="block text-sm font-medium text-gray-700">Service</label>
                            <select id="service" name="service" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-300 focus:ring focus:ring-blue-200 focus:ring-opacity-50">
                                <option value="">Tous les services</option>
                                <?php foreach ($sections as $section): ?>
                                    <option value="<?php echo htmlspecialchars($section); ?>" <?php echo $service === $section ? 'selected' : ''; ?>><?php echo htmlspecialchars($section); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div>
                            <label for="min_rating" class="block text-sm font-medium text-gray-700">Note minimum</label>
                            <input type="number" id="min_rating" name="min_rating" min="0" max="5" step="0.1" value="<?php echo htmlspecialchars($min_rating); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-300 focus:ring focus:ring-blue-200 focus:ring-opacity-50">
                        </div>
                        <div>
                            <label for="max_rating" class="block text-sm font-medium text-gray-700">Note maximum</label>
                            <input type="number" id="max_rating" name="max_rating" min="0" max="5" step="0.1" value="<?php echo htmlspecialchars($max_rating); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-300 focus:ring focus:ring-blue-200 focus:ring-opacity-50">
                        </div>
                        <div class="md:col-span-2 lg:col-span-3">
                            <button type="submit" class="w-full bg-blue-500 text-white px-4 py-2 rounded-md hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2">
                                Appliquer les filtres
                            </button>
                        </div>
                    </form>
                </div>
            </div>
            <div class="result-count"></div>
            <div class="bg-white p-6 rounded-lg shadow-md overflow-x-auto">
                <div class="flex justify-between items-center mb-4">
                    <h2 class="text-xl font-semibold">Questionnaires</h2>
                    <div class="flex items-center space-x-4">
                        <span id="unread-count" class="font-semibold"></span>
                        <button id="toggle-unread" class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded">
                            Afficher non lus
                        </button>
                    </div>
                </div>
                <div class="table-container">
                <table class="min-w-full leading-normal" id="questionnaires-table">
                        <thead class="sticky-header">
                            <tr>
                                <th class="px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-left text-xs font-semibold text-gray-600 uppercase tracking-wider">
                                    Client
                                </th>
                                <th class="px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-left text-xs font-semibold text-gray-600 uppercase tracking-wider">
                                    N° Chambre
                                </th>
                                <?php foreach ($sections as $section): ?>
                                    <th class="px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-left text-xs font-semibold text-gray-600 uppercase tracking-wider">
                                        <?php echo htmlspecialchars($section); ?>
                                    </th>
                                <?php endforeach; ?>
                                <th class="px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-left text-xs font-semibold text-gray-600 uppercase tracking-wider">
                                    Note moyenne
                                </th>
                                <th class="px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-left text-xs font-semibold text-gray-600 uppercase tracking-wider">
                                    Actions
                                </th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($recent_questionnaires as $questionnaire): ?>
                                <tr data-id="<?php echo $questionnaire['id']; ?>" 
    data-read="<?php echo $questionnaire['lu'] ? 'true' : 'false'; ?>"
    data-search="<?php echo strtolower(htmlspecialchars($questionnaire['prenom'] . ' ' . $questionnaire['nom'] . ' ' . $questionnaire['numero_chambre'] . ' ' . $questionnaire['id'])); ?>"
    class="<?php echo $questionnaire['lu'] ? 'read-row' : 'unread-row'; ?> hover:bg-gray-100 transition-colors duration-200 cursor-pointer"
    style="background-color: <?php echo $questionnaire['lu'] ? '#FFFFFF' : '#EBF8FF'; ?>;">
                                    <td class="px-5 py-5 border-b border-gray-200 text-sm">
                                        <div class="flex flex-col">
                                            <span class="font-semibold">
                                                <?php 
                                                if (empty($questionnaire['prenom']) && empty($questionnaire['nom'])) {
                                                    echo '<span class="text-red-500 font-semibold">Non renseigné</span>';
                                                } else {
                                                    echo htmlspecialchars($questionnaire['prenom'] . ' ' . $questionnaire['nom']);
                                                }
                                                ?>
                                            </span>
                                            <span class="text-gray-500 text-xs">
                                                <?php echo date('d/m/Y H:i', strtotime($questionnaire['date_soumission'])); ?>
                                            </span>
                                        </div>
                                    </td>
                                    <td class="px-5 py-5 border-b border-gray-200 text-sm">
                                        <?php echo !empty($questionnaire['numero_chambre']) ? '#' . htmlspecialchars($questionnaire['numero_chambre']) : 'N/A'; ?>
                                    </td>
                                    <?php foreach ($sections as $section): 
                                        $note_key = 'note_' . sanitizeForId($section);
                                        $note = $questionnaire[$note_key] !== null ? number_format($questionnaire[$note_key], 2) : 'N/A';
                                        $class = '';
                                        $sous_sections_notes = explode('|', $questionnaire['sous_sections_notes']);
                                        $commentaires = explode('||', $questionnaire['commentaires']);
                                        $section_comment = '';
                                        foreach ($commentaires as $comment) {
                                            list($comment_section, $comment_text) = explode(':', $comment, 2);
                                            if ($comment_section === $section) {
                                                $section_comment = $comment_text;
                                                break;
                                            }
                                        }
                                        $tooltip_content = "<div class='p-2'><strong>$section</strong><ul class='list-disc pl-4'>";
                                        $has_low_rating = false;
                                        $sous_sections_added = [];
                                        foreach ($sous_sections_notes as $ssn) {
                                            list($ssn_section, $sous_section, $ss_note) = explode(':', $ssn);
                                            if ($ssn_section === $section && !in_array($sous_section, $sous_sections_added)) {
                                                $ss_class = ($ss_note !== 'N/A' && floatval($ss_note) <= 2) ? 'text-red-500' : '';
                                                $tooltip_content .= "<li class='$ss_class'>$sous_section: $ss_note</li>";
                                                $sous_sections_added[] = $sous_section;
                                                if ($ss_note !== 'N/A' && floatval($ss_note) <= 2) $has_low_rating = true;
                                            }
                                        }
                                        $tooltip_content .= "</ul>";
                                        if ($section_comment) {
                                            $tooltip_content .= "<p class='mt-2'><strong>Commentaire:</strong> " . htmlspecialchars($section_comment) . "</p>";
                                        }
                                        $tooltip_content .= "</div>";
                                        if ($has_low_rating) $class = 'text-red-500';
                                    ?>
                                    <td class="px-5 py-5 border-b border-gray-200 text-sm">
                                        <span class="<?php echo $class; ?>" data-tippy-content="<?php echo htmlspecialchars($tooltip_content); ?>">
                                            <?php echo $note; ?>
                                            <?php if ($section_comment): ?>
                                                <span class="comment-icon ml-1" title="Commentaire présent"></span>
                                            <?php endif; ?>
                                        </span>
                                    </td>
                                    <?php endforeach; ?>
                                    <td class="px-5 py-5 border-b border-gray-200 text-sm font-bold">
                                        <?php echo $questionnaire['note_moyenne'] !== null ? number_format($questionnaire['note_moyenne'], 2) : 'N/A'; ?>
                                    </td>
                                    <td class="px-5 py-5 border-b border-gray-200 text-sm">
                                        <button onclick="editQuestionnaire(<?php echo $questionnaire['id']; ?>)" title="Éditer" class="text-blue-600 hover:text-blue-900 mr-2">
                                            <svg xmlns="http://www.w3.org/2000/svg" class="h-5 w-5 inline-block" viewBox="0 0 20 20" fill="currentColor">
                                                <path d="M13.586 3.586a2 2 0 112.828 2.828l-.793.793-2.828-2.828.793-.793zM11.379 5.793L3 14.172V17h2.828l8.38-8.379-2.83-2.828z" />
                                            </svg>
                                        </button>
                                        <button onclick="sendEmail(<?php echo $questionnaire['id']; ?>)" title="Envoyer un email" class="text-green-600 hover:text-green-900 mr-2">
                                            <svg xmlns="http://www.w3.org/2000/svg" class="h-5 w-5 inline-block" viewBox="0 0 20 20" fill="currentColor">
                                                <path d="M2.003 5.884L10 9.882l7.997-3.998A2 2 0 0016 4H4a2 2 0 00-1.997 1.884z" />
                                                <path d="M18 8.118l-8 4-8-4V14a2 2 0 002 2h12a2 2 0 002-2V8.118z" />
                                            </svg>
                                        </button>
                                        <?php if ($_SESSION['is_superadmin']): ?>
                                            <button onclick="deleteClient(<?php echo $questionnaire['id']; ?>)" title="Supprimer" class="text-red-600 hover:text-red-900 mr-2">
                                                <svg xmlns="http://www.w3.org/2000/svg" class="h-5 w-5 inline-block" viewBox="0 0 20 20" fill="currentColor">
                                                    <path fill-rule="evenodd" d="M9 2a1 1 0 00-.894.553L7.382 4H4a1 1 0 000 2v10a2 2 0 002 2h8a2 2 0 002-2V6a1 1 0 100-2h-3.382l-.724-1.447A1 1 0 0011 2H9zM7 8a1 1 0 012 0v6a1 1 0 11-2 0V8zm5-1a1 1 0 00-1 1v6a1 1 0 102 0V8a1 1 0 00-1-1z" clip-rule="evenodd" />
                                                </svg>
                                            </button>
                                        <?php endif; ?>
                                        <button onclick="downloadClientPDF(<?php echo $questionnaire['id']; ?>)" title="Télécharger PDF" class="text-blue-600 hover:text-blue-900">
                                            <svg class="w-5 h-5 inline-block" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                                                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 10v6m0 0l-3-3m3 3l3-3m2 8H7a2 2 0 01-2-2V5a2 2 0 012-2h5.586a1 1 0 01.707.293l5.414 5.414a1 1 0 01.293.707V19a2 2 0 01-2 2z"></path>
                                            </svg>
                                        </button>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>

                <!-- Pagination -->
                <div class="mt-6">
                    <nav class="flex items-center justify-between">
                        <div class="flex-1 flex justify-between sm:hidden">
                            <?php if ($page > 1): ?>
                                <a href="?<?php echo http_build_query(array_merge($_GET, ['page' => $page - 1])); ?>" class="relative inline-flex items-center px-4 py-2 border border-gray-300 text-sm font-medium rounded-md text-gray-700 bg-white hover:bg-gray-50">
                                    Précédent
                                </a>
                            <?php endif; ?>
                            <?php if ($page < $totalPages): ?>
                                <a href="?<?php echo http_build_query(array_merge($_GET, ['page' => $page + 1])); ?>" class="ml-3 relative inline-flex items-center px-4 py-2 border border-gray-300 text-sm font-medium rounded-md text-gray-700 bg-white hover:bg-gray-50">
                                    Suivant
                                </a>
                            <?php endif; ?>
                        </div>
                        <div class="hidden sm:flex-1 sm:flex sm:items-center sm:justify-between">
                            <div>
                                <p class="text-sm text-gray-700">
                                    Affichage de <span class="font-medium"><?php echo $offset + 1; ?></span> à <span class="font-medium"><?php echo min($offset + $perPage, $totalResults); ?></span> sur <span class="font-medium"><?php echo $totalResults; ?></span> résultats
                                </p>
                            </div>
                            <div>
                                <nav class="relative z-0 inline-flex rounded-md shadow-sm -space-x-px" aria-label="Pagination">
                                    <?php if ($page > 1): ?>
                                        <a href="?<?php echo http_build_query(array_merge($_GET, ['page' => $page - 1])); ?>" class="relative inline-flex items-center px-2 py-2 rounded-l-md border border-gray-300 bg-white text-sm font-medium text-gray-500 hover:bg-gray-50">
                                            <span class="sr-only">Précédent</span>
                                            <svg class="h-5 w-5" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor" aria-hidden="true">
                                                <path fill-rule="evenodd" d="M12.707 5.293a1 1 0 010 1.414L9.414 10l3.293 3.293a1 1 0 01-1.414 1.414l-4-4a1 1 0 010-1.414l4-4a1 1 0 011.414 0z" clip-rule="evenodd" />
                                            </svg>
                                        </a>
                                    <?php endif; ?>
                                    
                                    <?php
                                    $start = max(1, $page - 2);
                                    $end = min($totalPages, $page + 2);
                                    for ($i = $start; $i <= $end; $i++):
                                    ?>
                                        <a href="?<?php echo http_build_query(array_merge($_GET, ['page' => $i])); ?>" class="relative inline-flex items-center px-4 py-2 border border-gray-300 bg-white text-sm font-medium text-gray-700 hover:bg-gray-50 <?php echo $i === $page ? 'z-10 bg-blue-50 border-blue-500 text-blue-600' : ''; ?>">
                                            <?php echo $i; ?>
                                        </a>
                                    <?php endfor; ?>

                                    <?php if ($page < $totalPages): ?>
                                        <a href="?<?php echo http_build_query(array_merge($_GET, ['page' => $page + 1])); ?>" class="relative inline-flex items-center px-2 py-2 rounded-r-md border border-gray-300 bg-white text-sm font-medium text-gray-500 hover:bg-gray-50">
                                            <span class="sr-only">Suivant</span>
                                            <svg class="h-5 w-5" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor" aria-hidden="true">
                                                <path fill-rule="evenodd" d="M7.293 14.707a1 1 0 010-1.414L10.586 10 7.293 6.707a1 1 0 011.414-1.414l4 4a1 1 0 010 1.414l-4 4a1 1 0 01-1.414 0z" clip-rule="evenodd" />
                                            </svg>
                                        </a>
                                    <?php endif; ?>
                                </nav>
                            </div>
                        </div>
                    </nav>
                </div>
            </div>
        </div>
    </div>
    
    <script>
    // Inclusion des données pour la recherche JavaScript
    var allQuestionnaires = <?php echo json_encode($allQuestionnaires); ?>;
    </script>

    <script src="../js/admin.js"></script>
    
    <script>
document.addEventListener('DOMContentLoaded', function() {
    const searchInput = document.getElementById('search');
    const table = document.getElementById('questionnaires-table');
    const tbody = table.querySelector('tbody');
    const rows = tbody.querySelectorAll('tr');
    const paginationContainer = document.querySelector('.pagination-container'); // Ajustez le sélecteur si nécessaire
    
    console.log('Nombre de lignes trouvées:', rows.length);

    searchInput.addEventListener('input', function() {
        const searchTerm = this.value.toLowerCase();
        let visibleCount = 0;
        
        rows.forEach(row => {
            const text = row.textContent.toLowerCase();
            const isVisible = text.includes(searchTerm);
            row.style.display = isVisible ? '' : 'none';
            if (isVisible) visibleCount++;
        });

        // Mettre à jour l'affichage du nombre de résultats
        updateResultCount(visibleCount);

        // Cacher la pagination si une recherche est en cours, sinon l'afficher
        if (searchTerm) {
            if (paginationContainer) paginationContainer.style.display = 'none';
        } else {
            if (paginationContainer) paginationContainer.style.display = '';
            resetPagination();
        }
    });

    function updateResultCount(count) {
        const countDisplay = document.querySelector('.result-count'); // Ajoutez cet élément à votre HTML
        if (countDisplay) {
            countDisplay.textContent = `Affichage de ${count} résultat(s)`;
        }
    }

    function resetPagination() {
        // Réinitialiser la pagination à la première page
        // Vous devrez ajuster ceci en fonction de votre implémentation de pagination
    }

    // Les fonctions existantes restent inchangées
    window.editQuestionnaire = function(id) {
        window.location.href = `edit_questionnaire.php?id=${id}`;
    }

    window.sendEmail = function(id) {
        window.location.href = `send_email.php?id=${id}`;
    }

    window.deleteClient = function(id) {
        if (confirm('Êtes-vous sûr de vouloir supprimer ce client et son questionnaire ?')) {
            fetch('delete_client.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                body: `id=${id}`
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    alert('Client supprimé avec succès');
                    location.reload();
                } else {
                    alert('Erreur lors de la suppression du client : ' + data.message);
                }
            })
            .catch(error => {
                console.error('Error:', error);
                alert('Une erreur est survenue lors de la suppression du client');
            });
        }
    }

    window.downloadClientPDF = function(id) {
        window.open(`generate_client_pdf.php?id=${id}`, '_blank');
    }
});
</script>
</body>
</html>