<?php
session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';


// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("Location: ../admin.php");
    exit;
}

$message = '';

// Traitement du formulaire d'ajout ou de modification
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'add':
                $description = $_POST['description'] ?? '';
                $date = $_POST['date'] ?? '';
                $section = $_POST['section'] ?? '';
                $sous_section = $_POST['sous_section'] ?? '';
                $numero_chambre = $_POST['numero_chambre'] ?? '';

                if (empty($description) || empty($date) || empty($section)) {
                    $message = "Veuillez remplir tous les champs obligatoires.";
                } else {
                    if (addDateCle($pdo, $description, $date, $section, $sous_section, $numero_chambre)) {
                        $message = "Date clé ajoutée avec succès.";
                    } else {
                        $message = "Erreur lors de l'ajout de la date clé.";
                    }
                }
                break;

            case 'edit':
                if ($_SESSION['is_superadmin']) {
                    $id = $_POST['id'] ?? '';
                    $description = $_POST['description'] ?? '';
                    $date = $_POST['date'] ?? '';
                    $section = $_POST['section'] ?? '';
                    $sous_section = $_POST['sous_section'] ?? '';
                    $numero_chambre = $_POST['numero_chambre'] ?? '';

                    if (empty($id) || empty($description) || empty($date) || empty($section)) {
                        $message = "Veuillez remplir tous les champs obligatoires.";
                    } else {
                        if (updateDateCle($pdo, $id, $description, $date, $section, $sous_section, $numero_chambre)) {
                            $message = "Date clé modifiée avec succès.";
                        } else {
                            $message = "Erreur lors de la modification de la date clé.";
                        }
                    }
                } else {
                    $message = "Vous n'avez pas les droits pour effectuer cette action.";
                }
                break;

            case 'delete':
                if ($_SESSION['is_superadmin']) {
                    $id = $_POST['id'] ?? '';
                    if (empty($id)) {
                        $message = "ID de la date clé manquant.";
                    } else {
                        if (deleteDateCle($pdo, $id)) {
                            $message = "Date clé supprimée avec succès.";
                        } else {
                            $message = "Erreur lors de la suppression de la date clé.";
                        }
                    }
                } else {
                    $message = "Vous n'avez pas les droits pour effectuer cette action.";
                }
                break;
        }
    }
}

// Récupérer les dates clés existantes
$dates_cles = getDatesCles($pdo);

// Récupérer la structure du questionnaire pour les sections et sous-sections
$structure = getQuestionnaireStructure($pdo);

?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dates clés - Admin</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/@fortawesome/fontawesome-free@5.15.4/css/all.min.css" rel="stylesheet">
    <link href="../css/styles.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/gh/alpinejs/alpine@v2.x.x/dist/alpine.min.js" defer></script>
    <style>
        .date-card {
            transition: all 0.3s ease;
        }
        .date-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
        }
    </style>
</head>
<body class="bg-gray-100 font-sans" x-data="{ editingId: null, showForm: false }">
    <div class="flex">
        <?php include 'sidebar.php'; ?>
        <div id="main-content" class="flex-1 p-10">
            <h1 class="text-4xl font-bold mb-8 text-gray-800">Dates clés</h1>
            
            <?php if ($message): ?>
                <div class="bg-blue-100 border-l-4 border-blue-500 text-blue-700 p-4 mb-6 rounded" role="alert">
                    <p><?php echo htmlspecialchars($message); ?></p>
                </div>
            <?php endif; ?>
            
            <button @click="showForm = !showForm" class="mb-6 bg-indigo-600 hover:bg-indigo-700 text-white font-bold py-2 px-4 rounded transition duration-300 ease-in-out transform hover:-translate-y-1 hover:scale-110">
                <i class="fas fa-plus mr-2"></i> Ajouter une nouvelle date clé
            </button>

            <div x-show="showForm" x-cloak class="bg-white shadow-lg rounded-lg p-8 mb-8">
    <h2 class="text-2xl font-semibold mb-6 text-gray-800">Nouvelle date clé</h2>
    <form method="POST" class="space-y-6">
        <input type="hidden" name="action" value="add">
        <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
            <div class="col-span-1 md:col-span-2">
                <label for="description" class="block text-sm font-medium text-gray-700 mb-1">Description:</label>
                <input type="text" id="description" name="description" class="w-full px-4 py-2 border border-gray-300 rounded-md shadow-sm focus:ring-indigo-500 focus:border-indigo-500" required>
            </div>
            <div>
                <label for="date" class="block text-sm font-medium text-gray-700 mb-1">Date:</label>
                <input type="date" id="date" name="date" class="w-full px-4 py-2 border border-gray-300 rounded-md shadow-sm focus:ring-indigo-500 focus:border-indigo-500" required>
            </div>
            <div>
                <label for="section" class="block text-sm font-medium text-gray-700 mb-1">Section:</label>
                <select id="section" name="section" class="w-full px-4 py-2 border border-gray-300 rounded-md shadow-sm focus:ring-indigo-500 focus:border-indigo-500" required>
                    <option value="">Sélectionnez une section</option>
                    <?php foreach (array_keys($structure) as $section): ?>
                        <option value="<?php echo htmlspecialchars($section); ?>"><?php echo htmlspecialchars($section); ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div>
                <label for="sous_section" class="block text-sm font-medium text-gray-700 mb-1">Sous-section:</label>
                <select id="sous_section" name="sous_section" class="w-full px-4 py-2 border border-gray-300 rounded-md shadow-sm focus:ring-indigo-500 focus:border-indigo-500">
                    <option value="">Sélectionnez une sous-section</option>
                </select>
            </div>
            <div>
                <label for="numero_chambre" class="block text-sm font-medium text-gray-700 mb-1">Numéro de chambre:</label>
                <input type="text" id="numero_chambre" name="numero_chambre" class="w-full px-4 py-2 border border-gray-300 rounded-md shadow-sm focus:ring-indigo-500 focus:border-indigo-500">
            </div>
        </div>
        <div class="flex justify-end mt-6">
            <button type="submit" class="inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md shadow-sm text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                <svg class="w-5 h-5 mr-2 -ml-1" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 6v6m0 0v6m0-6h6m-6 0H6"></path>
                </svg>
                Ajouter
            </button>
        </div>
    </form>
</div>

            <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
                <?php foreach ($dates_cles as $date_cle): ?>
                    <div class="date-card bg-white rounded-lg shadow-md overflow-hidden">
                        <div class="p-6">
                        <div class="flex justify-between items-start mb-2">
    <h3 class="text-xl font-semibold text-gray-800"><?php echo htmlspecialchars($date_cle['description']); ?></h3>
    <?php if ($_SESSION['is_superadmin']): ?>
        <div class="flex space-x-2">
            <button @click="editingId = <?php echo $date_cle['id']; ?>" class="text-indigo-600 hover:text-indigo-800">
                <i class="fas fa-edit"></i>
            </button>
            <form method="POST" class="inline" onsubmit="return confirm('Êtes-vous sûr de vouloir supprimer cette date clé ?');">
                <input type="hidden" name="action" value="delete">
                <input type="hidden" name="id" value="<?php echo $date_cle['id']; ?>">
                <button type="submit" class="text-red-600 hover:text-red-800">
                    <i class="fas fa-trash"></i>
                </button>
            </form>
        </div>
    <?php endif; ?>
</div>
                            <p class="text-sm font-medium text-gray-500 mb-4"><?php echo htmlspecialchars($date_cle['date']); ?></p>
                            <div class="mb-4">
                                <p class="text-sm text-gray-600"><strong>Section:</strong> <?php echo htmlspecialchars($date_cle['section']); ?></p>
                                <?php if ($date_cle['sous_section']): ?>
                                    <p class="text-sm text-gray-600"><strong>Sous-section:</strong> <?php echo htmlspecialchars($date_cle['sous_section']); ?></p>
                                <?php endif; ?>
                                <?php if ($date_cle['numero_chambre']): ?>
                                    <p class="text-sm text-gray-600"><strong>Chambre:</strong> <?php echo htmlspecialchars($date_cle['numero_chambre']); ?></p>
                                <?php endif; ?>
                            </div>
                            <?php
                            $stats = getBeforeAfterData($pdo, $date_cle['id']);
                            if (!$stats['insufficient_data']): ?>
                                <div class="bg-gray-100 p-4 rounded-lg">
                                    <div class="flex justify-between mb-2">
                                        <span class="text-sm font-medium text-gray-700">Avant</span>
                                        <span class="text-sm font-medium text-gray-700">Après</span>
                                    </div>
                                    <div class="flex justify-between items-center">
                                        <span class="text-2xl font-bold text-gray-800"><?php echo number_format($stats['before'], 2); ?></span>
                                        <div class="flex items-center">
                                            <span class="text-2xl font-bold <?php echo $stats['difference'] >= 0 ? 'text-green-500' : 'text-red-500'; ?>">
                                                <?php echo $stats['difference'] >= 0 ? '+' : ''; ?><?php echo number_format($stats['difference'], 2); ?>
                                            </span>
                                            <i class="fas fa-arrow-<?php echo $stats['difference'] >= 0 ? 'up text-green-500' : 'down text-red-500'; ?> ml-2"></i>
                                        </div>
                                        <span class="text-2xl font-bold text-gray-800"><?php echo number_format($stats['after'], 2); ?></span>
                                    </div>
                                    <div class="flex justify-between mt-2 text-xs text-gray-500">
                                        <span><?php echo $stats['before_count']; ?> avis</span>
                                        <span><?php echo $stats['after_count']; ?> avis</span>
                                    </div>
                                </div>
                            <?php else: ?>
                                <p class="text-sm text-gray-500 italic">Pas de données suffisantes</p>
                            <?php endif; ?>
                        </div>
                    </div>
                    <?php if ($_SESSION['is_superadmin']): ?>
                        <div x-show="editingId === <?php echo $date_cle['id']; ?>" x-cloak class="fixed inset-0 bg-gray-600 bg-opacity-50 overflow-y-auto h-full w-full" id="modal">
                            <div class="relative top-20 mx-auto p-5 border w-11/12 md:w-3/4 lg:w-1/2 shadow-lg rounded-md bg-white">
                                <div class="flex justify-between items-center pb-3">
                                    <h3 class="text-2xl font-semibold text-gray-800">Modifier la date clé</h3>
                                    <button @click="editingId = null" class="text-gray-600 hover:text-gray-800">
                                        <i class="fas fa-times"></i>
                                    </button>
                                </div>
                                <form method="POST" class="space-y-4">
                                            <input type="hidden" name="action" value="edit">
                                            <input type="hidden" name="id" value="<?php echo $date_cle['id']; ?>">
                                            <div class="flex space-x-4">
                                                <div class="w-4/5">
                                                    <label for="edit_description_<?php echo $date_cle['id']; ?>" class="block text-sm font-medium text-gray-700">Description:</label>
                                                    <input type="text" id="edit_description_<?php echo $date_cle['id']; ?>" name="description" value="<?php echo htmlspecialchars($date_cle['description']); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-12" required>
                                                </div>
                                                <div class="w-1/5">
                                                    <label for="edit_date_<?php echo $date_cle['id']; ?>" class="block text-sm font-medium text-gray-700">Date:</label>
                                                    <input type="date" id="edit_date_<?php echo $date_cle['id']; ?>" name="date" value="<?php echo $date_cle['date']; ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-12" required>
                                                </div>
                                            </div>
                                            <div class="flex space-x-4">
                                                <div class="w-2/5">
                                                    <label for="edit_section_<?php echo $date_cle['id']; ?>" class="block text-sm font-medium text-gray-700">Section:</label>
                                                    <select id="edit_section_<?php echo $date_cle['id']; ?>" name="section" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-12" required>
                                                        <?php foreach (array_keys($structure) as $section): ?>
                                                            <option value="<?php echo htmlspecialchars($section); ?>" <?php echo $section === $date_cle['section'] ? 'selected' : ''; ?>><?php echo htmlspecialchars($section); ?></option>
                                                        <?php endforeach; ?>
                                                    </select>
                                                </div>
                                                <div class="w-2/5">
                                                    <label for="edit_sous_section_<?php echo $date_cle['id']; ?>" class="block text-sm font-medium text-gray-700">Sous-section:</label>
                                                    <select id="edit_sous_section_<?php echo $date_cle['id']; ?>" name="sous_section" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-12">
                                                        <option value="">Sélectionnez une sous-section</option>
                                                        <?php if (isset($structure[$date_cle['section']])): ?>
                                                            <?php foreach ($structure[$date_cle['section']] as $sous_section): ?>
                                                                <option value="<?php echo htmlspecialchars($sous_section); ?>" <?php echo $sous_section === $date_cle['sous_section'] ? 'selected' : ''; ?>><?php echo htmlspecialchars($sous_section); ?></option>
                                                            <?php endforeach; ?>
                                                        <?php endif; ?>
                                                    </select>
                                                </div>
                                                <div class="w-1/5">
                                                    <label for="edit_numero_chambre_<?php echo $date_cle['id']; ?>" class="block text-sm font-medium text-gray-700">Numéro de chambre:</label>
                                                    <input type="text" id="edit_numero_chambre_<?php echo $date_cle['id']; ?>" name="numero_chambre" value="<?php echo htmlspecialchars($date_cle['numero_chambre']); ?>" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-12">
                                                </div>
                                            </div>
                                            <div class="pt-4">
                                                <button type="submit" class="inline-flex justify-center py-2 px-4 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-blue-600 hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                                                    <i class="fas fa-save mr-2"></i> Enregistrer les modifications
                                                </button>
                                                <button type="button" @click="editingId = null" class="ml-2 inline-flex justify-center py-2 px-4 border border-gray-300 shadow-sm text-sm font-medium rounded-md text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                                    Annuler
                                                </button>
                                            </div>
                                            </form>
                            </div>
                        </div>
                    <?php endif; ?>
                <?php endforeach; ?>
            </div>
        </div>
    </div>

    <script>
    document.addEventListener('DOMContentLoaded', function() {
        const structure = <?php echo json_encode($structure); ?>;

        function updateSousSection(sectionSelect, sousSectionSelect) {
            const selectedSection = sectionSelect.value;
            sousSectionSelect.innerHTML = '<option value="">Sélectionnez une sous-section</option>';
            
            if (selectedSection && structure[selectedSection]) {
                structure[selectedSection].forEach(sousSection => {
                    const option = document.createElement('option');
                    option.value = sousSection;
                    option.textContent = sousSection;
                    sousSectionSelect.appendChild(option);
                });
            }
        }

        // Pour le formulaire d'ajout
        const addSectionSelect = document.getElementById('section');
        const addSousSectionSelect = document.getElementById('sous_section');
        addSectionSelect.addEventListener('change', () => updateSousSection(addSectionSelect, addSousSectionSelect));

        // Pour les formulaires de modification
        const editSectionSelects = document.querySelectorAll('select[id^="edit_section_"]');
        editSectionSelects.forEach(select => {
            const editSousSectionSelect = document.getElementById(select.id.replace('section', 'sous_section'));
            select.addEventListener('change', () => updateSousSection(select, editSousSectionSelect));
        });
    });
    </script>
</body>
</html>s