<?php
session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';


// Vérifier si l'utilisateur est un superadmin
if (!isset($_SESSION['user_id']) || !isset($_SESSION['is_superadmin']) || !$_SESSION['is_superadmin']) {
    echo json_encode(['success' => false, 'message' => 'Accès non autorisé']);
    exit;
}

// Fonction pour supprimer un questionnaire et toutes ses données associées
function deleteQuestionnaire($pdo, $questionnaire_id) {
    try {
        $pdo->beginTransaction();

        // 1. Supprimer les notes associées
        $stmt = $pdo->prepare("DELETE FROM notes_sous_sections WHERE questionnaire_id = ?");
        $stmt->execute([$questionnaire_id]);

        // 2. Supprimer les commentaires associés
        $stmt = $pdo->prepare("DELETE FROM commentaires_sections WHERE questionnaire_id = ?");
        $stmt->execute([$questionnaire_id]);

        // 3. Supprimer les tâches et tags_taches associés aux notifications
        $stmt = $pdo->prepare("SELECT id FROM notifications WHERE questionnaire_id = ?");
        $stmt->execute([$questionnaire_id]);
        $notification_ids = $stmt->fetchAll(PDO::FETCH_COLUMN);

        if (!empty($notification_ids)) {
            $placeholders = implode(',', array_fill(0, count($notification_ids), '?'));
            
            // Supprimer les tags_taches
            $stmt = $pdo->prepare("DELETE FROM tags_taches WHERE tache_id IN (SELECT id FROM taches WHERE notification_id IN ($placeholders))");
            $stmt->execute($notification_ids);

            // Supprimer les tâches
            $stmt = $pdo->prepare("DELETE FROM taches WHERE notification_id IN ($placeholders)");
            $stmt->execute($notification_ids);
        }

        // 4. Supprimer les notifications
        $stmt = $pdo->prepare("DELETE FROM notifications WHERE questionnaire_id = ?");
        $stmt->execute([$questionnaire_id]);

        // 5. Récupérer l'ID du client associé au questionnaire
        $stmt = $pdo->prepare("SELECT client_id FROM questionnaires WHERE id = ?");
        $stmt->execute([$questionnaire_id]);
        $client_id = $stmt->fetchColumn();

        // 6. Supprimer le questionnaire
        $stmt = $pdo->prepare("DELETE FROM questionnaires WHERE id = ?");
        $stmt->execute([$questionnaire_id]);

        // 7. Vérifier si le client a d'autres questionnaires
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM questionnaires WHERE client_id = ?");
        $stmt->execute([$client_id]);
        if ($stmt->fetchColumn() == 0) {
            // Si le client n'a plus de questionnaires, le supprimer
            $stmt = $pdo->prepare("DELETE FROM clients WHERE id = ?");
            $stmt->execute([$client_id]);
        }

        $pdo->commit();
        return true;
    } catch (Exception $e) {
        $pdo->rollBack();
        return false;
    }
}

// Traitement de la suppression
if ($_SERVER['REQUEST_METHOD'] === 'GET' && isset($_GET['id'])) {
    $id = $_GET['id'];
    if (deleteQuestionnaire($pdo, $id)) {
        echo json_encode(['success' => true, 'message' => "L'avis a été supprimé avec succès."]);
    } else {
        echo json_encode(['success' => false, 'message' => "Une erreur est survenue lors de la suppression de l'avis."]);
    }
} elseif ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['selected_ids'])) {
    $ids = $_POST['selected_ids'];
    $success = true;
    $deletedCount = 0;
    foreach ($ids as $id) {
        if (deleteQuestionnaire($pdo, $id)) {
            $deletedCount++;
        } else {
            $success = false;
            break;
        }
    }
    if ($success) {
        echo json_encode(['success' => true, 'message' => "$deletedCount avis ont été supprimés avec succès."]);
    } else {
        echo json_encode(['success' => false, 'message' => "Une erreur est survenue lors de la suppression des avis."]);
    }
} else {
    echo json_encode(['success' => false, 'message' => "Requête invalide"]);
}
?>