<?php
ini_set('display_errors', 1); 
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';

// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("Location: ../admin.php");
    exit;
}

$questionnaire_id = $_GET['id'] ?? null;
$error = '';
$success = '';

if (!$questionnaire_id) {
    header("Location: dashboard.php");
    exit;
}

// Récupérer les informations du questionnaire et du client
$stmt = $pdo->prepare("
    SELECT q.id, c.id as client_id, c.prenom, c.nom, c.email, c.date_arrivee, c.date_depart, c.numero_chambre
    FROM questionnaires q
    LEFT JOIN clients c ON q.client_id = c.id
    WHERE q.id = ?
");
$stmt->execute([$questionnaire_id]);
$data = $stmt->fetch(PDO::FETCH_ASSOC);

// Récupérer les notes et commentaires du questionnaire
$stmt = $pdo->prepare("
    SELECT section, sous_section, note
    FROM notes_sous_sections
    WHERE questionnaire_id = ?
");
$stmt->execute([$questionnaire_id]);
$notes = $stmt->fetchAll(PDO::FETCH_ASSOC);

$stmt = $pdo->prepare("
    SELECT section, commentaire
    FROM commentaires_sections
    WHERE questionnaire_id = ?
");
$stmt->execute([$questionnaire_id]);
$commentaires = $stmt->fetchAll(PDO::FETCH_ASSOC);

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $prenom = $_POST['prenom'] ?? '';
    $nom = $_POST['nom'] ?? '';
    $email = $_POST['email'] ?? '';
    $date_arrivee = $_POST['date_arrivee'] ?? '';
    $date_depart = $_POST['date_depart'] ?? '';
    $numero_chambre = $_POST['numero_chambre'] ?? '';

    if (empty($prenom) || empty($nom) || empty($date_arrivee) || empty($date_depart) || empty($numero_chambre)) {
        $error = "Tous les champs sont obligatoires sauf l'email.";
    } elseif (!empty($email) && !filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $error = "L'adresse email n'est pas valide.";
    } else {
        $pdo->beginTransaction();
        try {
            if ($data['client_id']) {
                // Mettre à jour les informations du client existant
                $stmt = $pdo->prepare("UPDATE clients SET prenom = ?, nom = ?, email = ?, date_arrivee = ?, date_depart = ?, numero_chambre = ? WHERE id = ?");
                $stmt->execute([$prenom, $nom, $email, $date_arrivee, $date_depart, $numero_chambre, $data['client_id']]);
            } else {
                // Créer un nouveau client et l'associer au questionnaire
                $stmt = $pdo->prepare("INSERT INTO clients (prenom, nom, email, date_arrivee, date_depart, numero_chambre) VALUES (?, ?, ?, ?, ?, ?)");
                $stmt->execute([$prenom, $nom, $email, $date_arrivee, $date_depart, $numero_chambre]);
                $client_id = $pdo->lastInsertId();

                $stmt = $pdo->prepare("UPDATE questionnaires SET client_id = ? WHERE id = ?");
                $stmt->execute([$client_id, $questionnaire_id]);
            }

            // Mettre à jour les notes
            $stmt = $pdo->prepare("UPDATE notes_sous_sections SET note = ? WHERE questionnaire_id = ? AND section = ? AND sous_section = ?");
            $stmtDelete = $pdo->prepare("DELETE FROM notes_sous_sections WHERE questionnaire_id = ? AND section = ? AND sous_section = ?");
            $stmtInsert = $pdo->prepare("INSERT INTO notes_sous_sections (questionnaire_id, section, sous_section, note) VALUES (?, ?, ?, ?)");
            foreach ($_POST['notes'] as $section => $sous_sections) {
                foreach ($sous_sections as $sous_section => $note) {
                    if ($note !== '') {
                        $stmt->execute([$note, $questionnaire_id, $section, $sous_section]);
                        if ($stmt->rowCount() == 0) {
                            $stmtInsert->execute([$questionnaire_id, $section, $sous_section, $note]);
                        }
                    } else {
                        $stmtDelete->execute([$questionnaire_id, $section, $sous_section]);
                    }
                }
            }

            // Mettre à jour les commentaires
            $stmt = $pdo->prepare("UPDATE commentaires_sections SET commentaire = ? WHERE questionnaire_id = ? AND section = ?");
            $stmtInsertComment = $pdo->prepare("INSERT INTO commentaires_sections (questionnaire_id, section, commentaire) VALUES (?, ?, ?)");
            foreach ($_POST['commentaires'] as $section => $commentaire) {
                $stmt->execute([$commentaire, $questionnaire_id, $section]);
                if ($stmt->rowCount() == 0 && !empty(trim($commentaire))) {
                    $stmtInsertComment->execute([$questionnaire_id, $section, $commentaire]);
                }
            }

            // Recalculer les moyennes
            updateQuestionnaireAverages($pdo, $questionnaire_id);

            $pdo->commit();
            $success = "Les informations ont été mises à jour avec succès.";
            
            // Ajouter le script de redirection
            echo "<script>
                setTimeout(function() {
                    window.location.href = 'dashboard.php';
                }, 2000);
            </script>";
            
            // Recharger les données mises à jour
            $stmt = $pdo->prepare("
                SELECT q.id, c.id as client_id, c.prenom, c.nom, c.email, c.date_arrivee, c.date_depart, c.numero_chambre
                FROM questionnaires q
                LEFT JOIN clients c ON q.client_id = c.id
                WHERE q.id = ?
            ");
            $stmt->execute([$questionnaire_id]);
            $data = $stmt->fetch(PDO::FETCH_ASSOC);

            // Recharger les notes et commentaires
            $stmt = $pdo->prepare("SELECT section, sous_section, note FROM notes_sous_sections WHERE questionnaire_id = ?");
            $stmt->execute([$questionnaire_id]);
            $notes = $stmt->fetchAll(PDO::FETCH_ASSOC);

            $stmt = $pdo->prepare("SELECT section, commentaire FROM commentaires_sections WHERE questionnaire_id = ?");
            $stmt->execute([$questionnaire_id]);
            $commentaires = $stmt->fetchAll(PDO::FETCH_ASSOC);

        } catch (Exception $e) {
            $pdo->rollBack();
            $error = "Une erreur est survenue lors de la mise à jour des informations : " . $e->getMessage();
        }
    }
}

// Récupérer la structure du questionnaire
$structure = getQuestionnaireStructure($pdo);
?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Éditer la fiche client - Admin</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="../css/styles.css" rel="stylesheet">
</head>
<body class="bg-gray-100 font-sans">
    <div class="flex">
        <?php include 'sidebar.php'; ?>

        <div id="main-content" class="flex-1 p-10">
            <h1 class="text-3xl font-bold mb-6">Éditer la fiche client</h1>
            
            <?php if ($error): ?>
                <div class="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative mb-4" role="alert">
                    <span class="block sm:inline"><?php echo htmlspecialchars($error); ?></span>
                </div>
            <?php endif; ?>

            <?php if ($success): ?>
                <div class="bg-green-100 border border-green-400 text-green-700 px-4 py-3 rounded relative mb-4" role="alert">
                    <span class="block sm:inline"><?php echo htmlspecialchars($success); ?></span>
                </div>
            <?php endif; ?>

            <form method="POST" class="bg-white shadow-md rounded px-8 pt-6 pb-8 mb-4">
                <h2 class="text-2xl font-bold mb-4">Informations du client</h2>
                <div class="mb-4">
                    <label class="block text-gray-700 text-sm font-bold mb-2" for="prenom">
                        Prénom
                    </label>
                    <input class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" id="prenom" type="text" name="prenom" value="<?php echo htmlspecialchars($data['prenom'] ?? ''); ?>" required>
                </div>
                <div class="mb-4">
                    <label class="block text-gray-700 text-sm font-bold mb-2" for="nom">
                        Nom
                    </label>
                    <input class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" id="nom" type="text" name="nom" value="<?php echo htmlspecialchars($data['nom'] ?? ''); ?>" required>
                </div>
                <div class="mb-4">
                    <label class="block text-gray-700 text-sm font-bold mb-2" for="email">
                        Email
                    </label>
                    <input class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" id="email" type="email" name="email" value="<?php echo htmlspecialchars($data['email'] ?? ''); ?>">
                </div>
                <div class="mb-4">
                    <label class="block text-gray-700 text-sm font-bold mb-2" for="date_arrivee">
                        Date d'arrivée
                    </label>
                    <input class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" id="date_arrivee" type="date" name="date_arrivee" value="<?php echo htmlspecialchars($data['date_arrivee'] ?? ''); ?>" required>
                </div>
                <div class="mb-4">
                    <label class="block text-gray-700 text-sm font-bold mb-2" for="date_depart">
                        Date de départ
                    </label>
                    <input class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" id="date_depart" type="date" name="date_depart" value="<?php echo htmlspecialchars($data['date_depart'] ?? ''); ?>" required>
                </div>
                <div class="mb-6">
                    <label class="block text-gray-700 text-sm font-bold mb-2" for="numero_chambre">
                        Numéro de chambre
                    </label>
                    <input class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" id="numero_chambre" type="text" name="numero_chambre" value="<?php echo htmlspecialchars($data['numero_chambre'] ?? ''); ?>" required>
                </div>

                <h2 class="text-2xl font-bold mb-4">Notes et commentaires</h2>
                <?php foreach ($structure as $section => $sous_sections): ?>
                    <div class="mb-6">
                        <h3 class="text-xl font-semibold mb-2"><?php echo htmlspecialchars($section); ?></h3>
                        <?php foreach ($sous_sections as $sous_section): ?>
                            <div class="mb-4">
                                <label class="block text-gray-700 text-sm font-bold mb-2" for="note_<?php echo sanitizeForId($section . '_' . $sous_section); ?>">
                                    <?php echo htmlspecialchars($sous_section); ?>
                                </label>
                                <select class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" 
                                        id="note_<?php echo sanitizeForId($section . '_' . $sous_section); ?>" 
                                        name="notes[<?php echo htmlspecialchars($section); ?>][<?php echo htmlspecialchars($sous_section); ?>]">
                                    <option value="">Sélectionner une note</option>
                                    <?php 
                                    $currentNote = '';
                                    foreach ($notes as $note) {
                                        if ($note['section'] == $section && $note['sous_section'] == $sous_section) {
                                            $currentNote = $note['note'];
                                            break;
                                        }
                                    }
                                    for ($i = 1; $i <= 5; $i++): 
                                    ?>
                                        <option value="<?php echo $i; ?>" <?php echo $currentNote !== '' && $currentNote == $i ? 'selected' : ''; ?>><?php echo $i; ?></option>
                                    <?php endfor; ?>
                                </select>
                            </div>
                        <?php endforeach; ?>
                        <div class="mb-4">
                            <label class="block text-gray-700 text-sm font-bold mb-2" for="commentaire_<?php echo sanitizeForId($section); ?>">
                                Commentaire
                            </label>
                            <textarea class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" 
          id="commentaire_<?php echo sanitizeForId($section); ?>" 
          name="commentaires[<?php echo htmlspecialchars($section); ?>]" 
          rows="3"><?php 
    $sectionComment = '';
    foreach ($commentaires as $commentaire) {
        if ($commentaire['section'] == $section) {
            $sectionComment = $commentaire['commentaire'];
            break;
        }
    }
    echo htmlspecialchars($sectionComment);
?></textarea>
                        </div>
                    </div>
                <?php endforeach; ?>

                <div class="flex items-center justify-between">
                    <button class="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline" type="submit">
                        Enregistrer les modifications
                    </button>
                    <a href="dashboard.php" class="inline-block align-baseline font-bold text-sm text-blue-500 hover:text-blue-800">
                        Retour au tableau de bord
                    </a>
                </div>
            </form>
        </div>
    </div>

    <script>
    document.addEventListener('DOMContentLoaded', function() {
        const form = document.querySelector('form');
        form.addEventListener('submit', function(e) {
            const requiredFields = form.querySelectorAll('input[required], select[required]');
            let isValid = true;

            requiredFields.forEach(field => {
                if (!field.value.trim()) {
                    isValid = false;
                    field.classList.add('border-red-500');
                } else {
                    field.classList.remove('border-red-500');
                }
            });

            if (!isValid) {
                e.preventDefault();
                alert('Veuillez remplir tous les champs obligatoires.');
            }
        });

        // Fonction pour vérifier si une note a été modifiée
        /*function checkNoteChange() {
            const noteSelects = document.querySelectorAll('select[name^="notes["]');
            noteSelects.forEach(select => {
                select.addEventListener('change', function() {
                    const section = this.name.match(/notes\[(.*?)\]/)[1];
                    const commentTextarea = document.querySelector(`textarea[name="commentaires[${section}]"]`);
                    
                    if (parseInt(this.value) <= 2) {
                        commentTextarea.classList.add('border-red-500');
                        commentTextarea.setAttribute('required', 'required');
                    } else {
                        commentTextarea.classList.remove('border-red-500');
                        commentTextarea.removeAttribute('required');
                    }
                });
            });
        }

        // Appeler la fonction pour initialiser les écouteurs d'événements
        checkNoteChange();
*/
        // Fonction pour valider les dates
        function validateDates() {
            const dateArrivee = document.getElementById('date_arrivee');
            const dateDepart = document.getElementById('date_depart');

            dateArrivee.addEventListener('change', function() {
                if (dateDepart.value && this.value > dateDepart.value) {
                    alert('La date d\'arrivée ne peut pas être postérieure à la date de départ.');
                    this.value = '';
                }
            });

            dateDepart.addEventListener('change', function() {
                if (dateArrivee.value && this.value < dateArrivee.value) {
                    alert('La date de départ ne peut pas être antérieure à la date d\'arrivée.');
                    this.value = '';
                }
            });
        }

        // Appeler la fonction pour initialiser la validation des dates
        validateDates();
    });
    </script>
</body>
</html>