<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

session_start();
if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../includes/db_connect.php';
require_once __DIR__ . '/../includes/functions.php';
require_once __DIR__ . '/../d8f7g9h3j2k.php';

// Vérifier si l'utilisateur est connecté et est un superadmin
if (!isset($_SESSION['user_id']) || !isset($_SESSION['is_superadmin']) || !$_SESSION['is_superadmin']) {
    header("Location: ../admin.php");
    exit;
}

$action = $_GET['action'] ?? 'list';
$id = $_GET['id'] ?? null;
$message = '';

// Fonction pour obtenir le contenu HTML du template par défaut
function getDefaultTemplateContent() {
    return '
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Email du Vallon de Varlugues</title>
    <style>
        body { font-family: Arial, sans-serif; line-height: 1.6; color: #333; max-width: 600px; margin: 0 auto; padding: 20px; }
        .header { text-align: center; margin-bottom: 20px; }
        .logo { max-width: 200px; }
        .content { background-color: #f9f9f9; padding: 20px; border-radius: 5px; }
        .footer { margin-top: 20px; text-align: center; font-size: 12px; color: #666; }
        .footer a { color: #3498db; text-decoration: none; }
    </style>
</head>
<body>
    <div class="header">
        <img src="https://votre-site.com/chemin-vers-votre-logo.png" alt="Logo Vallon de Varlugues" class="logo">
    </div>
    <div class="content">
        <p>Bonjour [PRENOM] [NOM],</p>
        <p>Lors de votre séjour dans notre établissement, vous nous avez fait part de votre mécontentement concernant le confort de la literie.</p>
        <p>Nous nous excusons de ce désagrément et nous tenions à vous informer que nous prenons très à coeur les remarques de nos clients. Le matelas de la chambre 33 a donc été changé.</p>
        <p>En esperant vous revoir prochainement dans notre établissement.</p>
        <p>Bonne journée.</p>
        <p>L\'équipe du Vallon de Varlugues</p>
    </div>
    <div class="footer">
        <p>
            <a href="https://www.vallondevauluges.com">Notre site web</a> | 
            <a href="mailto:contact@vallondevauluges.com">Nous contacter</a><br>
            Vallon de Vauluges, 13990 Fontvieille, France | Tél: +33 (0)4 90 54 50 54
        </p>
    </div>
</body>
</html>';
}

switch ($action) {
    case 'create':
    case 'edit':
        if ($_SERVER['REQUEST_METHOD'] == 'POST') {
            $name = $_POST['name'] ?? '';
            $subject = $_POST['subject'] ?? '';
            $body = $_POST['body'] ?? '';

            if (empty($name) || empty($subject) || empty($body)) {
                $message = "Tous les champs sont obligatoires.";
            } else {
                if ($action == 'create') {
                    $stmt = $pdo->prepare("INSERT INTO email_templates (name, subject, body) VALUES (?, ?, ?)");
                    $stmt->execute([$name, $subject, $body]);
                    $message = "Modèle d'email créé avec succès.";
                } else {
                    $stmt = $pdo->prepare("UPDATE email_templates SET name = ?, subject = ?, body = ? WHERE id = ?");
                    $stmt->execute([$name, $subject, $body, $id]);
                    $message = "Modèle d'email mis à jour avec succès.";
                }
                header("Location: email_templates.php");
                exit;
            }
        }

        if ($action == 'edit' && $id) {
            $stmt = $pdo->prepare("SELECT * FROM email_templates WHERE id = ?");
            $stmt->execute([$id]);
            $template = $stmt->fetch(PDO::FETCH_ASSOC);
        } else {
            $template = [
                'name' => '',
                'subject' => '',
                'body' => getDefaultTemplateContent()
            ];
        }
        break;

    case 'delete':
        if ($id) {
            $stmt = $pdo->prepare("DELETE FROM email_templates WHERE id = ?");
            $stmt->execute([$id]);
            $message = "Modèle d'email supprimé avec succès.";
        }
        header("Location: email_templates.php");
        exit;
        break;

    case 'duplicate':
        if ($id) {
            $stmt = $pdo->prepare("SELECT * FROM email_templates WHERE id = ?");
            $stmt->execute([$id]);
            $template = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($template) {
                $newName = $template['name'] . ' (copie)';
                $stmt = $pdo->prepare("INSERT INTO email_templates (name, subject, body) VALUES (?, ?, ?)");
                $stmt->execute([$newName, $template['subject'], $template['body']]);
                $message = "Modèle d'email dupliqué avec succès.";
            }
        }
        header("Location: email_templates.php");
        exit;
        break;

    default:
        $stmt = $pdo->query("SELECT * FROM email_templates ORDER BY name");
        $templates = $stmt->fetchAll(PDO::FETCH_ASSOC);
        break;
}
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gestion des modèles d'emails - Admin</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="../css/styles.css" rel="stylesheet">
    <script src="https://cdn.tiny.cloud/1/<?php echo TINY_API_KEY; ?>/tinymce/5/tinymce.min.js" referrerpolicy="origin"></script>
    <script>
        tinymce.init({
            selector: '#body',
            height: 500,
            plugins: 'link image code',
            toolbar: 'undo redo | formatselect | bold italic | alignleft aligncenter alignright | link image | code',
            apiKey: '<?php echo TINY_API_KEY; ?>'
        });
    </script>
</head>
<body class="bg-gray-100 font-sans">
    <div class="flex">
        <?php include 'sidebar.php'; ?>

        <div id="main-content" class="flex-1 p-10">
            <h1 class="text-3xl font-bold mb-6">Gestion des modèles d'emails</h1>
            
            <?php if ($message): ?>
                <div class="bg-green-100 border border-green-400 text-green-700 px-4 py-3 rounded relative mb-4" role="alert">
                    <span class="block sm:inline"><?php echo htmlspecialchars($message); ?></span>
                </div>
            <?php endif; ?>

            <?php if ($action == 'list'): ?>
                <a href="?action=create" class="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded mb-4 inline-block">Créer un nouveau modèle</a>

                <table class="min-w-full bg-white shadow-md rounded">
                    <thead>
                        <tr>
                            <th class="px-6 py-3 border-b-2 border-gray-300 text-left text-xs font-semibold text-gray-600 uppercase tracking-wider">Nom</th>
                            <th class="px-6 py-3 border-b-2 border-gray-300 text-left text-xs font-semibold text-gray-600 uppercase tracking-wider">Sujet</th>
                            <th class="px-6 py-3 border-b-2 border-gray-300 text-left text-xs font-semibold text-gray-600 uppercase tracking-wider">Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($templates as $template): ?>
                            <tr>
                                <td class="px-6 py-4 whitespace-nowrap"><?php echo htmlspecialchars($template['name']); ?></td>
                                <td class="px-6 py-4 whitespace-nowrap"><?php echo htmlspecialchars($template['subject']); ?></td>
                                <td class="px-6 py-4 whitespace-nowrap">
                                    <a href="?action=edit&id=<?php echo $template['id']; ?>" class="text-blue-600 hover:text-blue-900 mr-4">Modifier</a>
                                    <a href="?action=duplicate&id=<?php echo $template['id']; ?>" class="text-green-600 hover:text-green-900 mr-4">Dupliquer</a>
                                    <a href="?action=delete&id=<?php echo $template['id']; ?>" class="text-red-600 hover:text-red-900" onclick="return confirm('Êtes-vous sûr de vouloir supprimer ce modèle ?');">Supprimer</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php else: ?>
                <form method="POST" class="bg-white shadow-md rounded px-8 pt-6 pb-8 mb-4">
                    <div class="mb-4">
                        <label class="block text-gray-700 text-sm font-bold mb-2" for="name">
                            Nom du modèle
                        </label>
                        <input class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" id="name" type="text" name="name" value="<?php echo htmlspecialchars($template['name'] ?? ''); ?>" required>
                    </div>
                    <div class="mb-4">
                        <label class="block text-gray-700 text-sm font-bold mb-2" for="subject">
                            Sujet
                        </label>
                        <input class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" id="subject" type="text" name="subject" value="<?php echo htmlspecialchars($template['subject'] ?? ''); ?>" required>
                    </div>
                    <div class="mb-6">
                        <label class="block text-gray-700 text-sm font-bold mb-2" for="body">
                            Corps du message
                        </label>
                        <textarea class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" id="body" name="body" rows="10" required><?php echo htmlspecialchars($template['body'] ?? ''); ?></textarea>
                    </div>
                    <div class="flex items-center justify-between">
                        <button class="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline" type="submit">
                            <?php echo $action == 'create' ? 'Créer' : 'Mettre à jour'; ?>
                        </button>
                        <a href="email_templates.php" class="inline-block align-baseline font-bold text-sm text-blue-500 hover:text-blue-800">
                            Annuler
                        </a>
                    </div>
                </form>
            <?php endif; ?>
        </div>
    </div>
</body>
</html>