<?php
session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';
require(__DIR__ . '/../fpdf/fpdf.php');

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';


// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("HTTP/1.1 401 Unauthorized");
    exit;
}

// Vérifier si l'ID du questionnaire est fourni
if (!isset($_GET['id'])) {
    header("HTTP/1.1 400 Bad Request");
    exit;
}

$questionnaire_id = $_GET['id'];

// Récupérer les informations du client et du questionnaire
$stmt = $pdo->prepare("
    SELECT 
        q.id as questionnaire_id,
        q.date_soumission,
        c.prenom,
        c.nom,
        c.date_arrivee,
        c.date_depart,
        c.numero_chambre
    FROM 
        questionnaires q
    JOIN 
        clients c ON q.client_id = c.id
    WHERE 
        q.id = ?
");
$stmt->execute([$questionnaire_id]);
$client_info = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$client_info) {
    header("HTTP/1.1 404 Not Found");
    exit;
}

// Récupérer les notes du questionnaire
$stmt = $pdo->prepare("
    SELECT 
        section,
        sous_section,
        note
    FROM 
        notes_sous_sections
    WHERE 
        questionnaire_id = ?
");
$stmt->execute([$questionnaire_id]);
$notes = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Récupérer les commentaires
$stmt = $pdo->prepare("
    SELECT 
        section,
        commentaire
    FROM 
        commentaires_sections
    WHERE 
        questionnaire_id = ?
");
$stmt->execute([$questionnaire_id]);
$commentaires = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Grouper les notes par section et sous-section
$notes_groupees = [];
foreach ($notes as $note) {
    if (!isset($notes_groupees[$note['section']])) {
        $notes_groupees[$note['section']] = [];
    }
    $notes_groupees[$note['section']][$note['sous_section']] = $note['note'];
}

// Grouper les commentaires par section
$commentaires_groupes = [];
foreach ($commentaires as $commentaire) {
    $commentaires_groupes[$commentaire['section']] = $commentaire['commentaire'];
}

class PDF extends FPDF
{
    function Header()
    {
        $this->SetFont('Helvetica', 'B', 15);
        $this->Cell(0, 10, utf8_decode('Fiche Client'), 0, 1, 'C');
        $this->Ln(10);
    }

    function Footer()
    {
        $this->SetY(-15);
        $this->SetFont('Helvetica', 'I', 8);
        $this->Cell(0, 10, 'Page ' . $this->PageNo() . '/{nb}', 0, 0, 'C');
    }

    function SectionTitle($title)
    {
        $this->SetFont('Helvetica', 'B', 12);
        $this->Cell(0, 10, utf8_decode($title), 0, 1);
        $this->Line($this->GetX(), $this->GetY(), $this->GetX()+180, $this->GetY());
        $this->Ln(5);
    }
}

$pdf = new PDF();
$pdf->AliasNbPages();
$pdf->AddPage();
$pdf->SetLeftMargin(15);
$pdf->SetRightMargin(15);

// Informations du client
$pdf->SetFont('Helvetica', 'B', 12);
$pdf->Cell(0, 10, utf8_decode('Informations du client'), 0, 1);
$pdf->SetFont('Helvetica', '', 12);
$pdf->Cell(0, 10, utf8_decode('Nom: ' . $client_info['prenom'] . ' ' . $client_info['nom']), 0, 1);
$pdf->Cell(0, 10, utf8_decode('Numéro de chambre: ' . $client_info['numero_chambre']), 0, 1);
$pdf->Cell(0, 10, utf8_decode('Date d\'arrivée: ' . $client_info['date_arrivee']), 0, 1);
$pdf->Cell(0, 10, utf8_decode('Date de départ: ' . $client_info['date_depart']), 0, 1);
$pdf->Cell(0, 10, utf8_decode('Date de soumission: ' . $client_info['date_soumission']), 0, 1);
$pdf->Ln(10);

// Notes et commentaires par section
foreach ($notes_groupees as $section => $sous_sections) {
    $pdf->SectionTitle(utf8_decode($section));
    $pdf->SetFont('Helvetica', '', 12);
    
    foreach ($sous_sections as $sous_section => $note) {
        $pdf->SetTextColor(0, 0, 0); // Noir par défaut
        if ($note <= 2) {
            $pdf->SetTextColor(255, 0, 0); // Rouge pour les notes de 1 et 2
        }
        $pdf->Cell(120, 8, utf8_decode($sous_section), 0);
        $pdf->Cell(0, 8, $note . ' / 5', 0, 1);
    }
    
    if (isset($commentaires_groupes[$section])) {
        $pdf->SetTextColor(255, 0, 0); // Rouge pour les commentaires
        $pdf->SetFont('Helvetica', 'I', 11);
        $pdf->MultiCell(0, 8, utf8_decode('Commentaire: ' . $commentaires_groupes[$section]), 0, 'L');
    }
    
    $pdf->Ln(5);
}

// Générer le PDF
$pdf->Output('D', 'fiche_client_' . $client_info['nom'] . '_' . $client_info['prenom'] . '.pdf');