<?php
session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';
require_once __DIR__ . '/../fpdf/fpdf.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';

// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("HTTP/1.1 401 Unauthorized");
    exit;
}

$tag_id = $_GET['tag_id'] ?? null;

if (!$tag_id) {
    die("Tag ID non fourni");
}

// Récupérer les informations du tag
$stmt = $pdo->prepare("SELECT tag, section FROM section_tags WHERE id = ?");
$stmt->execute([$tag_id]);
$tag_info = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$tag_info) {
    die("Tag non trouvé");
}

// Récupérer les tâches associées au tag
$tasks = getTasksForTag($pdo, $tag_id);

// Créer le PDF
class PDF extends FPDF
{
    function Header()
    {
        $this->SetFont('Arial', 'B', 15);
        $this->Cell(0, 10, 'Liste des taches', 0, 1, 'C');
        $this->Ln(5);
    }

    function Footer()
    {
        $this->SetY(-15);
        $this->SetFont('Arial', 'I', 8);
        $this->Cell(0, 10, 'Page ' . $this->PageNo() . '/{nb}', 0, 0, 'C');
    }

    function CellWithOverflow($w, $h, $txt, $border=0, $align='J', $fill=false)
    {
        // Si le texte dépasse la cellule, on passe à la ligne
        if($this->GetStringWidth($txt) > $w)
        {
            $this->MultiCell($w, $h, $txt, $border, $align, $fill);
        }
        else
        {
            $this->Cell($w, $h, $txt, $border, 0, $align, $fill);
        }
    }
}

$pdf = new PDF('L', 'mm', 'A4'); // Format paysage pour plus d'espace
$pdf->AliasNbPages();
$pdf->AddPage();
$pdf->SetFont('Arial', 'B', 12);
$pdf->Cell(0, 10, utf8_decode("Tag: " . $tag_info['tag'] . " (Section: " . $tag_info['section'] . ")"), 0, 1);
$pdf->Ln(5);

$pdf->SetFont('Arial', 'B', 10);
$pdf->Cell(25, 7, 'Date', 1);
$pdf->Cell(35, 7, 'Client', 1);
$pdf->Cell(20, 7, 'Chambre', 1);
$pdf->Cell(25, 7, 'Section', 1);
$pdf->Cell(15, 7, 'Note', 1);
$pdf->Cell(60, 7, 'Remarque', 1);
$pdf->Cell(90, 7, 'Commentaire', 1);
$pdf->Ln();

$pdf->SetFont('Arial', '', 9);
foreach ($tasks as $task) {
    $startY = $pdf->GetY();
    $pdf->Cell(25, 7, date('d/m/Y', strtotime($task['date_creation'])), 1);
    $pdf->Cell(35, 7, utf8_decode($task['prenom'] . ' ' . $task['nom']), 1);
    $pdf->Cell(20, 7, $task['numero_chambre'], 1);
    $pdf->Cell(25, 7, utf8_decode($task['section']), 1);
    $pdf->Cell(15, 7, $task['note'] . '/5', 1);
    
    // Remarque
    $pdf->CellWithOverflow(60, 7, utf8_decode($task['remarque']), 1);
    
    // Commentaire
    $currentX = $pdf->GetX();
    $pdf->CellWithOverflow(90, 7, utf8_decode($task['commentaire'] ?? ''), 1);
    
    // Ajuster la hauteur de la ligne si nécessaire
    $endY = $pdf->GetY();
    $lineHeight = $endY - $startY;
    if ($lineHeight > 7) {
        $pdf->SetY($startY);
        $pdf->Cell(25, $lineHeight, '', 'LRB');
        $pdf->Cell(35, $lineHeight, '', 'LRB');
        $pdf->Cell(20, $lineHeight, '', 'LRB');
        $pdf->Cell(25, $lineHeight, '', 'LRB');
        $pdf->Cell(15, $lineHeight, '', 'LRB');
        $pdf->Cell(60, $lineHeight, '', 'LRB');
        $pdf->SetXY($currentX, $endY);
    }
    
    $pdf->Ln();
}

$pdf->Output('D', 'taches_' . $tag_info['tag'] . '.pdf');