<?php
header('Content-Type: application/json');
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';


// Activer l'enregistrement des erreurs dans un fichier de log personnalisé
ini_set('log_errors', 1);
ini_set('error_log', __DIR__ . '../logs/error.log');  // Crée un fichier error_log.txt dans le même répertoire
error_reporting(E_ALL);


// Vérification de l'ID de la date clé
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    echo json_encode(['error' => 'ID invalide']);
    exit;
}

$date_cle_id = intval($_GET['id']);

// Récupérer les informations de la date clé
$stmt = $pdo->prepare("SELECT date, section, sous_section FROM dates_cles WHERE id = ?");
$stmt->execute([$date_cle_id]);
$date_cle = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$date_cle) {
    echo json_encode(['error' => 'Date clé non trouvée']);
    exit;
}

$date = $date_cle['date'];
$section = $date_cle['section'];
$sous_section = $date_cle['sous_section'];

// Afficher pour débogage
error_log("Date clé utilisée: " . $date);
error_log("Section: " . $section);
error_log("Sous-section: " . $sous_section);

// Construire la requête pour récupérer les données avant et après
$query = "
    SELECT
        CASE 
            WHEN DATE(q.date_soumission) < :date THEN 'before'
            ELSE 'after'
        END as period,
        AVG(n.note) as average
    FROM
        questionnaires q
    JOIN
        notes_sous_sections n ON q.id = n.questionnaire_id
    WHERE
        q.date_soumission IS NOT NULL
        AND n.section = :section
        AND (n.sous_section = :sous_section OR :sous_section IS NULL)
    GROUP BY
        period
";

// Exécuter la requête
$stmt = $pdo->prepare($query);
$stmt->execute([
    'date' => $date,
    'section' => $section,
    'sous_section' => $sous_section
]);

$results = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Ajouter du débogage pour voir les résultats
error_log("Résultats de la requête: " . json_encode($results));

$before = null;
$after = null;

foreach ($results as $result) {
    if ($result['period'] === 'before') {
        $before = floatval($result['average']);
    } else {
        $after = floatval($result['average']);
    }
}

echo json_encode([
    'before' => $before ?? 0,
    'after' => $after ?? 0,
    'difference' => ($after !== null && $before !== null) ? $after - $before : 0
]);
