<?php
session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';

// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header('Content-Type: application/json');
    echo json_encode(['error' => 'Non autorisé']);
    exit;
}

// Récupérer les paramètres
$section = $_GET['section'] ?? null;
$sous_section = $_GET['sous_section'] ?? null;
$note = $_GET['note'] ?? null;
$start_date = $_GET['start_date'] ?? date('Y-m-d', strtotime('-1 month'));
$end_date = $_GET['end_date'] ?? date('Y-m-d');

// Vérifier que tous les paramètres requis sont présents
if (!$section || !$sous_section || !$note) {
    header('Content-Type: application/json');
    echo json_encode(['error' => 'Paramètres manquants']);
    exit;
}

try {
    // Récupérer les détails des notes
    $details = getStarDetails($pdo, $section, $sous_section, $note, $start_date, $end_date);
    
    // Formater les données pour la réponse
    $formatted_details = array_map(function($detail) {
        return [
            'prenom' => htmlspecialchars($detail['prenom']),
            'nom' => htmlspecialchars($detail['nom']),
            'numero_chambre' => htmlspecialchars($detail['numero_chambre']),
            'date_arrivee' => $detail['date_arrivee'],
            'date_depart' => $detail['date_depart'],
            'date_soumission' => $detail['date_soumission'],
            'note' => $detail['note'],
            'commentaire' => $detail['commentaire'] ? htmlspecialchars($detail['commentaire']) : null
        ];
    }, $details);

    header('Content-Type: application/json');
    echo json_encode($formatted_details);

} catch (Exception $e) {
    header('Content-Type: application/json');
    echo json_encode(['error' => 'Une erreur est survenue lors de la récupération des détails']);
    exit;
}
?>