<?php
session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';

// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("Location: ../admin.php");
    exit;
}

// Récupérer les sections du questionnaire
$stmt = $pdo->query("SELECT DISTINCT section FROM structure_questionnaire ORDER BY ordre");
$sections = $stmt->fetchAll(PDO::FETCH_COLUMN);

$error = '';
$success = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $action = $_POST['action'] ?? '';
    $section = $_POST['section'] ?? '';
    $tag = $_POST['tag'] ?? '';

    if ($action && $section && $tag) {
        switch ($action) {
            case 'add':
                $result = addTag($pdo, $section, $tag);
                if ($result['success']) {
                    $success = "Le tag a été ajouté avec succès.";
                } else {
                    $error = "Erreur lors de l'ajout du tag : " . ($result['error'] ?? 'Erreur inconnue');
                }
                break;
            case 'delete':
                if (deleteTag($pdo, $section, $tag)) {
                    $success = "Le tag a été supprimé avec succès.";
                } else {
                    $error = "Erreur lors de la suppression du tag.";
                }
                break;
            case 'edit':
                $newTag = $_POST['new_tag'] ?? '';
                if ($newTag && editTag($pdo, $section, $tag, $newTag)) {
                    $success = "Le tag a été modifié avec succès.";
                } else {
                    $error = "Erreur lors de la modification du tag.";
                }
                break;
        }
    }
}

// Récupérer tous les tags
$stmt = $pdo->query("SELECT * FROM section_tags ORDER BY section, tag");
$all_tags = $stmt->fetchAll(PDO::FETCH_ASSOC);

$tags_by_section = [];
foreach ($all_tags as $tag) {
    $tags_by_section[$tag['section']][] = $tag;
}
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gestion des Tags - Admin</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/gh/alpinejs/alpine@v2.x.x/dist/alpine.min.js" defer></script>
    <style>
        .tag-card {
            transition: all 0.3s ease;
        }
        .tag-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        }
    </style>
</head>
<body class="bg-gray-100 font-sans">
    <div class="flex">
        <?php include 'sidebar.php'; ?>
        <div id="main-content" class="flex-1 p-10">
            <h1 class="text-3xl font-bold mb-6 text-gray-800">Gestion des Tags</h1>

            <?php if ($error): ?>
                <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-6" role="alert">
                    <p><?php echo escapeHtml($error); ?></p>
                </div>
            <?php endif; ?>

            <?php if ($success): ?>
                <div class="bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-6" role="alert">
                    <p><?php echo escapeHtml($success); ?></p>
                </div>
            <?php endif; ?>

            <!-- Liste des tags par section -->
            <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
                <?php foreach ($sections as $section): ?>
                    <div x-data="{ addingTag: false, newTag: '' }" class="bg-white rounded-lg shadow-md p-6">
                        <h2 class="text-xl font-semibold mb-4 text-gray-800"><?php echo escapeHtml($section); ?></h2>
                        <div class="space-y-2">
                            <?php if (isset($tags_by_section[$section])): ?>
                                <?php foreach ($tags_by_section[$section] as $tag): ?>
                                    <div x-data="{ editing: false, editedTag: '<?php echo escapeJs($tag['tag']); ?>' }" class="tag-card bg-gray-50 p-3 rounded-md">
                                        <div class="flex justify-between items-center">
                                            <span x-show="!editing" class="text-gray-800"><?php echo escapeHtml($tag['tag']); ?></span>
                                            <input x-show="editing" type="text" x-model="editedTag" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                                            <div class="flex space-x-2">
                                                <button x-show="!editing" @click="editing = true" class="text-blue-600 hover:text-blue-800">
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                                <button x-show="editing" @click="
                                                    if(editedTag.trim() !== '<?php echo escapeJs($tag['tag']); ?>') {
                                                        window.editTag('<?php echo escapeJs($section); ?>', '<?php echo escapeJs($tag['tag']); ?>', editedTag.trim())
                                                    }
                                                    editing = false
                                                " class="text-green-600 hover:text-green-800">
                                                    <i class="fas fa-check"></i>
                                                </button>
                                                <button x-show="editing" @click="editing = false; editedTag = '<?php echo escapeJs($tag['tag']); ?>'" class="text-gray-600 hover:text-gray-800">
                                                    <i class="fas fa-times"></i>
                                                </button>
                                                <button @click="window.deleteTag('<?php echo escapeJs($section); ?>', '<?php echo escapeJs($tag['tag']); ?>')" class="text-red-600 hover:text-red-800">
                                                    <i class="fas fa-trash"></i>
                                                </button>
                                            </div>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <p class="text-gray-500">Aucun tag pour cette section.</p>
                            <?php endif; ?>
                        </div>
                        <div class="mt-4">
                            <template x-if="!addingTag">
                                <button @click="addingTag = true; newTag = ''" class="text-blue-600 hover:text-blue-800">
                                    <i class="fas fa-plus-circle"></i> Ajouter un tag
                                </button>
                            </template>
                            <div x-show="addingTag" class="flex items-center space-x-2">
                                <input x-model="newTag" type="text" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 h-10" placeholder="Nouveau tag">
                                <button @click="
                                    if(newTag.trim() !== '') {
                                        window.addTag('<?php echo escapeJs($section); ?>', newTag.trim());
                                        addingTag = false;
                                        newTag = '';
                                    }
                                " class="text-green-600 hover:text-green-800">
                                    <i class="fas fa-check"></i>
                                </button>
                                <button @click="addingTag = false" class="text-red-600 hover:text-red-800">
                                    <i class="fas fa-times"></i>
                                </button>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
    </div>

    <script>
    window.addTag = function(section, tag) {
        fetch('manage_tags.php', {
            method: 'POST',
            headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
            body: `action=add&section=${encodeURIComponent(section)}&tag=${encodeURIComponent(tag)}`
        })
        .then(response => response.text())
        .then(data => {
            location.reload(); // Recharge la page pour afficher le nouveau tag
        })
        .catch(error => {
            console.error('Error:', error);
            alert("Une erreur est survenue lors de l'ajout du tag.");
        });
    }

    window.editTag = function(section, oldTag, newTag) {
        fetch('manage_tags.php', {
            method: 'POST',
            headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
            body: `action=edit&section=${encodeURIComponent(section)}&tag=${encodeURIComponent(oldTag)}&new_tag=${encodeURIComponent(newTag)}`
        })
        .then(response => response.text())
        .then(data => {
            location.reload(); // Recharge la page pour afficher les changements
        })
        .catch(error => {
            console.error('Error:', error);
            alert("Une erreur est survenue lors de la modification du tag.");
        });
    }

    window.deleteTag = function(section, tag) {
        if (confirm('Êtes-vous sûr de vouloir supprimer ce tag ?')) {
            fetch('manage_tags.php', {
                method: 'POST',
                headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
                body: `action=delete&section=${encodeURIComponent(section)}&tag=${encodeURIComponent(tag)}`
            })
            .then(response => response.text())
            .then(data => {
                location.reload(); // Recharge la page pour refléter la suppression
            })
            .catch(error => {
                console.error('Error:', error);
                alert("Une erreur est survenue lors de la suppression du tag.");
            });
        }
    }
    </script>
</body>
</html>