<?php
session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';


// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("Location: ../admin.php");
    exit;
}

// Récupérer les notifications
$stmt = $pdo->query("
    SELECT 
        n.id,
        n.questionnaire_id,
        n.section,
        n.sous_section,
        n.note,
        c.prenom,
        c.nom,
        c.numero_chambre,
        cs.commentaire
    FROM 
        notifications n
    JOIN 
        questionnaires q ON n.questionnaire_id = q.id
    JOIN 
        clients c ON q.client_id = c.id
    LEFT JOIN 
        commentaires_sections cs ON q.id = cs.questionnaire_id AND n.section = cs.section
    WHERE 
        n.status != 'traitee'
    ORDER BY 
        n.date_creation DESC
");

$notifications = $stmt->fetchAll(PDO::FETCH_ASSOC);

?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Notifications - Admin</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="../css/styles.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/alpinejs@3.x.x/dist/cdn.min.js" defer></script>
</head>
<body class="bg-gray-100 font-sans">
    <div class="flex">
        <?php include 'sidebar.php'; ?>

        <div id="main-content" class="flex-1 p-10">
            <div x-data="notificationsApp()">
                <h1 class="text-3xl font-bold mb-6">Notifications</h1>
                
                <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                    <?php if (empty($notifications)): ?>
                        <div class="col-span-2 bg-white shadow-md rounded-lg p-6">
                            <p class="text-gray-600 text-center">Pas de nouvelles notifications</p>
                        </div>
                    <?php else: ?>
                        <?php foreach ($notifications as $notification): ?>
                            <div class="bg-white shadow-md rounded-lg p-6 h-full" x-data="{ showTags: false }">
                                <div class="flex justify-between items-start">
                                    <div>
                                        <h2 class="text-xl font-semibold"><?php echo escapeHtml($notification['prenom'] . ' ' . $notification['nom']); ?></h2>
                                        <p class="text-gray-600">Chambre: <?php echo escapeHtml($notification['numero_chambre']); ?></p>
                                    </div>
                                </div>
                                <div class="mt-4">
                                    <p class="font-medium"><?php echo escapeHtml($notification['section'] . ' - ' . $notification['sous_section']); ?></p>
                                    <p class="text-red-600 font-bold">Note: <?php echo $notification['note']; ?>/5</p>
                                </div>
                                <?php if ($notification['commentaire']): ?>
                                    <div class="mt-4">
                                        <p class="font-medium">Commentaire:</p>
                                        <p class="text-gray-700"><?php echo escapeHtml($notification['commentaire']); ?></p>
                                    </div>
                                <?php endif; ?>
                                <div class="mt-4">
                                    <button x-show="!showTags" @click="showTags = true" class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded">
                                        Créer une tâche
                                    </button>
                                </div>
                                <div x-show="showTags" class="mt-4">
                                    <p class="font-medium mb-2">Sélectionner les tags:</p>
                                    <div class="flex flex-wrap gap-2">
                                        <?php 
                                        $sectionTags = getTagsForSection($pdo, $notification['section']);
                                        foreach ($sectionTags as $tag): 
                                        ?>
                                            <button 
                                                @click="toggleTag('<?php echo $tag['id']; ?>', '<?php echo escapeJs($tag['tag']); ?>')" 
                                                :class="{'bg-blue-500 text-white': selectedTags.some(t => t.id === '<?php echo $tag['id']; ?>'), 'bg-gray-200 text-gray-700': !selectedTags.some(t => t.id === '<?php echo $tag['id']; ?>')}"
                                                class="px-3 py-1 rounded-full text-sm font-semibold"
                                            ><?php echo escapeHtml($tag['tag']); ?></button>
                                        <?php endforeach; ?>
                                    </div>
                                    <div class="mt-4">
                                        <label for="remarque" class="block text-sm font-medium text-gray-700">Remarque</label>
                                        <textarea id="remarque" x-model="remarque" rows="3" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50"></textarea>
                                    </div>
                                    <button @click="createTask(<?php echo $notification['id']; ?>)" class="mt-4 bg-indigo-500 hover:bg-indigo-600 text-white font-bold py-2 px-4 rounded">
                                        Valider la tâche
                                    </button>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
    <script src="../js/admin.js"></script>
    <script>
    function notificationsApp() {
        return {
            selectedTags: [],
            remarque: '',
            toggleTag(tagId, tagName) {
                const index = this.selectedTags.findIndex(t => t.id === tagId);
                if (index === -1) {
                    this.selectedTags.push({id: tagId, name: tagName});
                } else {
                    this.selectedTags.splice(index, 1);
                }
            },
            createTask(notificationId) {
                fetch('create_task.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({
                        notification_id: notificationId,
                        tags: this.selectedTags.map(tag => tag.id),
                        remarque: this.remarque
                    })
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        window.location.reload();
                    } else {
                        alert('Une erreur est survenue lors de la création de la tâche: ' + data.message);
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    alert('Une erreur est survenue lors de la création de la tâche.');
                });
            }
        }
    }
    </script>
</body>
</html>