<?php
session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';


// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("Location: ../admin.php");
    exit;
}

// Récupérer la structure du questionnaire
$stmt = $pdo->query("SELECT * FROM structure_questionnaire ORDER BY ordre");
$structure = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Grouper les sous-sections par section
$sections = [];
foreach ($structure as $item) {
    if (!isset($sections[$item['section']])) {
        $sections[$item['section']] = [];
    }
    $sections[$item['section']][] = $item;
}
?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gestion du Questionnaire - Admin</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="../css/styles.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/alpinejs@3.x.x/dist/cdn.min.js" defer></script>
    <script src="https://cdn.jsdelivr.net/npm/sortablejs@1.14.0/Sortable.min.js"></script>
</head>
<body class="bg-gray-100 font-sans">
    <div class="flex">
        <?php include 'sidebar.php'; ?>
        <div id="main-content" class="flex-1 p-10">
            <div x-data="questionnaireApp()">
                <h1 class="text-3xl font-bold mb-6">Gestion du Questionnaire</h1>
                
                <div class="mb-6 space-x-4">
                    <button @click="showAddSection = true" class="bg-green-500 hover:bg-green-600 text-white font-bold py-2 px-4 rounded">
                        Ajouter une section
                    </button>
                    <button @click="previewQuestionnaire" class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded">
                        Prévisualiser
                    </button>
                    <button @click="showHistory" class="bg-yellow-500 hover:bg-yellow-600 text-white font-bold py-2 px-4 rounded">
                        Historique
                    </button>
                    <button @click="exportStructure" class="bg-purple-500 hover:bg-purple-600 text-white font-bold py-2 px-4 rounded">
                        Exporter
                    </button>
                    <button @click="importStructure" class="bg-indigo-500 hover:bg-indigo-600 text-white font-bold py-2 px-4 rounded">
                        Importer
                    </button>
                </div>

                <!-- Formulaire d'ajout de section -->
                <div x-show="showAddSection" class="mb-6 bg-white p-6 rounded-lg shadow">
                    <h2 class="text-xl font-semibold mb-4">Ajouter une nouvelle section</h2>
                    <form @submit.prevent="addSection">
                        <div class="mb-4">
                            <label for="newSectionName" class="block text-sm font-medium text-gray-700">Nom de la section</label>
                            <input type="text" id="newSectionName" x-model="newSectionName" required class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                        </div>
                        <div class="mb-4">
                            <label for="newSubSectionName" class="block text-sm font-medium text-gray-700">Nom de la première sous-section</label>
                            <input type="text" id="newSubSectionName" x-model="newSubSectionName" required class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                        </div>
                        <button type="submit" class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded">
                            Ajouter
                        </button>
                    </form>
                </div>

                <!-- Structure du questionnaire -->
                <div id="questionnaire-structure" class="space-y-6">
                    <?php foreach ($sections as $sectionName => $subSections): ?>
                        <div class="bg-white shadow-md rounded-lg p-6" data-section="<?php echo htmlspecialchars($sectionName); ?>">
                            <h2 class="text-xl font-semibold mb-4"><?php echo htmlspecialchars($sectionName); ?></h2>
                            <ul class="space-y-2 subsections-list">
                                <?php foreach ($subSections as $subSection): ?>
                                    <li class="flex items-center justify-between p-2 rounded <?php echo $subSection['active'] ? 'bg-gray-100' : 'bg-gray-300'; ?>" data-id="<?php echo $subSection['id']; ?>">
                                        <span class="<?php echo $subSection['active'] ? '' : 'text-gray-500'; ?>"><?php echo htmlspecialchars($subSection['sous_section']); ?></span>
                                        <div class="flex items-center">
                                            <button @click="editSubSection(<?php echo $subSection['id']; ?>, '<?php echo addslashes($subSection['sous_section']); ?>')" class="text-blue-500 hover:text-blue-600 mr-2">Modifier</button>
                                            <button @click="deleteSubSection(<?php echo $subSection['id']; ?>)" class="text-red-500 hover:text-red-600 mr-2">Supprimer</button>
                                            <button @click="toggleSubSection(<?php echo $subSection['id']; ?>, <?php echo $subSection['active'] ? 'true' : 'false'; ?>)" class="focus:outline-none">
                                                <svg class="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                                                    <?php if ($subSection['active']): ?>
                                                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M15 12a3 3 0 11-6 0 3 3 0 016 0z"></path>
                                                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M2.458 12C3.732 7.943 7.523 5 12 5c4.478 0 8.268 2.943 9.542 7-1.274 4.057-5.064 7-9.542 7-4.477 0-8.268-2.943-9.542-7z"></path>
                                                    <?php else: ?>
                                                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M13.875 18.825A10.05 10.05 0 0112 19c-4.478 0-8.268-2.943-9.543-7a9.97 9.97 0 011.563-3.029m5.858.908a3 3 0 114.243 4.243M9.878 9.878l4.242 4.242M9.88 9.88l-3.29-3.29m7.532 7.532l3.29 3.29M3 3l3.59 3.59m0 0A9.953 9.953 0 0112 5c4.478 0 8.268 2.943 9.543 7a10.025 10.025 0 01-4.132 5.411m0 0L21 21"></path>
                                                    <?php endif; ?>
                                                </svg>
                                            </button>
                                        </div>
                                    </li>
                                <?php endforeach; ?>
                            </ul>
                            <div class="mt-4">
                                <button @click="showAddSubSection('<?php echo addslashes($sectionName); ?>')" class="text-green-500 hover:text-green-600">Ajouter une sous-section</button>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
    </div>
    <script src="../js/admin.js"></script>
    <script>
        function questionnaireApp() {
            return {
                showAddSection: false,
                newSectionName: '',
                newSubSectionName: '',
                init() {
                    this.initSortable();
                },
                initSortable() {
                    const container = document.getElementById('questionnaire-structure');
                    new Sortable(container, {
                        animation: 150,
                        handle: 'h2',
                        onEnd: () => {
                            this.updateSectionsOrder();
                        }
                    });

                    const lists = document.querySelectorAll('.subsections-list');
                    lists.forEach(list => {
                        new Sortable(list, {
                            animation: 150,
                            group: 'shared',
                            onEnd: (evt) => {
                                this.updateSubSectionsOrder(evt.to);
                            }
                        });
                    });
                },
                updateSectionsOrder() {
                    const sections = Array.from(document.querySelectorAll('#questionnaire-structure > div'));
                    const orderData = sections.map((section, index) => ({
                        section: section.dataset.section,
                        order: index + 1
                    }));

                    fetch('update_sections_order.php', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/json',
                        },
                        body: JSON.stringify(orderData)
                    })
                    .then(response => response.json())
                    .then(data => {
                        if (!data.success) {
                            alert('Erreur lors de la mise à jour de l\'ordre des sections: ' + data.message);
                        }
                    });
                },
                updateSubSectionsOrder(list) {
                    const items = Array.from(list.children);
                    const orderData = items.map((item, index) => ({
                        id: item.dataset.id,
                        order: index + 1
                    }));

                    fetch('update_structure_order.php', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/json',
                        },
                        body: JSON.stringify(orderData)
                    })
                    .then(response => response.json())
                    .then(data => {
                        if (!data.success) {
                            alert('Erreur lors de la mise à jour de l\'ordre: ' + data.message);
                        }
                    });
                },
                addSection() {
                    fetch('add_section.php', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/x-www-form-urlencoded',
                        },
                        body: `section=${encodeURIComponent(this.newSectionName)}&sous_section=${encodeURIComponent(this.newSubSectionName)}`
                    })
                    .then(response => response.json())
                    .then(data => {
                        if (data.success) {
                            window.location.reload();
                        } else {
                            alert('Erreur lors de l\'ajout de la section: ' + data.message);
                        }
                    });
                },
                showAddSubSection(sectionName) {
                    const subSectionName = prompt("Nom de la nouvelle sous-section :");
                    if (subSectionName) {
                        this.addSubSection(sectionName, subSectionName);
                    }
                },
                addSubSection(sectionName, subSectionName) {
                    fetch('add_subsection.php', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/x-www-form-urlencoded',
                        },
                        body: `section=${encodeURIComponent(sectionName)}&sous_section=${encodeURIComponent(subSectionName)}`
                    })
                    .then(response => response.json())
                    .then(data => {
                        if (data.success) {
                            window.location.reload();
                        } else {
                            alert('Erreur lors de l\'ajout de la sous-section: ' + data.message);
                        }
                    });
                },
                editSubSection(id, currentName) {
                    const newName = prompt("Nouveau nom de la sous-section :", currentName);
                    if (newName && newName !== currentName) {
                        fetch('edit_subsection.php', {
                            method: 'POST',
                            headers: {
                                'Content-Type': 'application/x-www-form-urlencoded',
                            },
                            body: `id=${id}&sous_section=${encodeURIComponent(newName)}`
                        })
                        .then(response => response.json())
                        .then(data => {
                            if (data.success) {
                                window.location.reload();
                            } else {
                                alert('Erreur lors de la modification de la sous-section: ' + data.message);
                            }
                        });
                    }
                },
                deleteSubSection(id) {
                    if (confirm("Êtes-vous sûr de vouloir supprimer cette sous-section ?")) {
                        fetch('delete_subsection.php', {
                            method: 'POST',
                            headers: {
                                'Content-Type': 'application/x-www-form-urlencoded',
                            },
                            body: `id=${id}`
                        })
                        .then(response => response.json())
                        .then(data => {
                            if (data.success) {
                                window.location.reload();
                            } else {
                                alert('Erreur lors de la suppression de la sous-section: ' + data.message);
                            }
                        });
                    }
                },
                toggleSubSection(id, currentStatus) {
                    fetch('toggle_subsection.php', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/x-www-form-urlencoded',
                        },
                        body: `id=${id}&active=${!currentStatus}`
                    })
                    .then(response => response.json())
                    .then(data => {
                        if (data.success) {
                            window.location.reload();
                        } else {
                            alert('Erreur lors de la modification du statut de la sous-section: ' + data.message);
                        }
                    });
                },
                previewQuestionnaire() {
                    window.open('preview_questionnaire.php', '_blank');
                },
                showHistory() {
                    window.open('questionnaire_history.php', '_blank');
                },
                exportStructure() {
                    window.location.href = 'export_structure.php';
                },
                importStructure() {
                    const input = document.createElement('input');
                    input.type = 'file';
                    input.accept = '.json';
                    input.onchange = (event) => {
                        const file = event.target.files[0];
                        const reader = new FileReader();
                        reader.onload = (e) => {
                            const content = e.target.result;
                            fetch('import_structure.php', {
                                method: 'POST',
                                headers: {
                                    'Content-Type': 'application/json',
                                },
                                body: content
                            })
                            .then(response => response.json())
                            .then(data => {
                                if (data.success) {
                                    window.location.reload();
                                } else {
                                    alert('Erreur lors de l\'importation: ' + data.message);
                                }
                            });
                        };
                        reader.readAsText(file);
                    };
                    input.click();
                }
            }
        }
    </script>
</body>
</html>