<?php
session_start();
if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';
require_once __DIR__ . '/../includes/db_connect.php';
require_once __DIR__ . '/../includes/functions.php';

// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit;
}

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\SMTP;
use PHPMailer\PHPMailer\Exception;

require_once __DIR__ . '/../libs/phpmailer/src/Exception.php';
require_once __DIR__ . '/../libs/phpmailer/src/PHPMailer.php';
require_once __DIR__ . '/../libs/phpmailer/src/SMTP.php';

$questionnaire_id = $_GET['id'] ?? null;
$bulk_emails = isset($_GET['bulk_emails']) ? explode(',', $_GET['bulk_emails']) : null;
$tag_id = $_GET['tag_id'] ?? null;
$error = '';
$success = '';
$client = null;
$clients = [];

// Récupérer les informations du client si c'est un envoi individuel
if ($questionnaire_id) {
    $stmt = $pdo->prepare("
        SELECT c.id as client_id, c.prenom, c.nom, c.email, q.id as questionnaire_id, q.date_soumission
        FROM questionnaires q
        JOIN clients c ON q.client_id = c.id
        WHERE q.id = ?
    ");
    $stmt->execute([$questionnaire_id]);
    $client = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$client) {
        die("Client non trouvé");
    }
} elseif ($bulk_emails) {
    // Récupérer les informations de tous les clients pour l'envoi en masse
    $placeholders = implode(',', array_fill(0, count($bulk_emails), '?'));
    $stmt = $pdo->prepare("
        SELECT c.id as client_id, c.prenom, c.nom, c.email, q.id as questionnaire_id, q.date_soumission
        FROM clients c
        JOIN questionnaires q ON c.id = q.client_id
        WHERE c.email IN ($placeholders)
        ORDER BY q.date_soumission DESC
    ");
    $stmt->execute($bulk_emails);
    $clients = $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Récupérer les modèles d'emails
$stmt = $pdo->query("SELECT id, name FROM email_templates ORDER BY name");
$templates = $stmt->fetchAll(PDO::FETCH_ASSOC);

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $template_id = $_POST['template_id'] ?? '';
    $subject = $_POST['subject'] ?? '';
    $body = $_POST['body'] ?? '';

    if (empty($template_id) || empty($subject) || empty($body)) {
        $error = "Tous les champs sont obligatoires.";
    } else {
        $successCount = 0;
        $failCount = 0;

        $sendEmail = function($clientInfo) use ($subject, $body, $pdo, $template_id, &$successCount, &$failCount) {
            $mail = new PHPMailer(true);
            try {
                //Server settings
                $mail->CharSet = 'UTF-8';
                $mail->Encoding = 'base64';
                $mail->SMTPDebug = SMTP::DEBUG_OFF;
                $mail->isSMTP();
                $mail->Host       = SMTP_HOST;
                $mail->SMTPAuth   = true;
                $mail->Username   = GMAIL_USERNAME;
                $mail->Password   = GMAIL_PASSWORD;
                $mail->SMTPSecure = SMTP_SECURE;
                $mail->Port       = SMTP_PORT;

                //Recipients
                $mail->setFrom(GMAIL_USERNAME, 'Vallon de Valrugues & Spa');
                $mail->addReplyTo('feraudmat.hieu@gmail.com', 'Vallon de Valrugues & Spa');
                $mail->addAddress($clientInfo['email'], $clientInfo['prenom'] . ' ' . $clientInfo['nom']);

                // Content
                $mail->isHTML(true);
                $mail->Subject = mb_encode_mimeheader($subject, 'UTF-8');
                $customBody = str_replace(
                    ['[PRENOM]', '[NOM]', '[DATE_SOUMISSION]'],
                    [$clientInfo['prenom'], $clientInfo['nom'], date('d/m/Y', strtotime($clientInfo['date_soumission']))],
                    $body
                );
                $mail->Body = $customBody;

                $mail->send();
                $successCount++;

                // Enregistrer l'envoi de l'email dans la base de données
                $stmt = $pdo->prepare("INSERT INTO email_logs (questionnaire_id, template_id, subject, body, sent_at) VALUES (?, ?, ?, ?, NOW())");
                $stmt->execute([$clientInfo['questionnaire_id'], $template_id, $subject, $customBody]);

            } catch (Exception $e) {
                $failCount++;
                error_log("Erreur d'envoi d'email à {$clientInfo['email']} : " . $mail->ErrorInfo);
            }
        };

        if ($clients) {
            foreach ($clients as $clientInfo) {
                $sendEmail($clientInfo);
                sleep(2); // Attendre 2 secondes entre chaque envoi
            }
            $success = "Emails envoyés : $successCount. Échecs : $failCount.";
        } elseif ($client) {
            $sendEmail($client);
            $success = $successCount > 0 ? "Email envoyé avec succès" : "Échec de l'envoi de l'email";
        } else {
            $error = "Aucun destinataire spécifié";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Envoyer un email - Admin</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="../css/styles.css" rel="stylesheet">
    <script src="https://cdn.tiny.cloud/1/<?php echo TINY_API_KEY; ?>/tinymce/5/tinymce.min.js" referrerpolicy="origin"></script>
</head>
<body class="bg-gray-100 font-sans">
    <div class="flex">
        <?php include 'sidebar.php'; ?>

        <div id="main-content" class="flex-1 p-10">
            <h1 class="text-3xl font-bold mb-6">Envoyer un email <?php echo $clients ? 'en masse' : ''; ?></h1>
            
            <?php if ($error): ?>
                <div class="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative mb-4" role="alert">
                    <span class="block sm:inline"><?php echo htmlspecialchars($error); ?></span>
                </div>
            <?php endif; ?>

            <?php if ($success): ?>
                <div class="bg-green-100 border border-green-400 text-green-700 px-4 py-3 rounded relative mb-4" role="alert">
                    <span class="block sm:inline"><?php echo htmlspecialchars($success); ?></span>
                </div>
            <?php endif; ?>

            <form id="emailForm" method="POST" class="bg-white shadow-md rounded px-8 pt-6 pb-8 mb-4">
                <?php if ($client): ?>
                    <div class="mb-4">
                        <p class="text-gray-700 text-sm font-bold">Envoi à : <?php echo htmlspecialchars($client['prenom'] . ' ' . $client['nom'] . ' (' . $client['email'] . ')'); ?></p>
                    </div>
                <?php elseif ($clients): ?>
                    <div class="mb-4">
                        <p class="text-gray-700 text-sm font-bold">Envoi en masse à <?php echo count($clients); ?> destinataires</p>
                    </div>
                <?php endif; ?>
                <div class="mb-4">
                    <label class="block text-gray-700 text-sm font-bold mb-2" for="template_id">
                        Modèle d'email
                    </label>
                    <select id="template_id" name="template_id" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" required>
                        <option value="">Sélectionnez un modèle</option>
                        <?php foreach ($templates as $template): ?>
                            <option value="<?php echo $template['id']; ?>"><?php echo htmlspecialchars($template['name']); ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="mb-4">
                    <label class="block text-gray-700 text-sm font-bold mb-2" for="subject">
                        Sujet
                    </label>
                    <input class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" id="subject" type="text" name="subject" required>
                </div>
                <div class="mb-6">
                    <label class="block text-gray-700 text-sm font-bold mb-2" for="body">
                        Corps du message
                    </label>
                    <textarea id="body" name="body" class="hidden"></textarea>
                    <div id="bodyEditor" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm"></div>
                    <p class="text-sm text-gray-600 mt-2">
                        Utilisez [PRENOM], [NOM] et [DATE_SOUMISSION] pour personnaliser le message pour chaque destinataire.
                    </p>
                </div>
                <div class="flex items-center justify-between">
                    <button class="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline" type="submit">
                        Envoyer l'email
                    </button>
                    <a href="dashboard.php" class="inline-block align-baseline font-bold text-sm text-blue-500 hover:text-blue-800">
                        Annuler
                    </a>
                </div>
            </form>
        </div>
    </div>

    <script>
    tinymce.init({
        selector: '#bodyEditor',
        height: 300,
        plugins: 'link image code',
        toolbar: 'undo redo | formatselect | bold italic | alignleft aligncenter alignright | link image | code',
        setup: function(editor) {
            editor.on('change', function () {
                document.getElementById('body').value = editor.getContent();
            });
        }
    });

    document.getElementById('template_id').addEventListener('change', function() {
        const templateId = this.value;
        if (templateId) {
            fetch(`get_email_template.php?id=${templateId}`)
                .then(response => response.json())
                .then(data => {
                    document.getElementById('subject').value = data.subject;
                    tinymce.get('bodyEditor').setContent(data.body);
                    document.getElementById('body').value = data.body;
                })
                .catch(error => console.error('Error:', error));
        }
    });

    document.getElementById('emailForm').addEventListener('submit', function(e) {
        e.preventDefault();
        const editor = tinymce.get('bodyEditor');
        document.getElementById('body').value = editor.getContent();
        this.submit();
    });
    </script>
</body>
</html>