<?php
session_start();
require_once '../includes/db_connect.php';
require_once '../includes/functions.php';

if (!defined('SECURE_ACCESS')) {
    define('SECURE_ACCESS', true);
}
require_once __DIR__ . '/../d8f7g9h3j2k.php';

// Vérifier si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("Location: ../admin.php");
    exit;
}

// Récupérer les sections du questionnaire
$sections = getQuestionnaireStructure($pdo);

$totalAlerts = getTotalAlerts($pdo);

?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Tâches - Admin</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="../css/styles.css" rel="stylesheet">
    
</head>
<body class="bg-gray-100 font-sans">
    <div class="flex">
        <?php include 'sidebar.php'; ?>

        <div id="main-content" class="flex-1 p-10">
            <h1 class="text-3xl font-bold mb-6">Tâches</h1>
            
            <div class="mb-6">
                <p class="text-xl font-semibold">Nombre total d'alertes : <?php echo $totalAlerts; ?></p>
            </div>
            
            <?php foreach ($sections as $section => $subSections): ?>
            <div class="mb-10">
                <h2 class="text-2xl font-semibold mb-4"><?php echo htmlspecialchars($section); ?></h2>
                <table class="min-w-full bg-white shadow-md rounded-lg overflow-hidden">
                    <thead class="bg-gray-100">
                        <tr>
                            <th class="w-1/4 px-4 py-2 text-left text-sm font-semibold text-gray-700">Tag</th>
                            <th class="w-1/6 px-4 py-2 text-left text-sm font-semibold text-gray-700">Nombre</th>
                            <th class="w-7/12 px-4 py-2 text-left text-sm font-semibold text-gray-700">Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $tags = getTagsForSectionWithCount($pdo, $section);
                        foreach ($tags as $tag):
                            $isAlerted = isTagAlerted($tag['count']);
                        ?>
                            <tr class="<?php echo $isAlerted ? 'bg-red-100' : ''; ?>">
                                <td class="px-4 py-2">
                                    <?php
                                    if ($section == 'Chambre' && isset($tag['numero_chambre'])) {
                                        echo htmlspecialchars($tag['tag']) . ' - Chambre ' . htmlspecialchars($tag['numero_chambre']);
                                    } else {
                                        echo htmlspecialchars($tag['tag']);
                                    }
                                    ?>
                                </td>
                                <td class="px-4 py-2"><?php echo $tag['count']; ?></td>
                                <td class="px-4 py-2">
                                    <div class="flex items-center space-x-2">
                                        <button onclick="showTasks(<?php echo $tag['id']; ?>)" class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-1 px-3 rounded text-sm">
                                            Voir les tâches
                                        </button>
                                        <?php if ($isAlerted): ?>
                                            <button onclick="sendBulkMail(<?php echo $tag['id']; ?>)" class="bg-yellow-500 hover:bg-yellow-600 text-white font-bold py-1 px-3 rounded text-sm">
                                                Envoyer e-mails
                                            </button>
                                            <button onclick="showDateCleModal(<?php echo $tag['id']; ?>, '<?php echo $section; ?>', '<?php echo $tag['numero_chambre'] ?? ''; ?>')" class="bg-green-500 hover:bg-green-600 text-white font-bold py-1 px-3 rounded text-sm">
                                                Créer une date clé
                                            </button>
                                        <?php endif; ?>
                                        <a href="generate_tasks_pdf.php?tag_id=<?php echo $tag['id']; ?>" title="Télécharger PDF" class="text-blue-600 hover:text-blue-900">
                                            <svg class="w-5 h-5 inline-block" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                                                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 10v6m0 0l-3-3m3 3l3-3m2 8H7a2 2 0 01-2-2V5a2 2 0 012-2h5.586a1 1 0 01.707.293l5.414 5.414a1 1 0 01.293.707V19a2 2 0 01-2 2z"></path>
                                            </svg>
                                        </a>
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
            <?php endforeach; ?>
        </div>
    </div>

    <!-- Modal pour les messages -->
    <div id="messageModal" class="modal">
        <div class="modal-content">
            <p id="modalMessage"></p>
            <button onclick="closeModal('messageModal')" class="mt-4 bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded">
                Fermer
            </button>
        </div>
    </div>

    <!-- Modal pour afficher les tâches -->
    <div id="tasksModal" class="modal">
        <div class="modal-content w-11/12 max-w-7xl">
            <h3 class="text-lg font-semibold mb-4">Tâches associées</h3>
            <div id="tasksModalContent" class="overflow-x-auto"></div>
            <button onclick="closeModal('tasksModal')" class="mt-4 bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded">
                Fermer
            </button>
        </div>
    </div>

    <!-- Modal pour créer une date clé -->
    <div id="dateCleModal" class="modal">
        <div class="modal-content">
            <h3 class="text-lg font-semibold mb-4">Créer une date clé</h3>
            <form id="dateCleForm" class="space-y-4">
                <input type="hidden" id="tagId" name="tagId">
                <div>
                    <label for="description" class="block text-sm font-medium text-gray-700">Description</label>
                    <input type="text" id="description" name="description" required class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                </div>
                <div>
                    <label for="date" class="block text-sm font-medium text-gray-700">Date</label>
                    <input type="date" id="date" name="date" required class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                </div>
                <div>
                    <label for="section" class="block text-sm font-medium text-gray-700">Section</label>
                    <input type="text" id="section" name="section" readonly class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                </div>
                <div>
                    <label for="sous_section" class="block text-sm font-medium text-gray-700">Sous-section</label>
                    <input type="text" id="sous_section" name="sous_section" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                </div>
                <div>
                    <label for="numero_chambre" class="block text-sm font-medium text-gray-700">Numéro de chambre</label>
                    <input type="text" id="numero_chambre" name="numero_chambre" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50">
                </div>
                <button type="submit" class="w-full bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded">
                    Créer la date clé
                </button>
            </form>
            <button onclick="closeModal('dateCleModal')" class="mt-4 bg-gray-500 hover:bg-gray-700 text-white font-bold py-2 px-4 rounded">
                Annuler
            </button>
        </div>
    </div>

    <script>
    function showTasks(tagId) {
        fetch(`get_tasks_for_tag.php?tag_id=${tagId}`)
            .then(response => response.json())
            .then(tasks => {
                const modalContent = document.getElementById('tasksModalContent');
                modalContent.innerHTML = '';
                if (tasks.length > 0) {
                    const table = document.createElement('table');
                    table.className = 'min-w-full divide-y divide-gray-200';
                    table.innerHTML = `
                        <thead>
                            <tr>
                                <th class="px-4 py-2 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Date</th>
                                <th class="px-4 py-2 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Client</th>
                                <th class="px-4 py-2 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Chambre</th>
                                <th class="px-4 py-2 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Section</th>
                                <th class="px-4 py-2 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Note</th>
                                <th class="px-4 py-2 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Remarque</th>
                                <th class="px-4 py-2 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Commentaire</th>
                            </tr>
                        </thead>
                        <tbody class="bg-white divide-y divide-gray-200">
                            ${tasks.map(task => `
                                <tr>
                                    <td class="px-4 py-2 whitespace-nowrap">${new Date(task.date_creation).toLocaleDateString()}</td>
                                    <td class="px-4 py-2 whitespace-nowrap">${task.prenom} ${task.nom}</td>
                                    <td class="px-4 py-2 whitespace-nowrap">${task.numero_chambre}</td>
                                    <td class="px-4 py-2 whitespace-nowrap">${task.section} - ${task.sous_section}</td>
                                    <td class="px-4 py-2 whitespace-nowrap">${task.note}/5</td>
                                    <td class="px-4 py-2 whitespace-normal">${task.remarque}</td>
                                    <td class="px-4 py-2 whitespace-normal">${task.commentaire || 'Aucun commentaire'}</td>
                                </tr>
                            `).join('')}
                        </tbody>
                    `;
                    modalContent.appendChild(table);
                } else {
                    modalContent.textContent = 'Aucune tâche associée à ce tag.';
                }
                document.getElementById('tasksModal').style.display = 'flex';
            })
            .catch(error => console.error('Error:', error));
    }

    function sendBulkMail(tagId) {
        fetch(`send_bulk_mail.php?tag_id=${tagId}`)
            .then(response => response.json())
            .then(data => {
                if (data.error) {
                    showModal(data.error);
                } else if (data.success) {
                    window.location.href = `send_email.php?bulk_emails=${data.emails.join(',')}&tag_id=${tagId}`;
                }
            })
            .catch(error => {
                console.error('Error:', error);
                showModal('Une erreur est survenue lors de la récupération des emails.');
            });
    }

    function showDateCleModal(tagId, section, numeroChambre) {
        document.getElementById('tagId').value = tagId;
        document.getElementById('section').value = section;
        document.getElementById('date').value = new Date().toISOString().split('T')[0];
        if (section === 'Chambre') {
            document.getElementById('numero_chambre').value = numeroChambre || '';
        } else {
            document.getElementById('numero_chambre').value = '';
        }
        document.getElementById('dateCleModal').style.display = 'flex';
    }

    function showModal(message) {
        document.getElementById('modalMessage').textContent = message;
        document.getElementById('messageModal').style.display = 'flex';
    }

    function closeModal(modalId) {
        document.getElementById(modalId).style.display = 'none';
    }

    document.getElementById('dateCleForm').addEventListener('submit', function(e) {
        e.preventDefault();
        const formData = new FormData(this);
        fetch('create_date_cle.php', {
            method: 'POST',
            body: formData
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                showModal('Date clé créée avec succès');
                closeModal('dateCleModal');
                // Vous pouvez ajouter ici un rechargement de la page ou une mise à jour dynamique du tableau
            } else {
                showModal('Erreur lors de la création de la date clé: ' + data.message);
            }
        })
        .catch(error => {
            console.error('Error:', error);
            showModal('Une erreur est survenue lors de la création de la date clé');
        });
    });

    // Fermer les modales si on clique en dehors
    window.onclick = function(event) {
        if (event.target.className === 'modal') {
            event.target.style.display = 'none';
        }
    }
    </script>
</body>
</html>