<?php
session_start();
define('SECURE_ACCESS', true);
require_once __DIR__ . '/d8f7g9h3j2k.php';
require_once 'includes/db_connect.php';
require_once 'includes/functions.php';

if (!isset($_SESSION['questionnaire_id'])) {
    header("Location: index.php");
    exit;
}

$error = '';
$success = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $prenom = trim($_POST['prenom'] ?? '');
    $nom = trim($_POST['nom'] ?? '');
    $email = trim($_POST['email'] ?? '');
    $date_arrivee = $_POST['date_arrivee'] ?? '';
    $date_depart = $_POST['date_depart'] ?? '';
    $numero_chambre = trim($_POST['numero_chambre'] ?? '');

    if (empty($prenom) || empty($nom) || empty($email) || empty($date_arrivee) || empty($date_depart) || empty($numero_chambre)) {
        $error = "Veuillez remplir tous les champs obligatoires.";
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $error = "L'adresse email n'est pas valide.";
    } else {
        $pdo->beginTransaction();
        try {
            $stmt = $pdo->prepare("INSERT INTO clients (prenom, nom, email, date_arrivee, date_depart, numero_chambre) VALUES (?, ?, ?, ?, ?, ?)");
            $stmt->execute([$prenom, $nom, $email, $date_arrivee, $date_depart, $numero_chambre]);
            $client_id = $pdo->lastInsertId();

            $stmt = $pdo->prepare("UPDATE questionnaires SET client_id = ? WHERE id = ?");
            $stmt->execute([$client_id, $_SESSION['questionnaire_id']]);

            $pdo->commit();
            unset($_SESSION['questionnaire_id']);
            $success = "Informations enregistrées avec succès";
        } catch (Exception $e) {
            $pdo->rollBack();
            $error = "Une erreur est survenue lors de l'enregistrement des informations.";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Informations client</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="css/styles.css" rel="stylesheet">
</head>
<body class="bg-gray-100 font-sans">
    <div class="container mx-auto px-4 py-8">
        <div class="max-w-xl mx-auto bg-white shadow-lg rounded-lg overflow-hidden">
            <div class="p-8">
                <h1 class="text-3xl font-bold mb-6 text-center text-gray-800">Informations client</h1>
                <?php if ($error): ?>
                    <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-6" role="alert">
                        <p><?php echo htmlspecialchars($error); ?></p>
                    </div>
                <?php endif; ?>
                <?php if ($success): ?>
                    <div id="successMessage" class="bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-6" role="alert">
                        <p><?php echo htmlspecialchars($success); ?></p>
                    </div>
                    <script>
                        setTimeout(function() {
                            window.location.href = 'index.php';
                        }, 3000); // Redirection après 3 secondes
                    </script>
                <?php else: ?>
                    <form id="clientInfoForm" method="POST" action="" class="space-y-6">
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                            <div>
                                <label for="prenom" class="block text-sm font-medium text-gray-700 mb-1">Prénom</label>
                                <input type="text" id="prenom" name="prenom" required class="w-full px-4 py-2 border border-gray-300 rounded-md shadow-sm focus:ring-2 focus:ring-blue-500 focus:border-blue-500">
                            </div>
                            <div>
                                <label for="nom" class="block text-sm font-medium text-gray-700 mb-1">Nom</label>
                                <input type="text" id="nom" name="nom" required class="w-full px-4 py-2 border border-gray-300 rounded-md shadow-sm focus:ring-2 focus:ring-blue-500 focus:border-blue-500">
                            </div>
                        </div>
                        <div>
                            <label for="email" class="block text-sm font-medium text-gray-700 mb-1">Email</label>
                            <input type="email" id="email" name="email" required class="w-full px-4 py-2 border border-gray-300 rounded-md shadow-sm focus:ring-2 focus:ring-blue-500 focus:border-blue-500">
                        </div>
                        <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                            <div>
                                <label for="date_arrivee" class="block text-sm font-medium text-gray-700 mb-1">Date d'arrivée</label>
                                <input type="date" id="date_arrivee" name="date_arrivee" required class="w-full px-4 py-2 border border-gray-300 rounded-md shadow-sm focus:ring-2 focus:ring-blue-500 focus:border-blue-500">
                            </div>
                            <div>
                                <label for="date_depart" class="block text-sm font-medium text-gray-700 mb-1">Date de départ</label>
                                <input type="date" id="date_depart" name="date_depart" required class="w-full px-4 py-2 border border-gray-300 rounded-md shadow-sm focus:ring-2 focus:ring-blue-500 focus:border-blue-500">
                            </div>
                        </div>
                        <div>
                            <label for="numero_chambre" class="block text-sm font-medium text-gray-700 mb-1">Numéro de chambre</label>
                            <input type="text" id="numero_chambre" name="numero_chambre" required class="w-full px-4 py-2 border border-gray-300 rounded-md shadow-sm focus:ring-2 focus:ring-blue-500 focus:border-blue-500">
                        </div>
                        <div class="text-center">
                            <button type="submit" id="submitButton" class="w-full bg-blue-600 hover:bg-blue-700 text-white font-bold py-3 px-4 rounded-md focus:outline-none focus:shadow-outline transition duration-300 ease-in-out transform hover:-translate-y-1 hover:scale-105">
                                Enregistrer les informations
                            </button>
                        </div>
                    </form>
                <?php endif; ?>
            </div>
        </div>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        const form = document.getElementById('clientInfoForm');
        const submitButton = document.getElementById('submitButton');
        const requiredInputs = form.querySelectorAll('input[required]');

        function checkFormValidity() {
            let isValid = true;
            requiredInputs.forEach(input => {
                if (!input.value.trim()) {
                    isValid = false;
                }
            });
            return isValid;
        }

        function updateButtonState() {
            const isValid = checkFormValidity();
            submitButton.disabled = !isValid;
            submitButton.classList.toggle('opacity-50', !isValid);
            submitButton.classList.toggle('cursor-not-allowed', !isValid);
        }

        if (form && submitButton) {
            requiredInputs.forEach(input => {
                input.addEventListener('input', updateButtonState);
            });

            form.addEventListener('submit', function(event) {
                if (!checkFormValidity()) {
                    event.preventDefault();
                    alert('Veuillez remplir tous les champs obligatoires.');
                }
            });

            // Initialiser l'état du bouton au chargement de la page
            updateButtonState();
        }
    });
    </script>
</body>
</html>