<?php
// File: includes/functions.php
// NOUVELLES FONCTIONS À AJOUTER
function calculateScore($note) {
    switch ($note) {
        case 1:
            return -30;
        case 2:
            return -15;
        case 3:
            return 1;
        case 4:
            return 2;
        case 5:
            return 5;
        default:
            return 0;
    }
}

function calculateAverageScore($scores) {
    if (empty($scores)) {
        return 0;
    }
    
    $totalScore = 0;
    $count = 0;
    
    foreach ($scores as $score) {
        if ($score !== null) {
            $totalScore += calculateScore($score);
            $count++;
        }
    }
    
    return $count > 0 ? round($totalScore / $count, 2) : 0;
}

function normalizeScoreToFiveStars($score) {
    // Le score minimum théorique est -30
    // Le score maximum théorique est 5
    $minScore = -30;
    $maxScore = 5;
    
    // Normaliser sur une échelle de 1 à 5
    $normalized = 1 + (($score - $minScore) * 4) / ($maxScore - $minScore);
    
    // Arrondir à 2 décimales
    return round($normalized, 2);
}

function sanitizeForId($input) {
    return preg_replace('/[^a-z0-9_]/i', '_', strtolower($input));
}

function getQuestionnaireStructure($pdo) {
    $stmt = $pdo->query("SELECT * FROM structure_questionnaire WHERE active = 1 ORDER BY ordre");
    $structure = [];
    while ($row = $stmt->fetch()) {
        if (!isset($structure[$row['section']])) {
            $structure[$row['section']] = [];
        }
        $structure[$row['section']][] = $row['sous_section'];
    }
    return $structure;
}

function createNotification($pdo, $questionnaire_id, $section, $sous_section, $note) {
    if ($note !== '' && $note <= 2) {
        $stmt = $pdo->prepare("INSERT INTO notifications (questionnaire_id, section, sous_section, note) VALUES (?, ?, ?, ?)");
        $stmt->execute([$questionnaire_id, $section, $sous_section, $note]);
    }
}

function logQuestionnaireAction($pdo, $user_id, $action, $details) {
    $stmt = $pdo->prepare("INSERT INTO historique_questionnaire (user_id, action, details) VALUES (?, ?, ?)");
    $stmt->execute([$user_id, $action, $details]);
}

function getNotificationCount($pdo) {
    $stmt = $pdo->query("SELECT COUNT(*) FROM notifications WHERE status != 'traitee'");
    return $stmt->fetchColumn();
}

function getAlertCount($pdo) {
    $stmt = $pdo->query("
        SELECT COUNT(DISTINCT st.tag) 
        FROM (
            SELECT tt.tag_id, COUNT(*) as count
            FROM tags_taches tt
            GROUP BY tt.tag_id
            HAVING COUNT(*) >= 10
        ) as frequent_tags
        JOIN section_tags st ON frequent_tags.tag_id = st.id
        WHERE st.resolved = FALSE
    ");
    return $stmt->fetchColumn();
}

function escapeHtml($unsafe) {
    return htmlspecialchars($unsafe, ENT_QUOTES | ENT_HTML5, 'UTF-8');
}

function escapeJs($string) {
    return str_replace("'", "\\'", $string);
}

function getTagsForSection($pdo, $section) {
    $stmt = $pdo->prepare("SELECT id, tag FROM section_tags WHERE section = ? AND active = TRUE ORDER BY tag");
    $stmt->execute([$section]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function getAllTags($pdo) {
    $stmt = $pdo->query("SELECT id, tag, section FROM section_tags WHERE active = TRUE ORDER BY section, tag");
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function getTagsForSectionWithCount($pdo, $section) {
    $isHotel = $section === 'Chambre' ? 1 : 0;
    $query = "
        SELECT st.id, st.tag, COUNT(DISTINCT tt.tache_id) as count,
               CASE WHEN ? = 1 THEN c.numero_chambre ELSE NULL END as numero_chambre
        FROM section_tags st
        LEFT JOIN tags_taches tt ON st.id = tt.tag_id
        LEFT JOIN taches t ON tt.tache_id = t.id
        LEFT JOIN notifications n ON t.notification_id = n.id
        LEFT JOIN questionnaires q ON n.questionnaire_id = q.id
        LEFT JOIN clients c ON q.client_id = c.id
        WHERE st.section = ?
        GROUP BY st.id, st.tag, 
                 CASE WHEN ? = 1 THEN c.numero_chambre ELSE NULL END
        ORDER BY count DESC, st.tag ASC
    ";
    $stmt = $pdo->prepare($query);
    $stmt->execute([$isHotel, $section, $isHotel]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function getTasksForTag($pdo, $tagId) {
    $query = "
        SELECT 
            t.id, t.remarque, t.date_creation, t.status, 
            n.section, n.sous_section, n.note,
            q.id as questionnaire_id,
            c.prenom, c.nom, c.numero_chambre,
            cs.commentaire,
            GROUP_CONCAT(DISTINCT st.tag) as tags
        FROM 
            taches t
        JOIN 
            tags_taches tt ON t.id = tt.tache_id
        JOIN 
            notifications n ON t.notification_id = n.id
        JOIN 
            questionnaires q ON n.questionnaire_id = q.id
        JOIN 
            clients c ON q.client_id = c.id
        LEFT JOIN
            commentaires_sections cs ON q.id = cs.questionnaire_id AND n.section = cs.section
        LEFT JOIN
            section_tags st ON tt.tag_id = st.id
        WHERE 
            tt.tag_id = :tag_id
        GROUP BY 
            t.id, t.remarque, t.date_creation, t.status, n.section, n.sous_section, n.note,
            q.id, c.prenom, c.nom, c.numero_chambre, cs.commentaire
        ORDER BY 
            t.date_creation DESC
    ";
    
    $stmt = $pdo->prepare($query);
    $stmt->execute(['tag_id' => $tagId]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function isTagAlerted($count) {
    return $count >= 10;
}

function getTotalAlerts($pdo) {
    $query = "
        SELECT COUNT(*) as alert_count
        FROM (
            SELECT COUNT(*) as tag_count
            FROM tags_taches tt
            JOIN section_tags st ON tt.tag_id = st.id
            GROUP BY st.id
            HAVING tag_count >= 10
        ) as alerted_tags
    ";
    $stmt = $pdo->query($query);
    return $stmt->fetchColumn();
}

function addTag($pdo, $section, $tag) {
    try {
        $stmt = $pdo->prepare("INSERT INTO section_tags (section, tag, active) VALUES (:section, :tag, TRUE)");
        $result = $stmt->execute([
            ':section' => $section,
            ':tag' => $tag
        ]);
        if (!$result) {
            return ['success' => false, 'error' => $stmt->errorInfo()];
        }
        return ['success' => true];
    } catch (PDOException $e) {
        return ['success' => false, 'error' => $e->getMessage()];
    }
}

function deleteTag($pdo, $section, $tag) {
    $stmt = $pdo->prepare("DELETE FROM section_tags WHERE section = :section AND tag = :tag");
    return $stmt->execute([
        ':section' => $section,
        ':tag' => $tag
    ]);
}

function editTag($pdo, $section, $oldTag, $newTag) {
    $stmt = $pdo->prepare("UPDATE section_tags SET tag = :newTag WHERE section = :section AND tag = :oldTag");
    return $stmt->execute([
        ':newTag' => $newTag,
        ':section' => $section,
        ':oldTag' => $oldTag
    ]);
}

function getTaches($pdo, $section = null, $subSection = null, $tags = []) {
    $query = "
        SELECT 
            t.id, t.remarque, t.date_creation, t.status,
            n.section, n.sous_section, n.note,
            q.id as questionnaire_id,
            c.prenom, c.nom, c.numero_chambre,
            cs.commentaire,
            GROUP_CONCAT(DISTINCT st.tag) as tags
        FROM 
            taches t
        JOIN 
            notifications n ON t.notification_id = n.id
        JOIN 
            questionnaires q ON n.questionnaire_id = q.id
        JOIN 
            clients c ON q.client_id = c.id
        LEFT JOIN
            commentaires_sections cs ON q.id = cs.questionnaire_id AND n.section = cs.section
        LEFT JOIN
            tags_taches tt ON t.id = tt.tache_id
        LEFT JOIN
            section_tags st ON tt.tag_id = st.id
        WHERE 1=1
    ";
    $params = [];
    
    if ($section) {
        $query .= " AND n.section = ?";
        $params[] = $section;
        if ($subSection) {
            $query .= " AND n.sous_section = ?";
            $params[] = $subSection;
        }
    }
    
    if (!empty($tags)) {
        $placeholders = implode(',', array_fill(0, count($tags), '?'));
        $query .= " AND t.id IN (SELECT DISTINCT tache_id FROM tags_taches WHERE tag_id IN ($placeholders))";
        $params = array_merge($params, $tags);
    }
    
    $query .= " GROUP BY t.id ORDER BY t.date_creation DESC";
    
    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function updateTaskStatus($pdo, $taskId, $newStatus) {
    $stmt = $pdo->prepare("UPDATE taches SET status = ? WHERE id = ?");
    return $stmt->execute([$newStatus, $taskId]);
}

function getAnalyticsData($pdo, $start_date, $end_date) {
    // Calculer les vraies moyennes avec la nouvelle pondération
    $subSectionAverages = getSubSectionAverages($pdo, $start_date, $end_date);
    $sectionAverages = [];
    
    // Regrouper par section et calculer les moyennes des sections
    foreach ($subSectionAverages as $data) {
        if (!isset($sectionAverages[$data['section']])) {
            $sectionAverages[$data['section']] = [
                'section' => $data['section'],
                'moyenne' => 0,
                'count' => 0,
            ];
        }
        $sectionAverages[$data['section']]['moyenne'] += $data['moyenne'];
        $sectionAverages[$data['section']]['count']++;
    }

    // Calculer la moyenne finale pour chaque section
    foreach ($sectionAverages as &$section) {
        $section['moyenne'] = $section['count'] > 0 ? 
            round($section['moyenne'] / $section['count'], 2) : 0;
    }

    return [
        'globalAverage' => getGlobalAverage($pdo, $start_date, $end_date),
        'noteEvolution' => getNoteEvolution($pdo, $start_date, $end_date),
        'roomRatings' => getAverageRoomRatings($pdo, $start_date, $end_date),
        'subSectionAverages' => $subSectionAverages,
        'sectionAverages' => array_values($sectionAverages)
    ];
}

function getGlobalAverage($pdo, $start_date, $end_date) {
    $stmt = $pdo->prepare("
        SELECT 
            COUNT(CASE WHEN n.note = 1 THEN 1 END) as one_star,
            COUNT(CASE WHEN n.note = 2 THEN 1 END) as two_stars,
            COUNT(CASE WHEN n.note = 3 THEN 1 END) as three_stars,
            COUNT(CASE WHEN n.note = 4 THEN 1 END) as four_stars,
            COUNT(CASE WHEN n.note = 5 THEN 1 END) as five_stars
        FROM notes_sous_sections n
        JOIN questionnaires q ON n.questionnaire_id = q.id
        WHERE q.date_soumission BETWEEN :start_date AND :end_date
        AND n.note IS NOT NULL
    ");
    $stmt->execute(['start_date' => $start_date, 'end_date' => $end_date]);
    $result = $stmt->fetch(PDO::FETCH_ASSOC);
    
    $total_points = 
        ($result['one_star'] * -30) +
        ($result['two_stars'] * -15) +
        ($result['three_stars'] * 1) +
        ($result['four_stars'] * 2) +
        ($result['five_stars'] * 5);
    
    $total_notes = 
        $result['one_star'] +
        $result['two_stars'] +
        $result['three_stars'] +
        $result['four_stars'] +
        $result['five_stars'];
    
    return $total_notes > 0 ? round($total_points / $total_notes, 2) : 0;
}

function getNoteEvolution($pdo, $start_date, $end_date) {
    $stmt = $pdo->prepare("
        SELECT 
            DATE(q.date_soumission) as date,
            n.section,
            n.sous_section,
            AVG(n.note) as moyenne
        FROM 
            notes_sous_sections n
        JOIN 
            questionnaires q ON n.questionnaire_id = q.id
        WHERE
            q.date_soumission BETWEEN :start_date AND :end_date
            AND n.note IS NOT NULL
        GROUP BY 
            DATE(q.date_soumission), n.section, n.sous_section
        ORDER BY 
            DATE(q.date_soumission), n.section, n.sous_section
    ");
    $stmt->execute(['start_date' => $start_date, 'end_date' => $end_date]);
    $results = $stmt->fetchAll(PDO::FETCH_ASSOC);

    $evolution = [];
    foreach ($results as $row) {
        if (!isset($evolution[$row['date']])) {
            $evolution[$row['date']] = ['date' => $row['date'], 'sections' => []];
        }
        if (!isset($evolution[$row['date']]['sections'][$row['section']])) {
            $evolution[$row['date']]['sections'][$row['section']] = [];
        }
        $evolution[$row['date']]['sections'][$row['section']][$row['sous_section']] = floatval($row['moyenne']);
    }

    return array_values($evolution);
}

function getAverageRoomRatings($pdo, $start_date, $end_date) {
    $query = "
        WITH RoomNotes AS (
            SELECT 
                c.numero_chambre,
                COUNT(CASE WHEN n.note = 1 THEN 1 END) as one_star,
                COUNT(CASE WHEN n.note = 2 THEN 1 END) as two_stars,
                COUNT(CASE WHEN n.note = 3 THEN 1 END) as three_stars,
                COUNT(CASE WHEN n.note = 4 THEN 1 END) as four_stars,
                COUNT(CASE WHEN n.note = 5 THEN 1 END) as five_stars
            FROM notes_sous_sections n
            JOIN questionnaires q ON n.questionnaire_id = q.id
            JOIN clients c ON q.client_id = c.id
            WHERE q.date_soumission BETWEEN :start_date AND :end_date
            AND c.numero_chambre IS NOT NULL
            GROUP BY c.numero_chambre
        )
        SELECT 
            numero_chambre,
            ROUND(
                CAST(
                    ((-30 * one_star) + (-15 * two_stars) + (1 * three_stars) + (2 * four_stars) + (5 * five_stars))
                    AS DECIMAL(10,6)
                ) / 
                NULLIF((one_star + two_stars + three_stars + four_stars + five_stars), 0)
            , 2) as moyenne
        FROM RoomNotes
        ORDER BY moyenne DESC
    ";
    
    $stmt = $pdo->prepare($query);
    $stmt->execute(['start_date' => $start_date, 'end_date' => $end_date]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Modifier la fonction dans functions.php
function getSubSectionAverages($pdo, $start_date, $end_date, $room_number = null) {
    $query = "
        WITH NotesData AS (
            SELECT 
                n.section,
                n.sous_section,
                COUNT(DISTINCT CASE WHEN n.note = 1 THEN q.id END) as one_star,
                COUNT(DISTINCT CASE WHEN n.note = 2 THEN q.id END) as two_stars,
                COUNT(DISTINCT CASE WHEN n.note = 3 THEN q.id END) as three_stars,
                COUNT(DISTINCT CASE WHEN n.note = 4 THEN q.id END) as four_stars,
                COUNT(DISTINCT CASE WHEN n.note = 5 THEN q.id END) as five_stars
            FROM 
                notes_sous_sections n
            JOIN 
                questionnaires q ON n.questionnaire_id = q.id
            LEFT JOIN 
                clients c ON q.client_id = c.id
            WHERE
                q.date_soumission BETWEEN :start_date AND :end_date
    ";
    
    $params = [
        'start_date' => $start_date,
        'end_date' => $end_date
    ];

    if ($room_number !== null) {
        $query .= " AND c.numero_chambre = :room_number";
        $params['room_number'] = $room_number;
    }

    $query .= "
            GROUP BY 
                n.section, n.sous_section
        )
        SELECT 
            nd.*,
            ROUND(
                CAST(
                    ((-30 * one_star) + (-15 * two_stars) + (1 * three_stars) + (2 * four_stars) + (5 * five_stars))
                    AS DECIMAL(10,6)
                ) / 
                NULLIF((one_star + two_stars + three_stars + four_stars + five_stars), 0)
            , 2) as score
        FROM NotesData nd
        ORDER BY 
            section ASC,
            score DESC
    ";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $results = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Ajouter le nombre total de notes pour chaque sous-section
    foreach ($results as &$result) {
        $result['total_notes'] = 
            $result['one_star'] + 
            $result['two_stars'] + 
            $result['three_stars'] + 
            $result['four_stars'] + 
            $result['five_stars'];

        $result['moyenne'] = $result['score']; // On utilise directement le score calculé
    }

    return $results;
}


// Nouvelle fonction pour obtenir les détails des notes
function getStarDetails($pdo, $section, $sous_section, $note, $start_date, $end_date) {
    $query = "
        SELECT DISTINCT
            c.prenom,
            c.nom,
            c.numero_chambre,
            c.date_arrivee,
            c.date_depart,
            q.date_soumission,
            n.note,
            cs.commentaire
        FROM 
            notes_sous_sections n
        JOIN 
            questionnaires q ON n.questionnaire_id = q.id
        JOIN 
            clients c ON q.client_id = c.id
        LEFT JOIN
            commentaires_sections cs ON q.id = cs.questionnaire_id 
            AND cs.section = n.section
        WHERE 
            n.section = :section
            AND n.sous_section = :sous_section
            AND n.note = :note
            AND q.date_soumission BETWEEN :start_date AND :end_date
        GROUP BY 
            q.id, c.id, c.prenom, c.nom, c.numero_chambre, 
            c.date_arrivee, c.date_depart, q.date_soumission,
            n.note, cs.commentaire
        ORDER BY 
            q.date_soumission DESC
    ";
    
    $stmt = $pdo->prepare($query);
    $stmt->execute([
        'section' => $section,
        'sous_section' => $sous_section,
        'note' => $note,
        'start_date' => $start_date,
        'end_date' => $end_date
    ]);
    
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function getSectionAverages($pdo, $start_date, $end_date) {
    $query = "
        WITH SectionNotes AS (
            SELECT 
                n.section,
                COUNT(CASE WHEN n.note = 1 THEN 1 END) as one_star,
                COUNT(CASE WHEN n.note = 2 THEN 1 END) as two_stars,
                COUNT(CASE WHEN n.note = 3 THEN 1 END) as three_stars,
                COUNT(CASE WHEN n.note = 4 THEN 1 END) as four_stars,
                COUNT(CASE WHEN n.note = 5 THEN 1 END) as five_stars
            FROM notes_sous_sections n
            JOIN questionnaires q ON n.questionnaire_id = q.id
            WHERE q.date_soumission BETWEEN :start_date AND :end_date
            GROUP BY n.section
        )
        SELECT 
            section,
            ROUND(
                CAST(
                    ((-30 * one_star) + (-15 * two_stars) + (1 * three_stars) + (2 * four_stars) + (5 * five_stars))
                    AS DECIMAL(10,6)
                ) / 
                NULLIF((one_star + two_stars + three_stars + four_stars + five_stars), 0)
            , 2) as moyenne
        FROM SectionNotes
        ORDER BY moyenne DESC
    ";
    
    $stmt = $pdo->prepare($query);
    $stmt->execute(['start_date' => $start_date, 'end_date' => $end_date]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function getNoteTrends($pdo, $start_date, $end_date) {
    $mid_date = date('Y-m-d', strtotime($start_date . ' + ' . floor((strtotime($end_date) - strtotime($start_date)) / 2) . ' seconds'));
    
    $query = "
        WITH PeriodNotes AS (
            SELECT 
                n.section,
                CASE 
                    WHEN q.date_soumission < :mid_date THEN 'first_half'
                    ELSE 'second_half'
                END as period,
                COUNT(CASE WHEN n.note = 1 THEN 1 END) as one_star,
                COUNT(CASE WHEN n.note = 2 THEN 1 END) as two_stars,
                COUNT(CASE WHEN n.note = 3 THEN 1 END) as three_stars,
                COUNT(CASE WHEN n.note = 4 THEN 1 END) as four_stars,
                COUNT(CASE WHEN n.note = 5 THEN 1 END) as five_stars
            FROM notes_sous_sections n
            JOIN questionnaires q ON n.questionnaire_id = q.id
            WHERE q.date_soumission BETWEEN :start_date AND :end_date
            GROUP BY n.section, period
        )
        SELECT 
            section,
            MAX(CASE 
                WHEN period = 'first_half' 
                THEN ROUND(
                    CAST(
                        ((-30 * one_star) + (-15 * two_stars) + (1 * three_stars) + (2 * four_stars) + (5 * five_stars))
                        AS DECIMAL(10,6)
                    ) / 
                    NULLIF((one_star + two_stars + three_stars + four_stars + five_stars), 0)
                , 2)
            END) as premiere_moitie,
            MAX(CASE 
                WHEN period = 'second_half' 
                THEN ROUND(
                    CAST(
                        ((-30 * one_star) + (-15 * two_stars) + (1 * three_stars) + (2 * four_stars) + (5 * five_stars))
                        AS DECIMAL(10,6)
                    ) / 
                    NULLIF((one_star + two_stars + three_stars + four_stars + five_stars), 0)
                , 2)
            END) as deuxieme_moitie
        FROM PeriodNotes
        GROUP BY section
    ";
    
    $stmt = $pdo->prepare($query);
    $stmt->execute([
        'start_date' => $start_date,
        'end_date' => $end_date,
        'mid_date' => $mid_date
    ]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function getBeforeAfterData($pdo, $date_cle_id) {
    $stmt = $pdo->prepare("SELECT date, section, sous_section, numero_chambre FROM dates_cles WHERE id = ?");
    $stmt->execute([$date_cle_id]);
    $date_cle = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$date_cle) {
        return null;
    }

    $date = $date_cle['date'];
    $section = $date_cle['section'];
    $sous_section = $date_cle['sous_section'];
    $numero_chambre = $date_cle['numero_chambre'];

    $start_date = date('Y-m-d', strtotime($date . ' -3 months'));
    $end_date = date('Y-m-d', strtotime($date . ' +3 months'));

    $query = "
    SELECT
        CASE 
            WHEN DATE(q.date_soumission) < :date THEN 'before'
            ELSE 'after'
        END as period,
        AVG(n.note) as average,
        COUNT(*) as count
    FROM
        questionnaires q
    JOIN
        notes_sous_sections n ON q.id = n.questionnaire_id
    JOIN
        clients c ON q.client_id = c.id
    WHERE
        q.date_soumission IS NOT NULL
        AND n.section = :section
        AND q.date_soumission BETWEEN :start_date AND :end_date
    ";

    $params = [
        'date' => $date,
        'section' => $section,
        'start_date' => $start_date,
        'end_date' => $end_date
    ];

    if ($section == 'Chambre' && !empty($numero_chambre)) {
        $query .= " AND c.numero_chambre = :numero_chambre";
        $params['numero_chambre'] = $numero_chambre;
    } elseif (!empty($sous_section)) {
        $query .= " AND n.sous_section = :sous_section";
        $params['sous_section'] = $sous_section;
    }

    $query .= " GROUP BY period";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);

    $results = $stmt->fetchAll(PDO::FETCH_ASSOC);

    $before = null;
    $after = null;
    $before_count = 0;
    $after_count = 0;

    foreach ($results as $result) {
        if ($result['period'] === 'before') {
            $before = floatval($result['average']);
            $before_count = intval($result['count']);
        } else {
            $after = floatval($result['average']);
            $after_count = intval($result['count']);
        }
    }

    $min_required_data = 1; // Modifié à 1 pour considérer toute donnée comme suffisante

    $insufficient_data = ($before_count < $min_required_data && $after_count < $min_required_data);

    return [
        'before' => $before,
        'after' => $after,
        'difference' => ($after ?? 0) - ($before ?? 0),
        'insufficient_data' => $insufficient_data,
        'before_count' => $before_count,
        'after_count' => $after_count
    ];
}

function updateDateCleStats($pdo, $questionnaire_id) {
    $stmt = $pdo->prepare("SELECT date_soumission, client_id FROM questionnaires WHERE id = ?");
    $stmt->execute([$questionnaire_id]);
    $questionnaire = $stmt->fetch();

    $stmt = $pdo->prepare("SELECT numero_chambre FROM clients WHERE id = ?");
    $stmt->execute([$questionnaire['client_id']]);
    $numero_chambre = $stmt->fetchColumn();

    $stmt = $pdo->prepare("SELECT id FROM dates_cles WHERE (section = 'Chambre' AND numero_chambre = ?) OR section != 'Chambre' AND date <= ?");
    $stmt->execute([$numero_chambre, $questionnaire['date_soumission']]);
    $date_cle_ids = $stmt->fetchAll(PDO::FETCH_COLUMN);

    foreach ($date_cle_ids as $date_cle_id) {
        $stats = getBeforeAfterData($pdo, $date_cle_id);
        $stmt = $pdo->prepare("UPDATE dates_cles SET stats_before = ?, stats_after = ?, stats_difference = ? WHERE id = ?");
        $stmt->execute([$stats['before'], $stats['after'], $stats['difference'], $date_cle_id]);
    }
}

function getDatesCles($pdo) {
    $stmt = $pdo->query("SELECT * FROM dates_cles ORDER BY date DESC");
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function addDateCle($pdo, $description, $date, $section, $sous_section, $numero_chambre) {
    $stmt = $pdo->prepare("INSERT INTO dates_cles (description, date, section, sous_section, numero_chambre) VALUES (?, ?, ?, ?, ?)");
    return $stmt->execute([$description, $date, $section, $sous_section, $numero_chambre]);
}

function deleteDateCle($pdo, $id) {
    $stmt = $pdo->prepare("DELETE FROM dates_cles WHERE id = ?");
    return $stmt->execute([$id]);
}

function updateDateCle($pdo, $id, $description, $date, $section, $sous_section, $numero_chambre) {
    $stmt = $pdo->prepare("UPDATE dates_cles SET description = ?, date = ?, section = ?, sous_section = ?, numero_chambre = ? WHERE id = ?");
    return $stmt->execute([$description, $date, $section, $sous_section, $numero_chambre, $id]);
}

function getGlobalStatistics($pdo, $start_date, $end_date) {
    $stmt = $pdo->prepare("
        SELECT 
            COUNT(DISTINCT q.id) as total_questionnaires,
            AVG(n.note) as moyenne_globale,
            MIN(n.note) as note_min,
            MAX(n.note) as note_max
        FROM 
            questionnaires q
        JOIN 
            notes_sous_sections n ON q.id = n.questionnaire_id
        WHERE
            q.date_soumission BETWEEN :start_date AND :end_date
    ");
    $stmt->execute(['start_date' => $start_date, 'end_date' => $end_date]);
    return $stmt->fetch(PDO::FETCH_ASSOC);
}

function getSectionStatistics($pdo, $start_date, $end_date) {
    $stmt = $pdo->prepare("
        SELECT 
            n.section,
            COUNT(DISTINCT q.id) as total_questionnaires,
            AVG(n.note) as moyenne,
            MIN(n.note) as note_min,
            MAX(n.note) as note_max
        FROM 
            questionnaires q
        JOIN 
            notes_sous_sections n ON q.id = n.questionnaire_id
        WHERE
            q.date_soumission BETWEEN :start_date AND :end_date
        GROUP BY 
            n.section
    ");
    $stmt->execute(['start_date' => $start_date, 'end_date' => $end_date]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function getTrendStatistics($pdo, $start_date, $end_date) {
    $mid_date = date('Y-m-d', strtotime($start_date . ' + ' . floor((strtotime($end_date) - strtotime($start_date)) / 2) . ' seconds'));
    
    $stmt = $pdo->prepare("
        SELECT 
            n.section,
            AVG(CASE WHEN q.date_soumission < :mid_date THEN n.note ELSE NULL END) as premiere_moitie,
            AVG(CASE WHEN q.date_soumission >= :mid_date THEN n.note ELSE NULL END) as deuxieme_moitie
        FROM 
            notes_sous_sections n
        JOIN 
            questionnaires q ON n.questionnaire_id = q.id
        WHERE
            q.date_soumission BETWEEN :start_date AND :end_date
        GROUP BY 
            n.section
    ");
    $stmt->execute(['start_date' => $start_date, 'end_date' => $end_date, 'mid_date' => $mid_date]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function getRecentComments($pdo, $limit = 5) {
    $stmt = $pdo->prepare("
        SELECT 
            cs.commentaire,
            q.date_soumission,
            c.prenom,
            c.nom
        FROM 
            commentaires_sections cs
        JOIN 
            questionnaires q ON cs.questionnaire_id = q.id
        JOIN 
            clients c ON q.client_id = c.id
        WHERE
            cs.commentaire IS NOT NULL AND cs.commentaire != ''
        ORDER BY 
            q.date_soumission DESC
        LIMIT :limit
    ");
    $stmt->bindValue(':limit', $limit, PDO::PARAM_INT);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function createTask($pdo, $notification_id, $remarque, $tags) {
    try {
        $pdo->beginTransaction();

        $stmt = $pdo->prepare("INSERT INTO taches (notification_id, remarque) VALUES (?, ?)");
        $stmt->execute([$notification_id, $remarque]);
        $task_id = $pdo->lastInsertId();

        $stmt = $pdo->prepare("INSERT INTO tags_taches (tache_id, tag_id) VALUES (?, ?)");
        foreach ($tags as $tag_id) {
            $stmt->execute([$task_id, $tag_id]);
        }

        $stmt = $pdo->prepare("UPDATE notifications SET status = 'traitee' WHERE id = ?");
        $stmt->execute([$notification_id]);

        $pdo->commit();
        return true;
    } catch (Exception $e) {
        $pdo->rollBack();
        error_log($e->getMessage());
        return false;
    }
}

function getTaskDetails($pdo, $taskId) {
    $stmt = $pdo->prepare("
        SELECT 
            t.id, t.remarque, t.date_creation, t.status, t.share_asana,
            n.section, n.sous_section, n.note,
            q.id as questionnaire_id,
            c.prenom, c.nom, c.numero_chambre,
            cs.commentaire,
            GROUP_CONCAT(DISTINCT st.tag) as tags
        FROM 
            taches t
        JOIN 
            notifications n ON t.notification_id = n.id
        JOIN 
            questionnaires q ON n.questionnaire_id = q.id
        JOIN 
            clients c ON q.client_id = c.id
        LEFT JOIN
            commentaires_sections cs ON q.id = cs.questionnaire_id AND n.section = cs.section
        LEFT JOIN
            tags_taches tt ON t.id = tt.tache_id
        LEFT JOIN
            section_tags st ON tt.tag_id = st.id
        WHERE
            t.id = ?
        GROUP BY 
            t.id
    ");
    $stmt->execute([$taskId]);
    return $stmt->fetch(PDO::FETCH_ASSOC);
}

function updateTask($pdo, $taskId, $status, $remarque) {
    $stmt = $pdo->prepare("UPDATE taches SET status = ?, remarque = ? WHERE id = ?");
    return $stmt->execute([$status, $remarque, $taskId]);
}



use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\SMTP;
use PHPMailer\PHPMailer\Exception;

// Inclure les fichiers PHPMailer
require_once __DIR__ . '/../libs/phpmailer/src/Exception.php';
require_once __DIR__ . '/../libs/phpmailer/src/PHPMailer.php';
require_once __DIR__ . '/../libs/phpmailer/src/SMTP.php';

function sendEmail($to, $subject, $body) {
    $mail = new PHPMailer(true);

    try {
        //Server settings
        $mail->SMTPDebug = 2; // Enable verbose debug output
        $mail->isSMTP();
        $mail->Host       = 'ssl0.ovh.net';
        $mail->SMTPAuth   = true;
        $mail->Username   = 'contact@satisfy.ovh';
        $mail->Password   = 'Aleis.191025';
        $mail->SMTPSecure = PHPMailer::ENCRYPTION_SMTPS;
        $mail->Port       = 465;

        //Recipients
        $mail->setFrom('contact@satisfy.ovh', 'Satisfy');
        $mail->addAddress($to);

        // Content
        $mail->isHTML(true);
        $mail->Subject = $subject;
        $mail->Body    = $body;

        ob_start();
        $mail->send();
        $result = ob_get_clean();
        error_log("Résultat de l'envoi d'email : " . $result);

        return true;
    } catch (Exception $e) {
        error_log("Erreur d'envoi d'email : " . $mail->ErrorInfo);
        error_log("Exception complète : " . $e->getMessage());
        return false;
    }
}

function updateQuestionnaireAverages($pdo, $questionnaire_id) {
    $sections = ['Hotel', 'Chambre', 'Restaurant', 'Spa'];
    $totalScore = 0;
    $count = 0;

    $sectionAverages = [];
    foreach ($sections as $section) {
        $sectionScore = calculateSectionAverage($pdo, $questionnaire_id, $section);
        if ($sectionScore !== null) {
            $sectionAverages[$section] = $sectionScore;
            $totalScore += $sectionScore;
            $count++;
        }
    }

    $globalAverage = $count > 0 ? round($totalScore / $count, 2) : null;
    $sectionAverages['Moyenne'] = $globalAverage;

    $stmt = $pdo->prepare("UPDATE questionnaires SET moyennes = ? WHERE id = ?");
    $stmt->execute([json_encode($sectionAverages), $questionnaire_id]);
}

function calculateSectionAverage($pdo, $questionnaire_id, $section) {
    $stmt = $pdo->prepare("
        SELECT note
        FROM notes_sous_sections
        WHERE questionnaire_id = ? AND section = ? AND note IS NOT NULL
    ");
    $stmt->execute([$questionnaire_id, $section]);
    $notes = $stmt->fetchAll(PDO::FETCH_COLUMN);
    
    $averageScore = calculateAverageScore($notes);
    return normalizeScoreToFiveStars($averageScore);
}

?>