<?php
session_start();
require_once 'includes/db_connect.php';
require_once 'includes/functions.php';

// Récupérer la structure du questionnaire, y compris les sections sans sous-sections actives
$stmt = $pdo->query("SELECT DISTINCT section, ordre FROM structure_questionnaire ORDER BY ordre");
$sections_order = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Récupérer les sous-sections actives
$stmt = $pdo->query("SELECT * FROM structure_questionnaire WHERE active = 1 ORDER BY ordre");
$active_subsections = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Grouper les sous-sections actives par section, en conservant l'ordre original des sections
$sections = [];
foreach ($sections_order as $section) {
    $sections[$section['section']] = [];
}
foreach ($active_subsections as $item) {
    $sections[$item['section']][] = $item['sous_section'];
}

// Filtrer les sections vides
$sections = array_filter($sections, function($subsections) {
    return !empty($subsections);
});
?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Questionnaire de satisfaction</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="css/styles.css" rel="stylesheet">
    <style>
        body {
            max-width: 700px;
            margin: 0 auto;
            padding: 20px;
        }
        .section-title {
            font-size: 1.5rem;
            font-weight: bold;
            margin-bottom: 1.5rem;
        }
        .subsection-container {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 1rem 0;
            border-bottom: 1px solid #e5e7eb;
        }
        .subsection-container:last-child {
            border-bottom: none;
        }
        .star-rating-container {
            display: flex;
        }
        .star-rating {
            font-size: 30px;
            width: 30px;
            height: 30px;
            cursor: pointer;
            color: #d1d5db;
        }
        .star-rating:hover,
        .star-rating.active {
            color: #fbbf24;
        }
        .star-rating::before {
            content: '★';
        }
        .comment-textarea {
            border: 1px solid #e5e7eb;
            border-radius: 0.375rem;
        }
        .comment-textarea[required] {
            border-color: #ef4444;
            background-color: #fee2e2;
        }
        .comment-textarea[required]:focus {
            border-color: #ef4444;
            ring-color: #fecaca;
        }
        .comment-required {
            color: #ef4444;
            font-size: 0.875rem;
            margin-top: 0.25rem;
        }
        @keyframes pulse-border {
            0% { box-shadow: 0 0 0 0 rgba(239, 68, 68, 0.7); }
            70% { box-shadow: 0 0 0 6px rgba(239, 68, 68, 0); }
            100% { box-shadow: 0 0 0 0 rgba(239, 68, 68, 0); }
        }
        .comment-textarea[required] {
            animation: pulse-border 2s infinite;
        }
    </style>
</head>
<body class="bg-gray-100 font-sans">
    <div class="container mx-auto">
        <div class="text-center mb-8">
            <img src="img/logo-noir.png" alt="Logo" width="180" height="180" class="mx-auto">
        </div>
        <h1 class="text-3xl font-bold mb-8 text-center text-gray-800">Questionnaire de satisfaction</h1>
        
        <form id="satisfaction-form" class="space-y-8" method="POST" action="submit_questionnaire.php">
            <?php 
            $sectionCount = count($sections);
            $currentSection = 0;
            foreach ($sections as $section => $subsections): 
                $currentSection++;
            ?>
                <div class="bg-white shadow-md rounded-lg p-6">
                    <h2 class="section-title"><?php echo htmlspecialchars($section); ?></h2>
                    
                    <?php foreach ($subsections as $subsection): ?>
                        <div class="subsection-container">
                            <span class="text-gray-700"><?php echo htmlspecialchars($subsection); ?></span>
                            <div class="star-rating-container">
                                <?php for ($i = 1; $i <= 5; $i++): ?>
                                    <span class="star-rating" data-section="<?php echo htmlspecialchars($section); ?>" data-subsection="<?php echo htmlspecialchars($subsection); ?>" data-rating="<?php echo $i; ?>"></span>
                                <?php endfor; ?>
                            </div>
                            <input type="hidden" name="ratings[<?php echo htmlspecialchars($section); ?>][<?php echo htmlspecialchars($subsection); ?>]" value="" class="rating-input">
                        </div>
                    <?php endforeach; ?>
                    
                    <div class="mt-6">
                        <label for="comment-<?php echo sanitizeForId($section); ?>" class="block text-sm font-medium text-gray-700">Commentaire</label>
                        <textarea id="comment-<?php echo sanitizeForId($section); ?>" name="comments[<?php echo htmlspecialchars($section); ?>]" class="mt-1 block w-full rounded-md shadow-sm focus:ring focus:ring-opacity-50 comment-textarea" rows="3"></textarea>
                        <p class="comment-required hidden" data-section="<?php echo htmlspecialchars($section); ?>"></p>
                    </div>
                </div>
            <?php endforeach; ?>
            
            <div class="text-center">
                <button type="submit" class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline">
                    Valider votre avis
                </button>
            </div>
        </form>
    </div>
    <script src="js/questionnaire.js"></script>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        const form = document.getElementById('satisfaction-form');
        const starButtons = document.querySelectorAll('.star-rating');
        const ratingInputs = document.querySelectorAll('.rating-input');
        const commentTextareas = document.querySelectorAll('.comment-textarea');
        const commentRequiredMessages = document.querySelectorAll('.comment-required');

        starButtons.forEach(button => {
            button.addEventListener('click', function() {
                const section = this.dataset.section;
                const subsection = this.dataset.subsection;
                const rating = this.dataset.rating;
                updateStarDisplay(section, subsection, rating);
                updateRatingInput(section, subsection, rating);
                checkCommentRequirement(section);
            });
        });

        function updateStarDisplay(section, subsection, rating) {
            const stars = document.querySelectorAll(`[data-section="${section}"][data-subsection="${subsection}"]`);
            stars.forEach((star, index) => {
                star.classList.toggle('active', index < rating);
            });
        }

        function updateRatingInput(section, subsection, rating) {
            const input = document.querySelector(`input[name="ratings[${section}][${subsection}]"]`);
            if (input) {
                input.value = rating;
            }
        }

        function checkCommentRequirement(section) {
            const sectionRatings = Array.from(document.querySelectorAll(`input[name^="ratings[${section}]"]`));
            const lowRatedSubsections = sectionRatings.filter(input => parseInt(input.value) <= 2 && parseInt(input.value) > 0)
                .map(input => input.name.match(/\[([^\]]+)\]$/)[1]);
            const commentTextarea = document.querySelector(`#comment-${sanitizeForId(section)}`);
            const commentRequired = document.querySelector(`[data-section="${section}"].comment-required`);
            
            if (lowRatedSubsections.length > 0) {
                commentTextarea.setAttribute('required', 'required');
                let message = "Pourriez-vous nous en dire davantage sur votre mécontentement à propos de ";
                if (lowRatedSubsections.length === 1) {
                    message += lowRatedSubsections[0] + " ?";
                } else {
                    message += lowRatedSubsections.slice(0, -1).join(", ") + " et " + lowRatedSubsections.slice(-1) + " ?";
                }
                commentRequired.textContent = message;
                commentRequired.classList.remove('hidden');
            } else {
                commentTextarea.removeAttribute('required');
                commentRequired.classList.add('hidden');
            }
        }

        function sanitizeForId(input) {
            return input.toLowerCase().replace(/[^a-z0-9]/g, '_');
        }

        form.addEventListener('submit', function(e) {
            let isValid = true;
            commentTextareas.forEach((textarea, index) => {
                if (textarea.hasAttribute('required') && textarea.value.trim() === '') {
                    e.preventDefault();
                    isValid = false;
                    commentRequiredMessages[index].classList.remove('hidden');
                }
            });

            if (!isValid) {
                alert('Veuillez remplir tous les commentaires obligatoires.');
            }
        });
    });
    </script>
</body>
</html>