document.addEventListener('DOMContentLoaded', function() {
    // Gestion du tableau de bord
    initializeDashboard();

    // Initialisation des graphiques si on est sur la page analytics
    if (document.getElementById('sectionAveragesChart')) {
        initializeCharts();
    }

    // Gestion du menu latéral responsive
    initializeSidebar();

    // Initialisation de Tippy.js
    initializeTippy();

    // Initialisation des filtres de date
    initializeDateFilters();
});

function initializeDashboard() {
    const table = document.getElementById('questionnaires-table');
    const toggleButton = document.getElementById('toggle-unread');
    const unreadCount = document.getElementById('unread-count');
    let showOnlyUnread = false;

    if (!table) return; // Si on n'est pas sur la page du tableau de bord, on sort de la fonction

    function updateUnreadCount() {
        const unreadRows = table.querySelectorAll('tbody tr[data-read="false"]');
        if (unreadCount) {
            unreadCount.textContent = `${unreadRows.length} non lu(s)`;
        }
    }

    function toggleUnreadRows() {
        const rows = table.querySelectorAll('tbody tr');
        rows.forEach(row => {
            if (showOnlyUnread) {
                row.style.display = row.getAttribute('data-read') === 'false' ? '' : 'none';
            } else {
                row.style.display = '';
            }
        });
    }

    if (toggleButton) {
        toggleButton.addEventListener('click', function() {
            showOnlyUnread = !showOnlyUnread;
            toggleButton.textContent = showOnlyUnread ? 'Afficher tout' : 'Afficher non lus';
            toggleUnreadRows();
        });
    }

    table.addEventListener('click', function(e) {
        const row = e.target.closest('tr');
        if (row && !e.target.closest('button')) {
            const id = row.getAttribute('data-id');
            const isCurrentlyRead = row.getAttribute('data-read') === 'true';
            
            fetch('update_read_state.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                body: `id=${id}&read=${!isCurrentlyRead}`
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    console.log('Mise à jour réussie, changement de l\'état visuel');
                    const newReadState = !isCurrentlyRead;
                    row.setAttribute('data-read', newReadState.toString());
                    row.style.backgroundColor = newReadState ? '#FFFFFF' : '#EBF8FF';
                    updateUnreadCount();
                    if (showOnlyUnread) {
                        toggleUnreadRows();
                    }
                } else {
                    console.error('Erreur lors de la mise à jour de l\'état de lecture');
                    alert('Erreur lors de la mise à jour. Veuillez réessayer.');
                }
            })
            .catch(error => {
                console.error('Erreur:', error);
                alert('Une erreur est survenue. Veuillez réessayer.');
            });
        }
    });

    // Filtrage côté client pour la recherche de texte
    const searchInput = document.getElementById('search');
    if (searchInput) {
        searchInput.addEventListener('input', function() {
            const searchTerm = this.value.toLowerCase();
            const rows = table.querySelectorAll('tbody tr');
            rows.forEach(row => {
                const text = row.textContent.toLowerCase();
                if (text.includes(searchTerm)) {
                    row.style.display = '';
                } else {
                    row.style.display = 'none';
                }
            });
            updateUnreadCount();
        });
    }

    // Initialiser le compte des non lus
    updateUnreadCount();
}

function initializeCharts() {
    // Code pour initialiser les graphiques
    console.log("Initialisation des graphiques");
    // Ajoutez ici le code spécifique à l'initialisation de vos graphiques
}

function initializeSidebar() {
    const sidebarToggle = document.getElementById('sidebar-toggle');
    const sidebar = document.getElementById('sidebar');
    if (sidebarToggle && sidebar) {
        sidebarToggle.addEventListener('click', function() {
            sidebar.classList.toggle('hidden');
        });
    }
}

function initializeTippy() {
    if (typeof tippy !== 'undefined') {
        tippy('[data-tippy-content]', {
            allowHTML: true,
            interactive: true,
            animation: 'scale',
        });
    }
}

function initializeDateFilters() {
    const startDateInput = document.getElementById('start_date');
    const endDateInput = document.getElementById('end_date');
    
    if (startDateInput && endDateInput) {
        startDateInput.addEventListener('change', function() {
            if (endDateInput.value && this.value > endDateInput.value) {
                alert('La date de début ne peut pas être postérieure à la date de fin.');
                this.value = '';
            }
        });

        endDateInput.addEventListener('change', function() {
            if (startDateInput.value && this.value < startDateInput.value) {
                alert('La date de fin ne peut pas être antérieure à la date de début.');
                this.value = '';
            }
        });
    }
}

function editQuestionnaire(id) {
    window.location.href = `edit_questionnaire.php?id=${id}`;
}

function repondreQuestionnaire(id) {
    // Cette fonction sera implémentée plus tard
    console.log(`Répondre au questionnaire ${id}`);
}

function deleteClient(id) {
    if (confirm('Êtes-vous sûr de vouloir supprimer ce client et son questionnaire ?')) {
        fetch('delete_client.php', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/x-www-form-urlencoded',
            },
            body: `id=${id}`
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                alert('Client supprimé avec succès');
                location.reload();
            } else {
                alert('Erreur lors de la suppression du client : ' + data.message);
            }
        })
        .catch(error => {
            console.error('Error:', error);
            alert('Une erreur est survenue lors de la suppression du client');
        });
    }
}

// Fonction pour gérer la pagination
function changePage(page) {
    const currentUrl = new URL(window.location.href);
    currentUrl.searchParams.set('page', page);
    window.location.href = currentUrl.toString();
}

// Autres fonctions utilitaires
function formatDate(date) {
    const d = new Date(date);
    const year = d.getFullYear();
    const month = ('0' + (d.getMonth() + 1)).slice(-2);
    const day = ('0' + d.getDate()).slice(-2);
    return `${year}-${month}-${day}`;
}

// Fonction pour exporter les données (à implémenter selon vos besoins)
function exportData() {
    console.log('Exportation des données');
    // Implémentez ici la logique d'exportation des données
}

// Fonction pour importer des données (à implémenter selon vos besoins)
function importData() {
    console.log('Importation des données');
    // Implémentez ici la logique d'importation des données
}

function downloadClientPDF(id) {
    window.open(`generate_client_pdf.php?id=${id}`, '_blank');
}

// Ajoutez d'autres fonctions spécifiques à l'administration si nécessaire