document.addEventListener('DOMContentLoaded', function() {
    const form = document.getElementById('satisfaction-form');
    const starButtons = document.querySelectorAll('.star-rating');
    const ratingInputs = document.querySelectorAll('.rating-input');
    const commentTextareas = document.querySelectorAll('.comment-textarea');
    const commentRequiredMessages = document.querySelectorAll('.comment-required');

    starButtons.forEach(button => {
        button.addEventListener('click', function() {
            const section = this.dataset.section;
            const subsection = this.dataset.subsection;
            const rating = this.dataset.rating;
            updateStarDisplay(section, subsection, rating);
            updateRatingInput(section, subsection, rating);
            checkCommentRequirement(section);
        });
    });

    function updateStarDisplay(section, subsection, rating) {
        const stars = document.querySelectorAll(`[data-section="${section}"][data-subsection="${subsection}"]`);
        stars.forEach((star, index) => {
            star.querySelector('span').classList.toggle('text-yellow-400', index < rating);
            star.querySelector('span').classList.toggle('text-gray-300', index >= rating);
        });
    }

    function updateRatingInput(section, subsection, rating) {
        const input = document.querySelector(`input[name="ratings[${section}][${subsection}]"]`);
        if (input) {
            input.value = rating;
        }
    }

    function checkCommentRequirement(section) {
        const sectionRatings = Array.from(document.querySelectorAll(`input[name^="ratings[${section}]"]`));
        const lowRatedSubsections = sectionRatings.filter(input => parseInt(input.value) <= 2 && parseInt(input.value) > 0)
            .map(input => input.name.match(/\[([^\]]+)\]$/)[1]);
        const commentTextarea = document.querySelector(`#comment-${sanitizeForId(section)}`);
        const commentRequired = document.querySelector(`[data-section="${section}"].comment-required`);
        
        if (lowRatedSubsections.length > 0) {
            commentTextarea.setAttribute('required', 'required');
            let message = "Pourriez-vous nous en dire davantage sur votre mécontentement à propos de ";
            if (lowRatedSubsections.length === 1) {
                message += lowRatedSubsections[0] + " ?";
            } else {
                message += lowRatedSubsections.slice(0, -1).join(", ") + " et " + lowRatedSubsections.slice(-1) + " ?";
            }
            commentRequired.textContent = message;
            commentRequired.classList.remove('hidden');
        } else {
            commentTextarea.removeAttribute('required');
            commentRequired.classList.add('hidden');
        }
    }

    function sanitizeForId(input) {
        return input.toLowerCase().replace(/[^a-z0-9]/g, '_');
    }

    form.addEventListener('submit', function(e) {
        let isValid = true;
        commentTextareas.forEach((textarea, index) => {
            if (textarea.hasAttribute('required') && textarea.value.trim() === '') {
                e.preventDefault();
                isValid = false;
                commentRequiredMessages[index].classList.remove('hidden');
            }
        });

        if (!isValid) {
            alert('Veuillez remplir tous les commentaires obligatoires.');
        }
    });
});